(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    507662,      21045]*)
(*NotebookOutlinePosition[    543910,      22258]*)
(*  CellTagsIndexPosition[    542989,      22224]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["excerpt from",
    FontSlant->"Italic"],
  " Numerical and Analytical Methods for Scientists and Engineers"
}], "Subtitle"],

Cell["\<\
The material in this notebook is copyright John Wiley and Sons, \
2003. Bullk reproduction or resale is prohibited.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
7.2.3 Time-Dependent Solutions of the KdV equation: The Galerkin \
Method\
\>", "Subsubtitle",
  CellTags->"c:18"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:19"],

Cell["\<\
\tWe have seen that steady soliton and cnoidal wave solutions to \
the KdV equation  occur because of a balance between nonlinear steepening and \
dispersive spreading. But how do we know that such a balance is stable? If a \
steady solution is slightly perturbed, does the result remain close to the \
steady solution, or diverge from it?  If the latter is true, then these \
steady solutions are not of much more than academic interest. Although Scott \
Russell's description indicates that solitons are in fact stable, it would be \
nice to see this fact arise from the mathematics. \
\>", "Text"],

Cell["\<\
\tThere has been considerable analytical work on the stability of \
steady solutions to the KdV equation. This work is of a highly technical \
nature and will not be discussed here. Rather, we will use numerical \
techniques already at our disposal to test the stability of the solutions.  \
We will also study the interaction between solitons, and wavebreaking. \
\>", \
"Text"],

Cell[TextData[{
  "\tWe will use the Galerkin method, solving the ",
  "KdV",
  " equation with periodic boundary conditions on an interval running from  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(-L\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ".  A set of basis functions for these boundary conditions are"
}], "Text",
  CellTags->"i:74"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          x)\  = \ \[ExponentialE]\^\(\(\ \)\(i\ k\ x\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ n\ \[Pi]/L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\) \[LessEqual] \ n \[LessEqual] \ M\)]],
  "."
}], "NE2",
  CellTags->"(7.2.20)"],

Cell[TextData[{
  "The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " is then written in terms of these functions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t)\  = \ \[Sum]\+n\(\( c\_n\)(
              t)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \ x\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.21)"],

Cell[TextData[{
  "The basis functions are orthogonal with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-L\)\%L\( f\^*\) g \[DifferentialD]x\)]],
  ", so this is the inner product we will use. Substituting this series into \
the ",
  "KdV",
  " equation, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\[Sum]\+n\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
                  t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\), "+", 
            RowBox[{
              UnderscriptBox[
                StyleBox["\[Sum]",
                  FontSize->9], \(\(n\&_\)\&_\)], 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->9], \(n\&_\)], \(\(\(c\_\(n\&_\)\&_\)(
                    t)\) \(\(c\_n\&_\)(
                    t)\) \[ImaginaryI]\ \(k\&_\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \((\(k\&_\)\&_ + k\&_)\)\ x\)\)}]}], 
            "-", \(\[Alpha] \(\[Sum]\+n \[ImaginaryI]\ \(k\^3\) \(\(c\_n\)(
                    t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)\)}], "=", 
          "0"}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.22)"],

Cell[TextData[{
  "We now take an inner product with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  ", and note that,",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\),
                "TraditionalForm"], 
              ",", \(\[ExponentialE]\^\(\[ImaginaryI]\ \((\(k\&_\)\&_ + 
                        k\&_)\)\ x\)\)}], ")"}], 
          "=", \(L\ \[Delta]\_\(k, \ \(k\&_\)\&_ + k\&_\)\)}], 
        TraditionalForm]]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\&_\)\&_ = k - k\&_\)]],
  ", and Eq. ",
  ButtonBox["(7.2.22)",
    ButtonData:>{"Chapter7.nb", "(7.2.22)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
              t)\) + \[Sum]\+\(n\&_\)\(\(c\_\(n - n\&_\)\)(t)\) \(\(c\_n\&_\)(
                t)\) \[ImaginaryI]\ k\&_ - \[Alpha]\ \[ImaginaryI]\ \(k\^3\) \
\(\(c\_n\)(t)\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.23)"],

Cell[TextData[{
  "We will solve these coupled nonlinear ODEs for ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  " using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Before we do, however, we note that ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " is a real function, so this implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(-n\)\)(t)\  = \ \(\(\(c\_n\)(t)\)\^*\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.24)"],

Cell[TextData[{
  "Therefore, we do not need to solve for the coefficients with ",
  Cell[BoxData[
      \(TraditionalForm\`n < 0\)]],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(\(c[n_]\)[t_]\  := \ 
        Conjugate[\(c[\(-n\)]\)[t]]\  /; \ n < 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.40"],

Cell[TextData[{
  "\tAlso, note that the nonlinear term in Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  "  couples modes with different wavenumbers. Even though the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_\)]],
  " runs only from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ",  coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(n - n\&_\)\)(t)\)]],
  " may fall outside this range . In fact, this is sure to happen \
eventually",
  ",",
  " even if ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " is initially zero for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(n\)\(|\)\(\(>\)\(M\)\)\)\)]],
  ". For example, say that initially only ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  " are the only nonzero coefficients (i.e., the solution is a sinusoidal \
wave with wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/L\)]],
  "). Then according to Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  " , there is an initial rate of change for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\[PlusMinus]2\)\)]],
  "given by\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) 
            c\_2 + \ \[ImaginaryI]\ \[Pi]\/L\ \((c\_1)\)\^2 = 
        0, \[IndentingNewLine]\(\[PartialD]\/\[PartialD]t\) 
            c\_\(-2\) - \ \[ImaginaryI]\ \[Pi]\/L\ \((c\_\(-1\))\)\^2 = 
        0. \)]]
}], "Text"],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\[PlusMinus]2\)\)]],
  "has grown to large amplitude, these coefficients couple in turn to modes \
with ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\[PlusMinus]3\), \ \(\[PlusMinus]4\), \)]],
  " and so on, until a broad range of wavenumbers are excited. This is called \
a ",
  StyleBox["cascade",
    FontSlant->"Italic"],
  ".  If it is unchecked, eventually waves with arbitrarily high wavenumbers \
are excited. This is what leads to wavebreaking in the case of Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : as the wave attains infinite slope, this corresponds to Fourier modes \
with infinite wavenumber. "
}], "Text",
  CellTags->"i:53"],

Cell[TextData[{
  "\tWe can hope that the cascade is suppressed by the dispersive term in the \
KdV equation. However, one can see in Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  "  that this term, proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", causes only a rapid oscillation in the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", and does not affect its amplitude. On the other hand, we might imagine \
that this rapid oscillation does cause phase mixing, which has an equivalent \
effect to the suppression of the amplitude, so we will simply neglect all \
modes with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(n\)\(|\)\(\(>\)\(M\)\)\)\)]],
  ", explicitly setting them equal to zero: "
}], "Text"],

Cell[BoxData[
    \(\(\(c[n_]\)[t_]\  := \ 0\  /; \ Abs[n] > M;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.41"],

Cell["The hope is that these modes will not be needed.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: Cnoidal Wave", "Section",
  CellTags->{"i:44", "c:20"}],

Cell["\<\
For our first test, we will try a cnoidal wave  as the initial \
condition:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(f[s_, a_, b_, 
          c_] = \ \ a\  - \ \((a - b)\)\ JacobiSN[Sqrt[\((a - c)\)/12] s, 
                  m]^2 /. m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(f0[x_]\  = \ f[x, 1,  .1, 0];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.42"],

Cell[TextData[{
  "In order to fit this cnoidal wave into our periodic boundary conditions, \
we choose ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " to be a multiple of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, c)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Lambda][a_, b_, c_]\  = \ 
        2\ EllipticK[m]\ Sqrt[12/\((a - c)\)]\  /. 
          m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(L\  = \ 2\ \[Lambda][1,  .1, 0]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.43"],

Cell[BoxData[
    \(35.72309221529325`\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "As usual, the initial conditions on the Fourier modes are determined by  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_o\)(x)\)\(\ \)\)\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(
          0)\  = \((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \ \(f\_o\)(
                x))\)/2  L\)]],
  ".",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "NE2",
  CellTags->"(7.2.25)"],

Cell["We will keep 15 modes in our solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(M = 15;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(k[n_]\  := \ n\ Pi/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ics\  = \ 
        Table[\(c[n]\)[0]\  \[Equal] \ 
            NIntegrate[
                Exp[\(-I\)\ k[n]\ x]\ f0[x], {x, \(-L\), L}]/\((2  L)\), {n, 
            0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.44"],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \!\(35.72309221520074`\)."\)], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \
\!\(-35.72309221520074`\)."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \!\(35.72309221520074`\)."\)], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(NIntegrate :: \"ncvb\"\) will be suppressed \
during this calculation."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
The errors in the  integration can be ignored: they arise from the \
fact that several of the modes have zero initial amplitude. These errors can \
be avoided by setting these mode amplitudes equal to zero directly without \
evaluating the integrals.\
\>", "Text"],

Cell[TextData[{
  "\t We now integrate the ODEs forward in time using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and plot the result over a time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < t\_max\)]],
  " in steps of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", with plot range from ",
  Cell[BoxData[
      \(TraditionalForm\`f\_min\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`f\_max\)]],
  " We do so using a module, since we will be studying several examples. The \
ODEs that we will solve are given by Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  " , taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(kdVmod[tmax_, \[CapitalDelta]t_, fmin_, fmax_]\  := \ 
      Module[{k, \ ODEs}, \[IndentingNewLine]\[IndentingNewLine]k[n_]\  = \ 
          n\ Pi/L; \[IndentingNewLine]\[IndentingNewLine]ODEs\  = \ 
          Table[D[\(c[n]\)[t], t]\  - I\ k[n]^3\ \(c[n]\)[t]\  + 
                Sum[\ I\ k[nb]\ \ \(c[nb]\)[t]\ \(c[n - nb]\)[
                      t], {nb, \(-M\), M}] == 0, {n, 0, 
              M}]; \[IndentingNewLine]\[IndentingNewLine]vars\  = \ 
          Table[\(c[n]\)[t], {n, 0, 
              M}]; \[IndentingNewLine]\[IndentingNewLine]sol\  = \ 
          NDSolve[Join[ODEs, \ ics], vars, {t, 0, tmax}, 
            MaxSteps \[Rule] 6000]; \[IndentingNewLine]\[IndentingNewLine]f[
            x_, t_]\  = \ 
          Sum[\(c[n]\)[t]\ Exp[I\ k[n]\ x], {n, \(-M\), 
              M}]; \[IndentingNewLine]f[x_, t_]\  = \ 
          f[x, t] /. 
            sol[\([1]\)]; \[IndentingNewLine]\[IndentingNewLine]Table[
          Plot[f[x, t], {x, \(-L\), L}, 
            PlotRange \[Rule] {{\(-L\), L}, {fmin, fmax}}, 
            PlotLabel \[Rule] "\< M = \>" <> \ ToString[M]\  <> "\<, t = \>" <> 
                ToString[t]], {t, 0, tmax, \[CapitalDelta]t}];]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.45"],

Cell[TextData[{
  "We now evaluate the solution over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 200\)]],
  ", as shown in Cell ",
  ButtonBox["7.46",
    ButtonData:>"Cell 7.46",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(kdVmod[200, 5, 0, 2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.46"],

Cell[BoxData[
    \( (*\ simulation\ removed\ to\ save\ space\ *) \)], "Input"],

Cell[TextData[{
  "The solution appears to be well behaved and stable over the time scale of \
interest. It moves to the right with a speed given by Eq. ",
  ButtonBox["(7.2.16)",
    ButtonData:>{"Chapter7.nb", "(7.2.16)"},
    ButtonStyle->"Hyperlink"],
  " . Other cnoidal waves and solitons can be handled by simply varying the \
parameters.  One can also add small perturbations to these solutions. One \
finds by this sort of empirical approach that steady solutions to the KdV \
equation are stable to small perturbations. This is born out by the \
previously mentioned analytic work on this problem. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Interacting Solitons", "Section",
  CellTags->"c:21"],

Cell["\<\
In this example, for initial conditions we take two soliton \
solutions with different amplitudes:\
\>", "Text"],

Cell[BoxData[{
    \(\(L = \ 60;\)\), "\n", 
    \(\(f0[
          x_]\  = \ \(1/3\)/Cosh[Sqrt[1/36]\ \((x + 30)\)]^2\  + \ \(1/4\)\ /
            Cosh[Sqrt[1/48]\ \((x - 30\ )\)]^2\ ;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.47"],

Cell["We will again evaluate the solution keeping 15 modes:", "Text"],

Cell[BoxData[{
    \(\(\(M = 15;\)\(\n\)
    \)\), "\n", 
    \(\(\(k[n_]\  := \ n\ Pi/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ics\  = \ 
        Table[\(c[n]\)[0]\  \[Equal] \ 
            NIntegrate[
                Exp[\(-I\)\ k[n]\ x]\ f0[x], {x, \(-L\), L}]/\((2  L)\), {n, 
            0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.48"],

Cell[TextData[{
  "In order to follow the dynamics we must integrate over a longer time, ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 6000\)]],
  ", because our initial conditions are solitons of rather small amplitude. \
This implies their velocities are small. The solution is displayed in Cell ",
  ButtonBox["7.49",
    ButtonData:>"Cell 7.49",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(kdVmod[6000, 100, 0,  .6]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.49"],

Cell[BoxData[
    \( (*\ simulation\ removed\ to\ save\ space\ *) \)], "Input"],

Cell["\<\
The soliton in back, being of larger amplitude, moves with higher \
speed and catches up to the soliton in the front. It then feeds some of its \
amplitude to the soliton in the front, until they exchange amplitudes, and \
the soliton in the front then moves away from the one in the back. \
Effectively, the two solitons have exchanged places: they have passed through \
one another without change. Thanks to the periodic boundary conditions, this \
interaction then repeats itself ad infinitum. \
\>", "Text"],

Cell["\<\
\tThe fact that solitons effectively retain their shape during \
binary interactions implies that a description of nonlinear processes can \
often be greatly simplified - one can think of the nonlinear system as a gas \
of discrete solitons, which act almost like discrete particles, interacting \
with one another but retaining their identity. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3: Suppression of Wavebreaking", "Section",
  CellTags->{"i:45", "c:22"}],

Cell[TextData[{
  "In this example, we investigate whether wavebreaking occurs in the KdV \
equation. Recall that wavebreaking was observed in the solutions to Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " , where dispersion is neglected. Although we cannot hope to observe \
similar double-valued solutions using the Galerkin method, which expands in a \
set of single-valued modes, we might expect to see some initial conditions \
steepen, and the spectrum of waves should display a cascade to high \
wavenumbers. "
}], "Text"],

Cell[TextData[{
  "For our initial condition, we  take a single finite amplitude sine wave. \
We now keep ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(20\)\(\ \)\)\)]],
  "modes in order to be certain of capturing the high-wavenumber dynamics \
properly, as shown in Cell ",
  ButtonBox["7.50",
    ButtonData:>"Cell 7.50",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[{
    \(L = \ 40; \ M = 20;\), "\n", 
    \(\(ics\  = \ Table[\(c[n]\)[0]\  \[Equal] \ 0, {n, 0, M}];\)\), "\n", 
    \(\(\(ics[\([2]\)] = \(c[1]\)[0] \[Equal] 1/8;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(kdVmod[800, 10, \(-1\), 1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.50"],

Cell[BoxData[
    \( (*\ simulation\ removed\ to\ save\ space\ *) \)], "Input"],

Cell[TextData[{
  "\tInitially the wave steepens, just as when dispersion is neglected. \
However, instead of breaking, the wave dissociates into several solitons that \
proceed to interact with one another in a complex manner.   The spectrum of \
the solution is peaked at low wavenumbers, as can be seen in the  plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\(c\_n\)(t)\)\(|\)\)\)]],
  " shown in Cell ",
  ButtonBox["7.51",
    ButtonData:>"Cell 7.51",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(spectrum = \ Abs[vars /. sol[\([1]\)]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ParametricPlot3D[{k[n], t, spectrum[\([n + 1]\)]}, {t, 0, 800}, 
          DisplayFunction \[Rule] Identity], {n, 0, M}];\)\), "\n", 
    \(\(Show[%, DisplayFunction \[Rule] $DisplayFunction, 
        BoxRatios \[Rule] {1, 1, 1}, 
        AxesLabel \[Rule] {"\<k\>", "\<t\>", "\<|\!\(c\_n\)(t)|  \>"}, 
        PlotLabel -> "\<wave spectrum\n \>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.51"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.5 1.098 -41.125 0 ]
[.5 1.098 41.125 24.5 ]
[.09072 .22988 -5.91576 -9 ]
[.09072 .22988 .08424 0 ]
[.25533 .16034 -16.7461 -9 ]
[.25533 .16034 1.25388 0 ]
[.43173 .08588 -5.24832 -9 ]
[.43173 .08588 .75168 0 ]
[.62122 .00596 -14.7438 -9 ]
[.62122 .00596 3.25621 0 ]
[.30907 .06148 -8.98592 -12 ]
[.30907 .06148 1.01408 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.12079 .90442 -10.0666 0 ]
[.12079 .90442 7.93341 9 ]
[.22056 .97437 -9.78807 0 ]
[.22056 .97437 8.21193 9 ]
[.31055 1.03745 -9.54626 0 ]
[.31055 1.03745 8.45374 9 ]
[.39213 1.09464 -9.33435 0 ]
[.39213 1.09464 8.66565 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.05358 .38541 -24 -2.72708 ]
[.05358 .38541 0 6.27292 ]
[.03208 .51999 -24 -2.84769 ]
[.03208 .51999 0 6.15231 ]
[.00848 .66771 -24 -2.98134 ]
[.00848 .66771 0 6.01866 ]
[-0.03373 .52941 -57.25 -3.77786 ]
[-0.03373 .52941 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -102.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(spectrum) show
69.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.26484 .17139 m
.2696 .17691 L
s
[(0.5)] .25533 .16034 .86068 1 Mshowa
.44047 .09754 m
.44484 .10337 L
s
[(1)] .43173 .08588 .74944 1 Mshowa
.62906 .01825 m
.63298 .02439 L
s
[(1.5)] .62122 .00596 .6382 1 Mshowa
.125 Mabswid
.13279 .22691 m
.1358 .23008 L
s
.16514 .21331 m
.16811 .21652 L
s
.19792 .19953 m
.20086 .20277 L
s
.23115 .18555 m
.23405 .18883 L
s
.299 .15703 m
.30181 .16038 L
s
.33363 .14247 m
.33639 .14585 L
s
.36874 .1277 m
.37146 .13113 L
s
.40435 .11273 m
.40703 .11619 L
s
.47711 .08214 m
.47968 .08567 L
s
.51427 .06651 m
.51679 .07008 L
s
.55198 .05066 m
.55444 .05427 L
s
.59024 .03457 m
.59265 .03822 L
s
.66846 .00168 m
.67075 .0054 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(200)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(400)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(600)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(800)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.04063 .83233 m
.04126 .82801 L
s
.06868 .85207 m
.06927 .84774 L
s
.09596 .87127 m
.09651 .86693 L
s
.14833 .90812 m
.14881 .90378 L
s
.17348 .92582 m
.17392 .92147 L
s
.19797 .94306 m
.19838 .9387 L
s
.24508 .97621 m
.24543 .97185 L
s
.26775 .99217 m
.26808 .9878 L
s
.28986 1.00772 m
.29016 1.00336 L
s
.33248 1.03771 m
.33271 1.03335 L
s
.35302 1.05217 m
.35323 1.0478 L
s
.37308 1.06628 m
.37326 1.06192 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.06714 .38007 m
.07392 .37739 L
s
[(0.02)] .05358 .38541 1 -0.39398 Mshowa
.04576 .51497 m
.0526 .51246 L
s
[(0.04)] .03208 .51999 1 -0.36718 Mshowa
.02229 .66305 m
.0292 .66072 L
s
[(0.06)] .00848 .66771 1 -0.33748 Mshowa
.125 Mabswid
.08197 .28651 m
.08601 .28484 L
s
.07713 .31702 m
.08118 .31537 L
s
.07219 .34819 m
.07625 .34657 L
s
.06198 .41265 m
.06605 .41107 L
s
.05669 .44598 m
.06078 .44443 L
s
.05129 .48008 m
.05539 .47855 L
s
.0401 .55068 m
.04422 .5492 L
s
.03431 .58725 m
.03843 .58579 L
s
.02837 .62469 m
.03251 .62326 L
s
.01607 .70236 m
.02022 .70099 L
s
.00968 .74265 m
.01384 .74131 L
s
.00313 .78396 m
.00731 .78266 L
s
gsave
-0.03373 .52941 -118.25 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
75.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 13.000 moveto
(H) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
(\\310) show
116.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4186 .578 m
.42216 .58164 L
s
.41502 .57434 m
.4186 .578 L
s
.41143 .57067 m
.41502 .57434 L
s
.40782 .56698 m
.41143 .57067 L
s
.40419 .56327 m
.40782 .56698 L
s
.40055 .55955 m
.40419 .56327 L
s
.39689 .55581 m
.40055 .55955 L
s
.39322 .55206 m
.39689 .55581 L
s
.38953 .54829 m
.39322 .55206 L
s
.38583 .5445 m
.38953 .54829 L
s
.3821 .54069 m
.38583 .5445 L
s
.37836 .53687 m
.3821 .54069 L
s
.37461 .53303 m
.37836 .53687 L
s
.37084 .52917 m
.37461 .53303 L
s
.36705 .5253 m
.37084 .52917 L
s
.36324 .52141 m
.36705 .5253 L
s
.35941 .5175 m
.36324 .52141 L
s
.35557 .51357 m
.35941 .5175 L
s
.35171 .50962 m
.35557 .51357 L
s
.34784 .50566 m
.35171 .50962 L
s
.34394 .50168 m
.34784 .50566 L
s
.42317 .54966 m
.4247 .6207 L
s
.41891 .56099 m
.42317 .54966 L
s
.34003 .49768 m
.34394 .50168 L
s
.5805 .57328 m
.58395 .58182 L
s
.57752 .59388 m
.5805 .57328 L
s
.3361 .49366 m
.34003 .49768 L
s
.60442 .55335 m
.60857 .58906 L
s
.60101 .54598 m
.60442 .55335 L
s
.59803 .55766 m
.60101 .54598 L
s
.33215 .48963 m
.3361 .49366 L
s
.41257 .62852 m
.41891 .56099 L
s
.46678 .51773 m
.46995 .54716 L
s
.46282 .52881 m
.46678 .51773 L
s
.5573 .6634 m
.56024 .61677 L
s
.67721 .51067 m
.6801 .50932 L
s
.32819 .48557 m
.33215 .48963 L
s
.65358 .54322 m
.65627 .53455 L
s
.62192 .52912 m
.62567 .54748 L
s
.61863 .52592 m
.62192 .52912 L
s
.3242 .4815 m
.32819 .48557 L
s
.70147 .49206 m
.70475 .49884 L
s
.67452 .51679 m
.67721 .51067 L
s
.49404 .52473 m
.49749 .54331 L
s
.4903 .53163 m
.49404 .52473 L
s
.59485 .56199 m
.59803 .55766 L
s
.46995 .54716 m
.47328 .56947 L
s
.3202 .4774 m
.3242 .4815 L
s
.69868 .49392 m
.70147 .49206 L
s
.62567 .54748 m
.6296 .57033 L
s
.61535 .52321 m
.61863 .52592 L
s
.57456 .61954 m
.57752 .59388 L
s
.45816 .56854 m
.46282 .52881 L
s
.51105 .48506 m
.51454 .50753 L
s
.50733 .50398 m
.51105 .48506 L
s
.45279 .59615 m
.45617 .61424 L
s
.44889 .59999 m
.45279 .59615 L
s
.49749 .54331 m
.50098 .56057 L
s
.31617 .47329 m
.3202 .4774 L
s
.65048 .54296 m
.65358 .54322 L
s
.61191 .51572 m
.61535 .52321 L
s
.50454 .56795 m
.50807 .58057 L
s
.50098 .56057 m
.50454 .56795 L
s
.47328 .56947 m
.47672 .58646 L
s
.50807 .58057 m
.51147 .62238 L
s
.63959 .50301 m
.64321 .51633 L
s
.63616 .49494 m
.63959 .50301 L
s
.72646 .48352 m
.72982 .49188 L
s
.45617 .61424 m
.4593 .64446 L
s
.6296 .57033 m
.63315 .58187 L
s
.60843 .50679 m
.61191 .51572 L
s
.69583 .49518 m
.69868 .49392 L
s
.64321 .51633 m
.64694 .53208 L
s
.67149 .51656 m
.67452 .51679 L
s
.72331 .47838 m
.72646 .48352 L
s
.63275 .48767 m
.63616 .49494 L
s
.31213 .46916 m
.31617 .47329 L
s
.59149 .55972 m
.59485 .56199 L
s
.60493 .49764 m
.60843 .50679 L
s
.52163 .52913 m
.52517 .55261 L
s
.51808 .5193 m
.52163 .52913 L
s
.51454 .50753 m
.51808 .5193 L
s
.47672 .58646 m
.48018 .60364 L
s
.60146 .48933 m
.60493 .49764 L
s
.48407 .73474 m
.48795 .72004 L
s
.48655 .53653 m
.4903 .53163 L
s
.49799 .65378 m
.50115 .71444 L
s
.49434 .65294 m
.49799 .65378 L
s
.4247 .6207 m
.42657 .68547 L
s
.64694 .53208 m
.65048 .54296 L
s
.62929 .47916 m
.63275 .48767 L
s
.44473 .61225 m
.44889 .59999 L
s
.59801 .48237 m
.60146 .48933 L
s
.72046 .47799 m
.72331 .47838 L
s
.62585 .47152 m
.62929 .47916 L
s
.75175 .47575 m
.75476 .47959 L
s
.30807 .46501 m
.31213 .46916 L
s
.48018 .60364 m
.48358 .62571 L
s
.58806 .55459 m
.59149 .55972 L
s
.59457 .47636 m
.59801 .48237 L
s
.62245 .46532 m
.62585 .47152 L
s
.6681 .50897 m
.67149 .51656 L
s
.69272 .49212 m
.69583 .49518 L
s
.6609 .4849 m
.66451 .49703 L
s
.65742 .47563 m
.6609 .4849 L
s
.52517 .55261 m
.52875 .59032 L
s
.49058 .65994 m
.49434 .65294 L
s
.66451 .49703 m
.6681 .50897 L
s
.48305 .52037 m
.48655 .53653 L
s
.4792 .52808 m
.48305 .52037 L
s
.304 .46084 m
.30807 .46501 L
s
.65406 .46901 m
.65742 .47563 L
s
.74856 .46954 m
.75175 .47575 L
s
.59111 .46988 m
.59457 .47636 L
s
.61912 .4615 m
.62245 .46532 L
s
.58453 .5452 m
.58806 .55459 L
s
.4593 .64446 m
.46255 .67143 L
s
.71744 .47549 m
.72046 .47799 L
s
.58097 .53413 m
.58453 .5452 L
s
.57741 .52361 m
.58097 .53413 L
s
.77703 .46483 m
.77988 .46748 L
s
.57387 .51351 m
.57741 .52361 L
s
.53882 .50159 m
.54241 .51816 L
s
.53527 .49572 m
.53882 .50159 L
s
.57032 .50383 m
.57387 .51351 L
s
.65072 .46343 m
.65406 .46901 L
s
.48358 .62571 m
.487 .64869 L
s
.74548 .46501 m
.74856 .46954 L
s
.58765 .46379 m
.59111 .46988 L
s
.68938 .48524 m
.69272 .49212 L
s
.56676 .49318 m
.57032 .50383 L
s
.50355 .52116 m
.50733 .50398 L
s
.5632 .48257 m
.56676 .49318 L
s
.5597 .47761 m
.5632 .48257 L
s
.2999 .45665 m
.304 .46084 L
s
.61578 .45787 m
.61912 .4615 L
s
.53172 .49613 m
.53527 .49572 L
s
.54241 .51816 m
.546 .53315 L
s
.5543 .71876 m
.5573 .6634 L
s
.68594 .47642 m
.68938 .48524 L
s
.57133 .63254 m
.57456 .61954 L
s
.64741 .45848 m
.65072 .46343 L
s
.58422 .46006 m
.58765 .46379 L
s
.71427 .47074 m
.71744 .47549 L
s
.77407 .46111 m
.77703 .46483 L
s
.74249 .46197 m
.74548 .46501 L
s
.68249 .4677 m
.68594 .47642 L
s
.51147 .62238 m
.51482 .69565 L
s
.546 .53315 m
.54963 .55126 L
s
.55617 .47078 m
.5597 .47761 L
s
.48029 .73824 m
.48407 .73474 L
s
.4407 .61786 m
.44473 .61225 L
s
.29578 .45244 m
.2999 .45665 L
s
.67911 .46029 m
.68249 .4677 L
s
.6124 .45355 m
.61578 .45787 L
s
.80251 .45404 m
.80541 .45789 L
s
.487 .64869 m
.49058 .65994 L
s
.64409 .45384 m
.64741 .45848 L
s
.46255 .67143 m
.46601 .68898 L
s
.55262 .46243 m
.55617 .47078 L
s
.71101 .4646 m
.71427 .47074 L
s
.58077 .45618 m
.58422 .46006 L
s
.6758 .45446 m
.67911 .46029 L
s
.52813 .48305 m
.53172 .49613 L
s
.52454 .48961 m
.52813 .48305 L
s
.47465 .57489 m
.4792 .52808 L
s
.77098 .45591 m
.77407 .46111 L
s
.54963 .55126 m
.55331 .57288 L
s
.7394 .45769 m
.74249 .46197 L
s
.54921 .47425 m
.55262 .46243 L
s
.29165 .44822 m
.29578 .45244 L
s
.4696 .69995 m
.47317 .71187 L
s
.46601 .68898 m
.4696 .69995 L
s
.7077 .45794 m
.71101 .4646 L
s
.60902 .44987 m
.6124 .45355 L
s
.47317 .71187 m
.47669 .72731 L
s
.64075 .44913 m
.64409 .45384 L
s
.79968 .45107 m
.80251 .45404 L
s
.67252 .44949 m
.6758 .45446 L
s
.52875 .59032 m
.5324 .63552 L
s
.45353 .60184 m
.45816 .56854 L
s
.57731 .45229 m
.58077 .45618 L
s
.7679 .451 m
.77098 .45591 L
s
.47669 .72731 m
.48029 .73824 L
s
.73625 .45262 m
.7394 .45769 L
s
.70439 .45153 m
.7077 .45794 L
s
.45886 .79607 m
.46292 .78431 L
s
.28749 .44397 m
.29165 .44822 L
s
.40617 .69223 m
.41257 .62852 L
s
.43692 .61315 m
.4407 .61786 L
s
.6374 .44434 m
.64075 .44913 L
s
.55331 .57288 m
.55699 .59353 L
s
.66923 .44463 m
.67252 .44949 L
s
.82833 .44448 m
.83128 .44936 L
s
.60561 .44562 m
.60902 .44987 L
s
.76485 .44653 m
.7679 .451 L
s
.79674 .44696 m
.79968 .45107 L
s
.70111 .44567 m
.70439 .45153 L
s
.57396 .457 m
.57731 .45229 L
s
.5679 .63394 m
.57133 .63254 L
s
.73305 .4472 m
.73625 .45262 L
s
.49977 .53052 m
.50355 .52116 L
s
.28331 .4397 m
.28749 .44397 L
s
.43318 .60646 m
.43692 .61315 L
s
.50115 .71444 m
.50409 .82619 L
s
.63405 .44013 m
.6374 .44434 L
s
.52087 .51932 m
.52454 .48961 L
s
.66592 .43973 m
.66923 .44463 L
s
.82552 .44102 m
.82833 .44448 L
s
.60221 .44219 m
.60561 .44562 L
s
.69785 .44038 m
.70111 .44567 L
s
.76177 .44182 m
.76485 .44653 L
s
.55699 .59353 m
.56068 .61175 L
s
.79369 .44191 m
.79674 .44696 L
s
.72985 .44178 m
.73305 .4472 L
s
.42899 .61397 m
.43318 .60646 L
s
.42657 .68547 m
.42893 .73873 L
s
.27912 .43541 m
.28331 .4397 L
s
.66263 .43537 m
.66592 .43973 L
s
.6307 .43634 m
.63405 .44013 L
s
.54575 .48704 m
.54921 .47425 L
s
.69461 .43552 m
.69785 .44038 L
s
.8545 .43587 m
.85737 .44048 L
s
.82267 .43732 m
.82552 .44102 L
s
.56433 .62611 m
.5679 .63394 L
s
.72665 .43658 m
.72985 .44178 L
s
.75865 .4369 m
.76177 .44182 L
s
.59888 .44268 m
.60221 .44219 L
s
.79063 .4368 m
.79369 .44191 L
s
.56068 .61175 m
.56433 .62611 L
s
.45485 .80281 m
.45886 .79607 L
s
.5706 .46263 m
.57396 .457 L
s
.2749 .4311 m
.27912 .43541 L
s
.65934 .43137 m
.66263 .43537 L
s
.69137 .43109 m
.69461 .43552 L
s
.85164 .43151 m
.8545 .43587 L
s
.62733 .43224 m
.6307 .43634 L
s
.72345 .43159 m
.72665 .43658 L
s
.78759 .43201 m
.79063 .4368 L
s
.75553 .43201 m
.75865 .4369 L
s
.81972 .43281 m
.82267 .43732 L
s
.49584 .55032 m
.49977 .53052 L
s
.27067 .42677 m
.2749 .4311 L
s
.68813 .42678 m
.69137 .43109 L
s
.5324 .63552 m
.53613 .68104 L
s
.59558 .44535 m
.59888 .44268 L
s
.65603 .42712 m
.65934 .43137 L
s
.8809 .42711 m
.88367 .43132 L
s
.72026 .42689 m
.72345 .43159 L
s
.84884 .42771 m
.85164 .43151 L
s
.75241 .42724 m
.75553 .43201 L
s
.4241 .6417 m
.42899 .61397 L
s
.62403 .43089 m
.62733 .43224 L
s
.78454 .4273 m
.78759 .43201 L
s
.81672 .42781 m
.81972 .43281 L
s
.26641 .42242 m
.27067 .42677 L
s
.68487 .42239 m
.68813 .42678 L
s
.71707 .42242 m
.72026 .42689 L
s
.6527 .42294 m
.65603 .42712 L
s
.74928 .42259 m
.75241 .42724 L
s
.45088 .80632 m
.45485 .80281 L
s
.87808 .42258 m
.8809 .42711 L
s
.78148 .42261 m
.78454 .4273 L
s
.84597 .42344 m
.84884 .42771 L
s
.81371 .42286 m
.81672 .42781 L
s
.56716 .4662 m
.5706 .46263 L
s
.54219 .49115 m
.54575 .48704 L
s
.44915 .62056 m
.45353 .60184 L
s
.62077 .43136 m
.62403 .43089 L
s
.4347 .44295 m
.43584 .53877 L
s
.42743 .54382 m
.4347 .44295 L
s
.26214 .41805 m
.26641 .42242 L
s
.51482 .69565 m
.51828 .78335 L
s
.55102 .75518 m
.5543 .71876 L
s
.6816 .41808 m
.68487 .42239 L
s
.59225 .44828 m
.59558 .44535 L
s
.71386 .41792 m
.71707 .42242 L
s
.90754 .41808 m
.91025 .42232 L
s
.74614 .41804 m
.74928 .42259 L
s
.77842 .41803 m
.78148 .42261 L
s
.87529 .41835 m
.87808 .42258 L
s
.64942 .42025 m
.6527 .42294 L
s
.81071 .41815 m
.81371 .42286 L
s
.84305 .41875 m
.84597 .42344 L
s
.47001 .61865 m
.47465 .57489 L
s
.51713 .53698 m
.52087 .51932 L
s
.25784 .41366 m
.26214 .41805 L
s
.44687 .80948 m
.45088 .80632 L
s
.71064 .41344 m
.71386 .41792 L
s
.67831 .41377 m
.6816 .41808 L
s
.743 .41354 m
.74614 .41804 L
s
.77535 .41353 m
.77842 .41803 L
s
.8077 .41354 m
.81071 .41815 L
s
.90479 .41374 m
.90754 .41808 L
s
.42893 .73873 m
.4318 .77736 L
s
.87248 .41409 m
.87529 .41835 L
s
.8401 .41393 m
.84305 .41875 L
s
.6175 .43249 m
.62077 .43136 L
s
.64618 .4192 m
.64942 .42025 L
s
.56373 .47255 m
.56716 .4662 L
s
.53859 .49352 m
.54219 .49115 L
s
.49164 .58716 m
.49584 .55032 L
s
.25352 .40924 m
.25784 .41366 L
s
.70742 .40917 m
.71064 .41344 L
s
.73984 .40902 m
.743 .41354 L
s
.77227 .40905 m
.77535 .41353 L
s
.8047 .409 m
.8077 .41354 L
s
.67506 .41042 m
.67831 .41377 L
s
.58892 .45261 m
.59225 .44828 L
s
.90203 .40927 m
.90479 .41374 L
s
.83715 .4092 m
.8401 .41393 L
s
.86962 .40956 m
.87248 .41409 L
s
.53613 .68104 m
.53992 .72086 L
s
.64294 .41848 m
.64618 .4192 L
s
.44285 .81219 m
.44687 .80948 L
s
.24919 .40481 m
.25352 .40924 L
s
.73668 .40459 m
.73984 .40902 L
s
.80168 .40452 m
.8047 .409 L
s
.76918 .40457 m
.77227 .40905 L
s
.70418 .40471 m
.70742 .40917 L
s
.8342 .4046 m
.83715 .4092 L
s
.61421 .43388 m
.6175 .43249 L
s
.89926 .40487 m
.90203 .40927 L
s
.86675 .4049 m
.86962 .40956 L
s
.67184 .40813 m
.67506 .41042 L
s
.41878 .67912 m
.4241 .6417 L
s
.53497 .50199 m
.53859 .49352 L
s
.44475 .63727 m
.44915 .62056 L
s
.56027 .48065 m
.56373 .47255 L
s
.24483 .40035 m
.24919 .40481 L
s
.4 .74515 m
.40617 .69223 L
s
.7335 .40016 m
.73668 .40459 L
s
.79866 .40005 m
.80168 .40452 L
s
.76608 .40007 m
.76918 .40457 L
s
.70096 .40091 m
.70418 .40471 L
s
.83125 .40007 m
.8342 .4046 L
s
.86385 .40023 m
.86675 .4049 L
s
.89646 .40037 m
.89926 .40487 L
s
.58556 .45723 m
.58892 .45261 L
s
.63966 .41746 m
.64294 .41848 L
s
.66862 .40604 m
.67184 .40813 L
s
.4318 .77736 m
.43516 .80073 L
s
.43889 .81093 m
.44285 .81219 L
s
.51339 .5359 m
.51713 .53698 L
s
.61087 .43437 m
.61421 .43388 L
s
.24045 .39588 m
.24483 .40035 L
s
.76296 .3956 m
.76608 .40007 L
s
.79562 .39557 m
.79866 .40005 L
s
.7303 .39568 m
.7335 .40016 L
s
.82829 .39556 m
.83125 .40007 L
s
.86096 .39562 m
.86385 .40023 L
s
.89365 .39577 m
.89646 .40037 L
s
.69776 .39778 m
.70096 .40091 L
s
.63633 .41578 m
.63966 .41746 L
s
.66536 .40374 m
.66862 .40604 L
s
.43516 .80073 m
.43889 .81093 L
s
.46966 .49931 m
.47277 .54413 L
s
.46552 .50981 m
.46966 .49931 L
s
.23604 .39138 m
.24045 .39588 L
s
.75983 .39111 m
.76296 .3956 L
s
.79257 .39106 m
.79562 .39557 L
s
.72712 .39155 m
.7303 .39568 L
s
.82531 .39105 m
.82829 .39556 L
s
.85806 .39106 m
.86096 .39562 L
s
.89082 .39116 m
.89365 .39577 L
s
.54745 .76479 m
.55102 .75518 L
s
.53992 .72086 m
.54372 .75069 L
s
.50966 .53039 m
.51339 .5359 L
s
.5313 .50905 m
.53497 .50199 L
s
.69456 .39482 m
.69776 .39778 L
s
.58212 .45936 m
.58556 .45723 L
s
.55676 .48805 m
.56027 .48065 L
s
.60741 .43199 m
.61087 .43437 L
s
.53806 .41242 m
.54188 .44676 L
s
.53443 .43011 m
.53806 .41242 L
s
.23162 .38685 m
.23604 .39138 L
s
.50589 .52862 m
.50966 .53039 L
s
.7895 .38655 m
.79257 .39106 L
s
.75668 .3866 m
.75983 .39111 L
s
.82232 .38652 m
.82531 .39105 L
s
.85515 .38652 m
.85806 .39106 L
s
.88798 .38655 m
.89082 .39116 L
s
.72395 .38789 m
.72712 .39155 L
s
.66209 .40165 m
.66536 .40374 L
s
.63295 .41305 m
.63633 .41578 L
s
.50532 .41607 m
.50882 .46286 L
s
.5014 .42943 m
.50532 .41607 L
s
.43975 .67325 m
.44475 .63727 L
s
.69134 .39193 m
.69456 .39482 L
s
.50409 .82619 m
.50716 .95377 L
s
.60383 .42546 m
.60741 .43199 L
s
.46541 .65289 m
.47001 .61865 L
s
.22718 .38231 m
.23162 .38685 L
s
.78642 .38201 m
.7895 .38655 L
s
.75353 .38227 m
.75668 .3866 L
s
.81932 .38197 m
.82232 .38652 L
s
.85222 .38196 m
.85515 .38652 L
s
.88513 .38196 m
.88798 .38655 L
s
.72077 .38436 m
.72395 .38789 L
s
.50212 .52292 m
.50589 .52862 L
s
.57095 .42404 m
.57479 .4432 L
s
.56729 .41686 m
.57095 .42404 L
s
.48734 .62157 m
.49164 .58716 L
s
.57854 .45566 m
.58212 .45936 L
s
.62952 .40975 m
.63295 .41305 L
s
.6588 .3995 m
.66209 .40165 L
s
.54372 .75069 m
.54745 .76479 L
s
.60021 .41775 m
.60383 .42546 L
s
.68813 .38947 m
.69134 .39193 L
s
.52758 .51737 m
.5313 .50905 L
s
.43201 .4048 m
.43347 .48947 L
s
.42652 .44537 m
.43201 .4048 L
s
.46045 .56084 m
.46552 .50981 L
s
.22271 .37774 m
.22718 .38231 L
s
.56386 .42789 m
.56729 .41686 L
s
.78332 .37744 m
.78642 .38201 L
s
.8163 .37741 m
.81932 .38197 L
s
.84929 .37739 m
.85222 .38196 L
s
.88227 .37738 m
.88513 .38196 L
s
.7504 .37824 m
.75353 .38227 L
s
.59671 .41556 m
.60021 .41775 L
s
.49826 .52603 m
.50212 .52292 L
s
.55318 .49297 m
.55676 .48805 L
s
.46857 .41895 m
.47149 .47454 L
s
.46442 .42732 m
.46857 .41895 L
s
.71759 .38104 m
.72077 .38436 L
s
.57479 .4432 m
.57854 .45566 L
s
.62611 .40744 m
.62952 .40975 L
s
.51828 .78335 m
.52192 .86346 L
s
.41346 .71273 m
.41878 .67912 L
s
.65547 .39695 m
.6588 .3995 L
s
.54188 .44676 m
.54573 .47591 L
s
.21822 .37316 m
.22271 .37774 L
s
.78022 .37298 m
.78332 .37744 L
s
.81327 .37282 m
.8163 .37741 L
s
.84633 .37279 m
.84929 .37739 L
s
.8794 .37278 m
.88227 .37738 L
s
.68488 .38677 m
.68813 .38947 L
s
.74726 .37434 m
.7504 .37824 L
s
.47277 .54413 m
.47601 .58657 L
s
.59325 .4159 m
.59671 .41556 L
s
.71441 .3779 m
.71759 .38104 L
s
.49726 .45771 m
.5014 .42943 L
s
.53074 .44847 m
.53443 .43011 L
s
.62265 .40446 m
.62611 .40744 L
s
.21371 .36855 m
.21822 .37316 L
s
.81022 .36821 m
.81327 .37282 L
s
.84337 .36818 m
.84633 .37279 L
s
.87651 .36816 m
.8794 .37278 L
s
.77712 .3687 m
.78022 .37298 L
s
.65207 .39325 m
.65547 .39695 L
s
.49422 .54264 m
.49826 .52603 L
s
.53338 .9131 m
.53698 .8543 L
s
.74411 .37058 m
.74726 .37434 L
s
.43584 .53877 m
.43671 .65226 L
s
.68157 .38312 m
.68488 .38677 L
s
.54951 .49059 m
.55318 .49297 L
s
.52382 .52681 m
.52758 .51737 L
s
.71118 .37438 m
.71441 .3779 L
s
.20918 .36391 m
.21371 .36855 L
s
.45952 .46687 m
.46442 .42732 L
s
.80717 .36365 m
.81022 .36821 L
s
.84039 .36355 m
.84337 .36818 L
s
.87362 .36353 m
.87651 .36816 L
s
.50882 .46286 m
.51246 .49864 L
s
.77401 .36452 m
.77712 .3687 L
s
.58964 .411 m
.59325 .4159 L
s
.56027 .43073 m
.56386 .42789 L
s
.61903 .39686 m
.62265 .40446 L
s
.39434 .78108 m
.4 .74515 L
s
.64852 .38632 m
.65207 .39325 L
s
.54573 .47591 m
.54951 .49059 L
s
.74095 .36686 m
.74411 .37058 L
s
.67813 .3775 m
.68157 .38312 L
s
.39107 .51395 m
.39002 .63701 L
s
.38682 .51276 m
.39107 .51395 L
s
.61526 .38475 m
.61903 .39686 L
s
.61151 .37332 m
.61526 .38475 L
s
.60813 .37511 m
.61151 .37332 L
s
.58207 .38519 m
.58589 .39974 L
s
.57835 .3753 m
.58207 .38519 L
s
.54511 .37363 m
.54893 .3929 L
s
.54143 .37643 m
.54511 .37363 L
s
.70787 .36984 m
.71118 .37438 L
s
.64481 .37574 m
.64852 .38632 L
s
.20463 .35926 m
.20918 .36391 L
s
.57485 .37922 m
.57835 .3753 L
s
.5119 .37569 m
.51561 .40145 L
s
.50794 .39612 m
.5119 .37569 L
s
.83739 .35889 m
.84039 .36355 L
s
.8707 .35887 m
.87362 .36353 L
s
.80411 .35919 m
.80717 .36365 L
s
.58589 .39974 m
.58964 .411 L
s
.64123 .36872 m
.64481 .37574 L
s
.7709 .36042 m
.77401 .36452 L
s
.32373 .41296 m
.32746 .42525 L
s
.31606 .45645 m
.32373 .41296 L
s
.67457 .36978 m
.67813 .3775 L
s
.32746 .42525 m
.3302 .45245 L
s
.43413 .72661 m
.43975 .67325 L
s
.73775 .36281 m
.74095 .36686 L
s
.63795 .3696 m
.64123 .36872 L
s
.54893 .3929 m
.55271 .40569 L
s
.6711 .36401 m
.67457 .36978 L
s
.46066 .68925 m
.46541 .65289 L
s
.70448 .36418 m
.70787 .36984 L
s
.55271 .40569 m
.55651 .41999 L
s
.20005 .35458 m
.20463 .35926 L
s
.37867 .59321 m
.38682 .51276 L
s
.83439 .35425 m
.83739 .35889 L
s
.86778 .35419 m
.8707 .35887 L
s
.80105 .35481 m
.80411 .35919 L
s
.429 1.00478 m
.43398 .97299 L
s
.55651 .41999 m
.56027 .43073 L
s
.76777 .35632 m
.7709 .36042 L
s
.52001 .52939 m
.52382 .52681 L
s
.48325 .63321 m
.48734 .62157 L
s
.47601 .58657 m
.47949 .61828 L
s
.73449 .3582 m
.73775 .36281 L
s
.60467 .37512 m
.60813 .37511 L
s
.37278 .68262 m
.37611 .70407 L
s
.36869 .67714 m
.37278 .68262 L
s
.48604 .41142 m
.48971 .43154 L
s
.48185 .42696 m
.48604 .41142 L
s
.6678 .36188 m
.6711 .36401 L
s
.70111 .35907 m
.70448 .36418 L
s
.53771 .38008 m
.54143 .37643 L
s
.49016 .55463 m
.49422 .54264 L
s
.52696 .44563 m
.53074 .44847 L
s
.19545 .34987 m
.20005 .35458 L
s
.51561 .40145 m
.51939 .41672 L
s
.42087 .61441 m
.42743 .54382 L
s
.86483 .34948 m
.86778 .35419 L
s
.83138 .34967 m
.83439 .35425 L
s
.79797 .35046 m
.80105 .35481 L
s
.57123 .37832 m
.57485 .37922 L
s
.47149 .47454 m
.47474 .51759 L
s
.76462 .35208 m
.76777 .35632 L
s
.51246 .49864 m
.51621 .51994 L
s
.3302 .45245 m
.3328 .48269 L
s
.36396 .68406 m
.36869 .67714 L
s
.51939 .41672 m
.52317 .42925 L
s
.40849 .73359 m
.41346 .71273 L
s
.63447 .36585 m
.63795 .3696 L
s
.52317 .42925 m
.52696 .44563 L
s
.73122 .35351 m
.73449 .3582 L
s
.69778 .355 m
.70111 .35907 L
s
.48971 .43154 m
.49334 .45764 L
s
.37611 .70407 m
.37898 .73604 L
s
.19082 .34515 m
.19545 .34987 L
s
.86188 .34478 m
.86483 .34948 L
s
.82836 .34513 m
.83138 .34967 L
s
.66434 .35693 m
.6678 .36188 L
s
.42089 .48601 m
.42652 .44537 L
s
.79489 .34615 m
.79797 .35046 L
s
.49334 .45764 m
.49726 .45771 L
s
.60101 .36816 m
.60467 .37512 L
s
.51621 .51994 m
.52001 .52939 L
s
.76143 .34763 m
.76462 .35208 L
s
.56363 .35353 m
.56745 .36722 L
s
.55996 .35303 m
.56363 .35353 L
s
.72793 .34895 m
.73122 .35351 L
s
.32334 .65071 m
.32711 .66298 L
s
.31908 .64594 m
.32334 .65071 L
s
.63079 .35712 m
.63447 .36585 L
s
.32711 .66298 m
.33025 .68552 L
s
.56745 .36722 m
.57123 .37832 L
s
.69436 .34945 m
.69778 .355 L
s
.53394 .37866 m
.53771 .38008 L
s
.59725 .35796 m
.60101 .36816 L
s
.18618 .3404 m
.19082 .34515 L
s
.47949 .61828 m
.48325 .63321 L
s
.66072 .34889 m
.66434 .35693 L
s
.85892 .3401 m
.86188 .34478 L
s
.62714 .34946 m
.63079 .35712 L
s
.82532 .34062 m
.82836 .34513 L
s
.59351 .34859 m
.59725 .35796 L
s
.79178 .34178 m
.79489 .34615 L
s
.45565 .59294 m
.46045 .56084 L
s
.75822 .34303 m
.76143 .34763 L
s
.31452 .64537 m
.31908 .64594 L
s
.5039 .4149 m
.50794 .39612 L
s
.58987 .34408 m
.59351 .34859 L
s
.65718 .3427 m
.66072 .34889 L
s
.72456 .34336 m
.72793 .34895 L
s
.62349 .34238 m
.62714 .34946 L
s
.69082 .3423 m
.69436 .34945 L
s
.35898 .69453 m
.36396 .68406 L
s
.3328 .48269 m
.33337 .54596 L
s
.52192 .86346 m
.52572 .91787 L
s
.18151 .33562 m
.18618 .3404 L
s
.33025 .68552 m
.33274 .71954 L
s
.48613 .55973 m
.49016 .55463 L
s
.38941 .79623 m
.39434 .78108 L
s
.85594 .33545 m
.85892 .3401 L
s
.82228 .33615 m
.82532 .34062 L
s
.5563 .35527 m
.55996 .35303 L
s
.78865 .33724 m
.79178 .34178 L
s
.61996 .33898 m
.62349 .34238 L
s
.68742 .33766 m
.69082 .3423 L
s
.37898 .73604 m
.38191 .76821 L
s
.65373 .33907 m
.65718 .3427 L
s
.53015 .38098 m
.53394 .37866 L
s
.75494 .33782 m
.75822 .34303 L
s
.47773 .43351 m
.48185 .42696 L
s
.72111 .33676 m
.72456 .34336 L
s
.58637 .34733 m
.58987 .34408 L
s
.43347 .48947 m
.43559 .55906 L
s
.30983 .64607 m
.31452 .64537 L
s
.17682 .33083 m
.18151 .33562 L
s
.45483 .49175 m
.45952 .46687 L
s
.47033 .39543 m
.47395 .41835 L
s
.46631 .3928 m
.47033 .39543 L
s
.85296 .33081 m
.85594 .33545 L
s
.42379 1.04143 m
.429 1.00478 L
s
.81923 .33162 m
.82228 .33615 L
s
.71781 .33249 m
.72111 .33676 L
s
.78546 .33234 m
.78865 .33724 L
s
.68407 .3342 m
.68742 .33766 L
s
.75159 .33181 m
.75494 .33782 L
s
.47474 .51759 m
.4783 .54665 L
s
.61637 .33443 m
.61996 .33898 L
s
.40392 .7416 m
.40849 .73359 L
s
.65026 .33515 m
.65373 .33907 L
s
.52958 .93587 m
.53338 .9131 L
s
.1721 .32601 m
.17682 .33083 L
s
.45555 .73606 m
.46066 .68925 L
s
.84997 .32619 m
.85296 .33081 L
s
.5526 .35783 m
.5563 .35527 L
s
.81613 .3269 m
.81923 .33162 L
s
.74832 .32703 m
.75159 .33181 L
s
.48212 .55997 m
.48613 .55973 L
s
.78222 .32693 m
.78546 .33234 L
s
.71451 .32856 m
.71781 .33249 L
s
.46203 .40148 m
.46631 .3928 L
s
.52632 .38193 m
.53015 .38098 L
s
.30518 .64585 m
.30983 .64607 L
s
.47395 .41835 m
.47773 .43351 L
s
.68062 .32924 m
.68407 .3342 L
s
.61275 .32931 m
.61637 .33443 L
s
.35413 .7016 m
.35898 .69453 L
s
.64664 .32843 m
.65026 .33515 L
s
.58278 .34748 m
.58637 .34733 L
s
.33274 .71954 m
.33463 .76467 L
s
.30729 .5127 m
.31606 .45645 L
s
.38191 .76821 m
.3853 .79066 L
s
.41061 .54139 m
.41295 .59444 L
s
.40592 .5512 m
.41061 .54139 L
s
.16736 .32116 m
.1721 .32601 L
s
.84695 .32151 m
.84997 .32619 L
s
.34209 .4352 m
.34503 .46194 L
s
.33251 .5129 m
.34209 .4352 L
s
.779 .32182 m
.78222 .32693 L
s
.813 .32187 m
.81613 .3269 L
s
.74508 .32281 m
.74832 .32703 L
s
.3853 .79066 m
.38941 .79623 L
s
.643 .3212 m
.64664 .32843 L
s
.71108 .32297 m
.71451 .32856 L
s
.51007 1.05246 m
.50716 .95377 L
s
.60923 .32842 m
.61275 .32931 L
s
.67706 .32266 m
.68062 .32924 L
s
.4283 .7815 m
.43413 .72661 L
s
.4783 .54665 m
.48212 .55997 L
s
.37197 .4267 m
.37568 .44131 L
s
.36689 .43757 m
.37197 .4267 L
s
.49989 .421 m
.5039 .4149 L
s
.51478 .34363 m
.51862 .35643 L
s
.51088 .34179 m
.51478 .34363 L
s
.51862 .35643 m
.52246 .37397 L
s
.1626 .31629 m
.16736 .32116 L
s
.39943 .74602 m
.40392 .7416 L
s
.37568 .44131 m
.37658 .51299 L
s
.30065 .64336 m
.30518 .64585 L
s
.63955 .31917 m
.643 .3212 L
s
.54885 .35777 m
.5526 .35783 L
s
.52246 .37397 m
.52632 .38193 L
s
.84391 .31668 m
.84695 .32151 L
s
.7758 .31722 m
.779 .32182 L
s
.80984 .3168 m
.813 .32187 L
s
.6735 .31629 m
.67706 .32266 L
s
.74172 .31727 m
.74508 .32281 L
s
.70762 .317 m
.71108 .32297 L
s
.57908 .34396 m
.58278 .34748 L
s
.4807 .35148 m
.48446 .3698 L
s
.47682 .34062 m
.4807 .35148 L
s
.52572 .91787 m
.52958 .93587 L
s
.45148 .59387 m
.45565 .59294 L
s
.34948 .70408 m
.35413 .7016 L
s
.15781 .31139 m
.1626 .31629 L
s
.47286 .33391 m
.47682 .34062 L
s
.60562 .32518 m
.60923 .32842 L
s
.67005 .31227 m
.6735 .31629 L
s
.4241 .38937 m
.42775 .40749 L
s
.42003 .38326 m
.4241 .38937 L
s
.45787 .40205 m
.46203 .40148 L
s
.34503 .46194 m
.34472 .54428 L
s
.41595 .50346 m
.42089 .48601 L
s
.39774 .41378 m
.40002 .4629 L
s
.39253 .4315 m
.39774 .41378 L
s
.84084 .31172 m
.84391 .31668 L
s
.8067 .31192 m
.80984 .3168 L
s
.7042 .31186 m
.70762 .317 L
s
.29628 .63831 m
.30065 .64336 L
s
.77253 .31189 m
.7758 .31722 L
s
.73835 .31174 m
.74172 .31727 L
s
.50698 .33536 m
.51088 .34179 L
s
.6361 .31772 m
.63955 .31917 L
s
.57532 .33762 m
.57908 .34396 L
s
.48446 .3698 m
.48822 .38972 L
s
.39851 .62628 m
.40592 .5512 L
s
.54504 .35405 m
.54885 .35777 L
s
.4687 .33656 m
.47286 .33391 L
s
.45031 .37086 m
.45407 .38721 L
s
.44615 .36914 m
.45031 .37086 L
s
.45033 .50491 m
.45483 .49175 L
s
.41542 .39049 m
.42003 .38326 L
s
.42775 .40749 m
.4307 .44815 L
s
.15299 .30647 m
.15781 .31139 L
s
.3946 .75793 m
.39943 .74602 L
s
.50308 .32696 m
.50698 .33536 L
s
.29201 .6317 m
.29628 .63831 L
s
.73503 .30711 m
.73835 .31174 L
s
.70078 .30702 m
.7042 .31186 L
s
.49593 .41767 m
.49989 .421 L
s
.83776 .30678 m
.84084 .31172 L
s
.76924 .30662 m
.77253 .31189 L
s
.8035 .3067 m
.8067 .31192 L
s
.6666 .30856 m
.67005 .31227 L
s
.60194 .32038 m
.60562 .32518 L
s
.43671 .65226 m
.43846 .74301 L
s
.5715 .32906 m
.57532 .33762 L
s
.45407 .38721 m
.45787 .40205 L
s
.49915 .32115 m
.50308 .32696 L
s
.42087 1.06352 m
.42379 1.04143 L
s
.44758 .58304 m
.45148 .59387 L
s
.33337 .54596 m
.33164 .64926 L
s
.36036 .47328 m
.36689 .43757 L
s
.34483 .70566 m
.34948 .70408 L
s
.33463 .76467 m
.33608 .81942 L
s
.44332 .58531 m
.44758 .58304 L
s
.28771 .62522 m
.29201 .6317 L
s
.53341 .31657 m
.53729 .32983 L
s
.52954 .30848 m
.53341 .31657 L
s
.48822 .38972 m
.49204 .40665 L
s
.56765 .31833 m
.5715 .32906 L
s
.53729 .32983 m
.54118 .3445 L
s
.54118 .3445 m
.54504 .35405 L
s
.63257 .3148 m
.6361 .31772 L
s
.14816 .30153 m
.15299 .30647 L
s
.56383 .31038 m
.56765 .31833 L
s
.766 .302 m
.76924 .30662 L
s
.80029 .3015 m
.8035 .3067 L
s
.83464 .30164 m
.83776 .30678 L
s
.69731 .30167 m
.70078 .30702 L
s
.73168 .3022 m
.73503 .30711 L
s
.59827 .31647 m
.60194 .32038 L
s
.44212 .36225 m
.44615 .36914 L
s
.52566 .30484 m
.52954 .30848 L
s
.49204 .40665 m
.49593 .41767 L
s
.66312 .3047 m
.6666 .30856 L
s
.4952 .31589 m
.49915 .32115 L
s
.28328 .6202 m
.28771 .62522 L
s
.56002 .30451 m
.56383 .31038 L
s
.41598 .63115 m
.42087 .61441 L
s
.46425 .35033 m
.4687 .33656 L
s
.1433 .29656 m
.14816 .30153 L
s
.43814 .35313 m
.44212 .36225 L
s
.37115 .65545 m
.37867 .59321 L
s
.79712 .29681 m
.80029 .3015 L
s
.69388 .29724 m
.69731 .30167 L
s
.8315 .29638 m
.83464 .30164 L
s
.76271 .297 m
.766 .302 L
s
.30475 .36344 m
.30269 .45469 L
s
.29825 .38454 m
.30475 .36344 L
s
.72827 .29669 m
.73168 .3022 L
s
.41295 .59444 m
.41598 .63115 L
s
.62893 .30958 m
.63257 .3148 L
s
.43559 .55906 m
.43899 .58869 L
s
.49115 .31659 m
.4952 .31589 L
s
.27868 .61703 m
.28328 .6202 L
s
.33992 .71122 m
.34483 .70566 L
s
.43377 .35595 m
.43814 .35313 L
s
.59454 .31106 m
.59827 .31647 L
s
.55619 .29822 m
.56002 .30451 L
s
.52175 .30483 m
.52566 .30484 L
s
.65961 .30053 m
.66312 .3047 L
s
.40965 .42589 m
.41542 .39049 L
s
.43899 .58869 m
.44332 .58531 L
s
.38923 .78139 m
.3946 .75793 L
s
.39002 .63701 m
.38872 .77326 L
s
.13841 .29156 m
.1433 .29656 L
s
.41107 .5173 m
.41595 .50346 L
s
.8284 .29159 m
.8315 .29638 L
s
.72486 .29148 m
.72827 .29669 L
s
.7939 .29171 m
.79712 .29681 L
s
.38671 .46029 m
.39253 .4315 L
s
.75938 .29156 m
.76271 .297 L
s
.45027 .78395 m
.45555 .73606 L
s
.69048 .29364 m
.69388 .29724 L
s
.62521 .30259 m
.62893 .30958 L
s
.44608 .50573 m
.45033 .50491 L
s
.55236 .29377 m
.55619 .29822 L
s
.59072 .30259 m
.59454 .31106 L
s
.27394 .6152 m
.27868 .61703 L
s
.65603 .29532 m
.65961 .30053 L
s
.4307 .44815 m
.43375 .48812 L
s
.58689 .29355 m
.59072 .30259 L
s
.62146 .29488 m
.62521 .30259 L
s
.1335 .28654 m
.13841 .29156 L
s
.7215 .28711 m
.72486 .29148 L
s
.40002 .4629 m
.40235 .51372 L
s
.75603 .28627 m
.75938 .29156 L
s
.82525 .2865 m
.8284 .29159 L
s
.79064 .2864 m
.7939 .29171 L
s
.487 .32168 m
.49115 .31659 L
s
.51779 .30704 m
.52175 .30483 L
s
.58309 .28677 m
.58689 .29355 L
s
.54852 .29051 m
.55236 .29377 L
s
.68703 .28952 m
.69048 .29364 L
s
.42921 .36295 m
.43377 .35595 L
s
.61772 .28793 m
.62146 .29488 L
s
.33458 .72314 m
.33992 .71122 L
s
.65242 .28983 m
.65603 .29532 L
s
.26914 .61374 m
.27394 .6152 L
s
.44186 .50461 m
.44608 .50573 L
s
.12856 .28149 m
.1335 .28654 L
s
.75271 .28134 m
.75603 .28627 L
s
.78739 .28132 m
.79064 .2864 L
s
.57933 .28288 m
.58309 .28677 L
s
.82207 .28124 m
.82525 .2865 L
s
.71813 .28288 m
.7215 .28711 L
s
.614 .28198 m
.61772 .28793 L
s
.45983 .35996 m
.46425 .35033 L
s
.68353 .28476 m
.68703 .28952 L
s
.6488 .28466 m
.65242 .28983 L
s
.54467 .28851 m
.54852 .29051 L
s
.42249 .83 m
.4283 .7815 L
s
.29834 .56846 m
.30729 .5127 L
s
.33608 .81942 m
.33722 .88168 L
s
.37658 .51299 m
.37611 .61692 L
s
.1236 .27642 m
.12856 .28149 L
s
.74937 .27638 m
.75271 .28134 L
s
.81891 .27625 m
.82207 .28124 L
s
.78413 .27621 m
.78739 .28132 L
s
.26436 .61165 m
.26914 .61374 L
s
.61027 .27625 m
.614 .28198 L
s
.51381 .30776 m
.51779 .30704 L
s
.57555 .27936 m
.57933 .28288 L
s
.71471 .27812 m
.71813 .28288 L
s
.43755 .50514 m
.44186 .50461 L
s
.36784 .38212 m
.37152 .39914 L
s
.36128 .41674 m
.36784 .38212 L
s
.40619 .52912 m
.41107 .5173 L
s
.48277 .32919 m
.487 .32168 L
s
.64513 .27855 m
.6488 .28466 L
s
.67997 .27913 m
.68353 .28476 L
s
.28391 .50185 m
.29825 .38454 L
s
.11861 .27132 m
.1236 .27642 L
s
.37152 .39914 m
.37465 .42706 L
s
.35208 .5372 m
.36036 .47328 L
s
.5408 .28963 m
.54467 .28851 L
s
.60656 .27206 m
.61027 .27625 L
s
.78083 .27095 m
.78413 .27621 L
s
.42429 .37867 m
.42921 .36295 L
s
.81571 .27111 m
.81891 .27625 L
s
.38341 .8128 m
.38923 .78139 L
s
.74604 .27185 m
.74937 .27638 L
s
.71123 .27279 m
.71471 .27812 L
s
.43375 .48812 m
.43755 .50514 L
s
.64143 .27202 m
.64513 .27855 L
s
.25965 .60836 m
.26436 .61165 L
s
.67634 .27269 m
.67997 .27913 L
s
.57177 .27678 m
.57555 .27936 L
s
.32889 .73974 m
.33458 .72314 L
s
.38242 .33026 m
.38478 .37488 L
s
.37816 .32403 m
.38242 .33026 L
s
.32455 .36805 m
.32499 .43175 L
s
.31668 .41054 m
.32455 .36805 L
s
.44414 .30682 m
.44764 .33532 L
s
.44001 .30026 m
.44414 .30682 L
s
.11359 .2662 m
.11861 .27132 L
s
.50981 .30382 m
.51381 .30776 L
s
.77756 .26612 m
.78083 .27095 L
s
.81249 .26584 m
.81571 .27111 L
s
.40526 .29682 m
.40818 .33377 L
s
.40032 .30663 m
.40526 .29682 L
s
.74268 .26713 m
.74604 .27185 L
s
.60283 .26744 m
.60656 .27206 L
s
.63775 .26633 m
.64143 .27202 L
s
.34472 .54428 m
.3451 .61829 L
s
.67271 .26649 m
.67634 .27269 L
s
.70772 .26727 m
.71123 .27279 L
s
.45553 .36169 m
.45983 .35996 L
s
.37036 .38326 m
.37816 .32403 L
s
.25502 .60381 m
.25965 .60836 L
s
.38208 .46188 m
.38671 .46029 L
s
.43543 .30748 m
.44001 .30026 L
s
.56795 .27369 m
.57177 .27678 L
s
.53689 .2901 m
.5408 .28963 L
s
.40376 .46051 m
.40965 .42589 L
s
.32258 .59181 m
.33251 .5129 L
s
.10855 .26104 m
.11359 .2662 L
s
.37465 .42706 m
.37827 .44618 L
s
.40235 .51372 m
.40619 .52912 L
s
.80927 .26069 m
.81249 .26584 L
s
.77428 .26134 m
.77756 .26612 L
s
.63408 .26136 m
.63775 .26633 L
s
.50583 .29461 m
.50981 .30382 L
s
.66911 .261 m
.67271 .26649 L
s
.47852 .33387 m
.48277 .32919 L
s
.73928 .26205 m
.74268 .26713 L
s
.70421 .26189 m
.70772 .26727 L
s
.5991 .26394 m
.60283 .26744 L
s
.25045 .59835 m
.25502 .60381 L
s
.50183 .28683 m
.50583 .29461 L
s
.43846 .74301 m
.44132 .79861 L
s
.37827 .44618 m
.38208 .46188 L
s
.44764 .33532 m
.45142 .35474 L
s
.80604 .25561 m
.80927 .26069 L
s
.6655 .25569 m
.66911 .261 L
s
.56409 .26939 m
.56795 .27369 L
s
.6304 .25661 m
.63408 .26136 L
s
.77097 .25639 m
.77428 .26134 L
s
.49773 .28678 m
.50183 .28683 L
s
.70067 .25634 m
.70421 .26189 L
s
.45142 .35474 m
.45553 .36169 L
s
.73585 .25676 m
.73928 .26205 L
s
.44534 .81096 m
.45027 .78395 L
s
.24589 .59247 m
.25045 .59835 L
s
.59538 .26172 m
.5991 .26394 L
s
.53294 .28715 m
.53689 .2901 L
s
.46272 .27815 m
.46657 .29677 L
s
.45865 .26979 m
.46272 .27815 L
s
.39057 .70813 m
.39851 .62628 L
s
.41913 .39829 m
.42429 .37867 L
s
.32307 .75693 m
.32889 .73974 L
s
.66188 .25067 m
.6655 .25569 L
s
.8028 .2506 m
.80604 .25561 L
s
.24128 .58694 m
.24589 .59247 L
s
.69711 .25064 m
.70067 .25634 L
s
.3959 .30361 m
.40032 .30663 L
s
.76761 .2511 m
.77097 .25639 L
s
.62671 .25236 m
.6304 .25661 L
s
.56022 .26536 m
.56409 .26939 L
s
.73237 .25108 m
.73585 .25676 L
s
.36458 .69439 m
.37115 .65545 L
s
.45401 .28296 m
.45865 .26979 L
s
.43127 .30044 m
.43543 .30748 L
s
.40818 .33377 m
.41091 .37764 L
s
.33722 .88168 m
.33822 .94917 L
s
.47439 .32945 m
.47852 .33387 L
s
.46657 .29677 m
.47044 .31496 L
s
.59161 .25865 m
.59538 .26172 L
s
.49366 .28186 m
.49773 .28678 L
s
.52896 .28006 m
.53294 .28715 L
s
.23652 .58274 m
.24128 .58694 L
s
.38478 .37488 m
.3878 .4077 L
s
.33164 .64926 m
.32854 .77994 L
s
.42694 .29767 m
.43127 .30044 L
s
.65824 .2456 m
.66188 .25067 L
s
.69354 .24522 m
.69711 .25064 L
s
.79954 .24551 m
.8028 .2506 L
s
.72887 .24528 m
.73237 .25108 L
s
.76422 .24561 m
.76761 .2511 L
s
.37736 .84698 m
.38341 .8128 L
s
.62301 .24819 m
.62671 .25236 L
s
.47044 .31496 m
.47439 .32945 L
s
.55633 .26223 m
.56022 .26536 L
s
.39136 .30266 m
.3959 .30361 L
s
.52097 .25422 m
.52496 .26824 L
s
.51695 .24989 m
.52097 .25422 L
s
.35419 .4577 m
.36128 .41674 L
s
.4857 .25433 m
.48968 .26811 L
s
.48156 .25121 m
.4857 .25433 L
s
.30269 .45469 m
.30222 .5278 L
s
.52496 .26824 m
.52896 .28006 L
s
.41666 .87419 m
.42249 .83 L
s
.48968 .26811 m
.49366 .28186 L
s
.23154 .58056 m
.23652 .58274 L
s
.68998 .23997 m
.69354 .24522 L
s
.72538 .23986 m
.72887 .24528 L
s
.65462 .24116 m
.65824 .2456 L
s
.79625 .24027 m
.79954 .24551 L
s
.76082 .24017 m
.76422 .24561 L
s
.58778 .25362 m
.59161 .25865 L
s
.42226 .30344 m
.42694 .29767 L
s
.61929 .24413 m
.62301 .24819 L
s
.55238 .25648 m
.55633 .26223 L
s
.51291 .24523 m
.51695 .24989 L
s
.4773 .25249 m
.48156 .25121 L
s
.15892 .24012 m
.15345 .32493 L
s
.38534 .33077 m
.39136 .30266 L
s
.72188 .23454 m
.72538 .23986 L
s
.6864 .23486 m
.68998 .23997 L
s
.75741 .23474 m
.76082 .24017 L
s
.79293 .23493 m
.79625 .24027 L
s
.58387 .24597 m
.58778 .25362 L
s
.65099 .23708 m
.65462 .24116 L
s
.22633 .58044 m
.23154 .58056 L
s
.28905 .62582 m
.29834 .56846 L
s
.31728 .77233 m
.32307 .75693 L
s
.30092 .35631 m
.30491 .36915 L
s
.28805 .45417 m
.30092 .35631 L
s
.32499 .43175 m
.32133 .55938 L
s
.30491 .36915 m
.30605 .42001 L
s
.5484 .24761 m
.55238 .25648 L
s
.61555 .24001 m
.61929 .24413 L
s
.3878 .4077 m
.39111 .43568 L
s
.44948 .28909 m
.45401 .28296 L
s
.50883 .24199 m
.51291 .24523 L
s
.44132 .79861 m
.44534 .81096 L
s
.57994 .23815 m
.58387 .24597 L
s
.39878 .47028 m
.40376 .46051 L
s
.30991 .43548 m
.31668 .41054 L
s
.41452 .40116 m
.41913 .39829 L
s
.71837 .22926 m
.72188 .23454 L
s
.75397 .22924 m
.75741 .23474 L
s
.5444 .23805 m
.5484 .24761 L
s
.68281 .22992 m
.6864 .23486 L
s
.78959 .22945 m
.79293 .23493 L
s
.41033 .26203 m
.41401 .28305 L
s
.40494 .28095 m
.41033 .26203 L
s
.64732 .23248 m
.65099 .23708 L
s
.5404 .23124 m
.5444 .23805 L
s
.57606 .23334 m
.57994 .23815 L
s
.41091 .37764 m
.41452 .40116 L
s
.47295 .25673 m
.4773 .25249 L
s
.61176 .235 m
.61555 .24001 L
s
.22093 .58179 m
.22633 .58044 L
s
.41788 .30002 m
.42226 .30344 L
s
.3451 .61829 m
.34648 .67803 L
s
.1845 .22949 m
.18792 .24706 L
s
.50471 .24095 m
.50883 .24199 L
s
.71485 .224 m
.71837 .22926 L
s
.75053 .22382 m
.75397 .22924 L
s
.78623 .22388 m
.78959 .22945 L
s
.67922 .22518 m
.68281 .22992 L
s
.53641 .23025 m
.5404 .23124 L
s
.41401 .28305 m
.41788 .30002 L
s
.64358 .22687 m
.64732 .23248 L
s
.57212 .22663 m
.57606 .23334 L
s
.39111 .43568 m
.39471 .4581 L
s
.18792 .24706 m
.1888 .28597 L
s
.34257 .61797 m
.35208 .5372 L
s
.6079 .22834 m
.61176 .235 L
s
.74707 .21846 m
.75053 .22382 L
s
.78285 .21841 m
.78623 .22388 L
s
.71132 .21896 m
.71485 .224 L
s
.37611 .61692 m
.37625 .71347 L
s
.67561 .22054 m
.67922 .22518 L
s
.44512 .28749 m
.44948 .28909 L
s
.21498 .2264 m
.21826 .24584 L
s
.21036 .21875 m
.21498 .2264 L
s
.35857 .71962 m
.36458 .69439 L
s
.56816 .21937 m
.57212 .22663 L
s
.63981 .22096 m
.64358 .22687 L
s
.37108 .88321 m
.37736 .84698 L
s
.21542 .58367 m
.22093 .58179 L
s
.33899 1.00406 m
.33822 .94917 L
s
.31132 .78909 m
.31728 .77233 L
s
.5006 .23442 m
.50471 .24095 L
s
.60398 .22044 m
.6079 .22834 L
s
.38872 .77326 m
.38861 .88887 L
s
.39471 .4581 m
.39878 .47028 L
s
.53238 .22805 m
.53641 .23025 L
s
.36313 .42789 m
.37036 .38326 L
s
.46862 .25773 m
.47295 .25673 L
s
.77947 .213 m
.78285 .21841 L
s
.7436 .21313 m
.74707 .21846 L
s
.70778 .21402 m
.71132 .21896 L
s
.56422 .21477 m
.56816 .21937 L
s
.21826 .24584 m
.21984 .28117 L
s
.60008 .21359 m
.60398 .22044 L
s
.67197 .2156 m
.67561 .22054 L
s
.63605 .21562 m
.63981 .22096 L
s
.43302 .24712 m
.437 .26204 L
s
.42866 .24304 m
.43302 .24712 L
s
.32218 .34873 m
.32561 .37046 L
s
.31804 .33716 m
.32218 .34873 L
s
.49649 .22663 m
.5006 .23442 L
s
.31259 .34321 m
.31804 .33716 L
s
.437 .26204 m
.44097 .27777 L
s
.44097 .27777 m
.44512 .28749 L
s
.24548 .22514 m
.24834 .24973 L
s
.24128 .21379 m
.24548 .22514 L
s
.23649 .20789 m
.24128 .21379 L
s
.77608 .20758 m
.77947 .213 L
s
.74012 .20785 m
.7436 .21313 L
s
.59622 .2086 m
.60008 .21359 L
s
.41065 .91949 m
.41666 .87419 L
s
.49226 .22728 m
.49649 .22663 L
s
.7042 .20884 m
.70778 .21402 L
s
.20991 .58519 m
.21542 .58367 L
s
.56028 .21252 m
.56422 .21477 L
s
.52832 .22401 m
.53238 .22805 L
s
.63224 .20959 m
.63605 .21562 L
s
.66826 .20993 m
.67197 .2156 L
s
.34861 .47038 m
.35419 .4577 L
s
.37935 .35566 m
.38534 .33077 L
s
.30605 .42001 m
.30991 .43548 L
s
.39924 .3045 m
.40494 .28095 L
s
.42367 .255 m
.42866 .24304 L
s
.32561 .37046 m
.32787 .40976 L
s
.46441 .25111 m
.46862 .25773 L
s
.77267 .20216 m
.77608 .20758 L
s
.73663 .2027 m
.74012 .20785 L
s
.59234 .20392 m
.59622 .2086 L
s
.1888 .28597 m
.18828 .33744 L
s
.30222 .5278 m
.30325 .58283 L
s
.70059 .20341 m
.7042 .20884 L
s
.3145 .63868 m
.32258 .59181 L
s
.6284 .20305 m
.63224 .20959 L
s
.27221 .21051 m
.27585 .22807 L
s
.26769 .20251 m
.27221 .21051 L
s
.6645 .2034 m
.66826 .20993 L
s
.24834 .24973 m
.24979 .28915 L
s
.52424 .21671 m
.52832 .22401 L
s
.55631 .20938 m
.56028 .21252 L
s
.46029 .2401 m
.46441 .25111 L
s
.48802 .22608 m
.49226 .22728 L
s
.4561 .23144 m
.46029 .2401 L
s
.30461 .81588 m
.31132 .78909 L
s
.20443 .58588 m
.20991 .58519 L
s
.26291 .19692 m
.26769 .20251 L
s
.27585 .22807 m
.2781 .26138 L
s
.30373 .39287 m
.31259 .34321 L
s
.76924 .19679 m
.77267 .20216 L
s
.73312 .19754 m
.73663 .2027 L
s
.62456 .19707 m
.6284 .20305 L
s
.66075 .19733 m
.6645 .2034 L
s
.69697 .19799 m
.70059 .20341 L
s
.52015 .2067 m
.52424 .21671 L
s
.58844 .19947 m
.59234 .20392 L
s
.21984 .28117 m
.22039 .32678 L
s
.34648 .67803 m
.34909 .71769 L
s
.45189 .22318 m
.4561 .23144 L
s
.51602 .20422 m
.52015 .2067 L
s
.35321 .73062 m
.35857 .71962 L
s
.33603 .3104 m
.33985 .32738 L
s
.33119 .30843 m
.33603 .3104 L
s
.34079 .43878 m
.34471 .45439 L
s
.33556 .44362 m
.34079 .43878 L
s
.38351 .76342 m
.39057 .70813 L
s
.55228 .20434 m
.55631 .20938 L
s
.76581 .19145 m
.76924 .19679 L
s
.62075 .19252 m
.62456 .19707 L
s
.44745 .22226 m
.45189 .22318 L
s
.657 .19167 m
.66075 .19733 L
s
.29897 .19801 m
.30306 .21093 L
s
.29435 .1914 m
.29897 .19801 L
s
.30306 .21093 m
.30605 .23756 L
s
.72958 .19214 m
.73312 .19754 L
s
.34471 .45439 m
.34861 .47038 L
s
.69331 .19232 m
.69697 .19799 L
s
.33985 .32738 m
.3439 .34089 L
s
.5845 .19402 m
.58844 .19947 L
s
.3439 .34089 m
.34758 .36052 L
s
.48381 .2204 m
.48802 .22608 L
s
.19895 .58611 m
.20443 .58588 L
s
.27882 .6925 m
.28905 .62582 L
s
.36432 .92681 m
.37108 .88321 L
s
.41872 .26411 m
.42367 .255 L
s
.28961 .18582 m
.29435 .1914 L
s
.32787 .40976 m
.33078 .44071 L
s
.51184 .20403 m
.51602 .20422 L
s
.54822 .1971 m
.55228 .20434 L
s
.76235 .18603 m
.76581 .19145 L
s
.65321 .18576 m
.657 .19167 L
s
.72599 .18632 m
.72958 .19214 L
s
.68961 .1862 m
.69331 .19232 L
s
.32462 .33035 m
.33119 .30843 L
s
.61692 .18798 m
.62075 .19252 L
s
.26764 .63742 m
.28391 .50185 L
s
.34758 .36052 m
.35016 .39864 L
s
.58056 .18948 m
.5845 .19402 L
s
.47961 .21282 m
.48381 .2204 L
s
.33026 .19611 m
.33391 .21559 L
s
.32593 .18627 m
.33026 .19611 L
s
.15345 .32493 m
.14867 .4066 L
s
.44279 .22711 m
.44745 .22226 L
s
.2781 .26138 m
.279 .31101 L
s
.54414 .18922 m
.54822 .1971 L
s
.35894 .28803 m
.36272 .30675 L
s
.3547 .27716 m
.35894 .28803 L
s
.30605 .23756 m
.30788 .27972 L
s
.24979 .28915 m
.25039 .33847 L
s
.64944 .18052 m
.65321 .18576 L
s
.33078 .44071 m
.33556 .44362 L
s
.32129 .18023 m
.32593 .18627 L
s
.75886 .18055 m
.76235 .18603 L
s
.68588 .18002 m
.68961 .1862 L
s
.19333 .58727 m
.19895 .58611 L
s
.72238 .18047 m
.72599 .18632 L
s
.34986 .27566 m
.3547 .27716 L
s
.47541 .20385 m
.47961 .21282 L
s
.37428 .36073 m
.37935 .35566 L
s
.61304 .18275 m
.61692 .18798 L
s
.39425 .31033 m
.39924 .3045 L
s
.34909 .71769 m
.35321 .73062 L
s
.54006 .18509 m
.54414 .18922 L
s
.33391 .21559 m
.33698 .2438 L
s
.57658 .18458 m
.58056 .18948 L
s
.36272 .30675 m
.36635 .32835 L
s
.47112 .19905 m
.47541 .20385 L
s
.50766 .19969 m
.51184 .20403 L
s
.3166 .17461 m
.32129 .18023 L
s
.68218 .17454 m
.68588 .18002 L
s
.64568 .1758 m
.64944 .18052 L
s
.71877 .17477 m
.72238 .18047 L
s
.75535 .17496 m
.75886 .18055 L
s
.18828 .33744 m
.18788 .38926 L
s
.30325 .58283 m
.30542 .62367 L
s
.35731 .44457 m
.36313 .42789 L
s
.35759 .18265 m
.3617 .196 L
s
.35314 .17478 m
.35759 .18265 L
s
.29652 .86108 m
.30461 .81588 L
s
.3617 .196 m
.36557 .21334 L
s
.60911 .17622 m
.61304 .18275 L
s
.40445 .96566 m
.41065 .91949 L
s
.37821 .24796 m
.3823 .26186 L
s
.3739 .23829 m
.37821 .24796 L
s
.3823 .26186 m
.38619 .27955 L
s
.22039 .32678 m
.22105 .37261 L
s
.57256 .17839 m
.57658 .18458 L
s
.34478 .27729 m
.34986 .27566 L
s
.32854 .77994 m
.32532 .91863 L
s
.53596 .18306 m
.54006 .18509 L
s
.36635 .32835 m
.37012 .34799 L
s
.23815 .61304 m
.2416 .63355 L
s
.23326 .60806 m
.23815 .61304 L
s
.18736 .59112 m
.19333 .58727 L
s
.46671 .19868 m
.47112 .19905 L
s
.3696 .22827 m
.3739 .23829 L
s
.4142 .2606 m
.41872 .26411 L
s
.50347 .19219 m
.50766 .19969 L
s
.36557 .21334 m
.3696 .22827 L
s
.2173 .54998 m
.22093 .56805 L
s
.21301 .53848 m
.2173 .54998 L
s
.34853 .16895 m
.35314 .17478 L
s
.67847 .1691 m
.68218 .17454 L
s
.71512 .1689 m
.71877 .17477 L
s
.43831 .22495 m
.44279 .22711 L
s
.75181 .16911 m
.75535 .17496 L
s
.20812 .53276 m
.21301 .53848 L
s
.38619 .27955 m
.39003 .29869 L
s
.64187 .1707 m
.64568 .1758 L
s
.60518 .17067 m
.60911 .17622 L
s
.35016 .39864 m
.35305 .43306 L
s
.40194 .21733 m
.40603 .23152 L
s
.39778 .20478 m
.40194 .21733 L
s
.56852 .17209 m
.57256 .17839 L
s
.39362 .19201 m
.39778 .20478 L
s
.33698 .2438 m
.34038 .26801 L
s
.38945 .17967 m
.39362 .19201 L
s
.22093 .56805 m
.22441 .58785 L
s
.37012 .34799 m
.37428 .36073 L
s
.49928 .18403 m
.50347 .19219 L
s
.38512 .17007 m
.38945 .17967 L
s
.2416 .63355 m
.24228 .68561 L
s
.40603 .23152 m
.41006 .24738 L
s
.22845 .60209 m
.23326 .60806 L
s
.39003 .29869 m
.39425 .31033 L
s
.37625 .71347 m
.37853 .76803 L
s
.34388 .16327 m
.34853 .16895 L
s
.20297 .52922 m
.20812 .53276 L
s
.71147 .16311 m
.71512 .1689 L
s
.67474 .16374 m
.67847 .1691 L
s
.41006 .24738 m
.4142 .2606 L
s
.74824 .16315 m
.75181 .16911 L
s
.38063 .16333 m
.38512 .17007 L
s
.53183 .17847 m
.53596 .18306 L
s
.60126 .16602 m
.60518 .17067 L
s
.63802 .16494 m
.64187 .1707 L
s
.30892 .64644 m
.3145 .63868 L
s
.49504 .1784 m
.49928 .18403 L
s
.22441 .58785 m
.22845 .60209 L
s
.56447 .1668 m
.56852 .17209 L
s
.46235 .19417 m
.46671 .19868 L
s
.43407 .21434 m
.43831 .22495 L
s
.34038 .26801 m
.34478 .27729 L
s
.31773 .35504 m
.32462 .33035 L
s
.42577 .18765 m
.42993 .20066 L
s
.42157 .1759 m
.42577 .18765 L
s
.42993 .20066 m
.43407 .21434 L
s
.18087 .59921 m
.18736 .59112 L
s
.30788 .27972 m
.30942 .32708 L
s
.33278 .6984 m
.34257 .61797 L
s
.41728 .16582 m
.42157 .1759 L
s
.37606 .15755 m
.38063 .16333 L
s
.70781 .15762 m
.71147 .16311 L
s
.74467 .1574 m
.74824 .16315 L
s
.67098 .1583 m
.67474 .16374 L
s
.19775 .52595 m
.20297 .52922 L
s
.63411 .15841 m
.63802 .16494 L
s
.49076 .17435 m
.49504 .1784 L
s
.52766 .17151 m
.53183 .17847 L
s
.4129 .15803 m
.41728 .16582 L
s
.59729 .16049 m
.60126 .16602 L
s
.56042 .16305 m
.56447 .1668 L
s
.27284 .57597 m
.28805 .45417 L
s
.279 .31101 m
.27886 .37431 L
s
.30542 .62367 m
.30892 .64644 L
s
.45811 .18423 m
.46235 .19417 L
s
.32133 .55938 m
.31874 .67647 L
s
.25039 .33847 m
.25053 .39408 L
s
.35922 .96448 m
.36432 .92681 L
s
.37146 .15181 m
.37606 .15755 L
s
.35305 .43306 m
.35731 .44457 L
s
.74107 .15161 m
.74467 .1574 L
s
.29326 .46024 m
.30373 .39287 L
s
.40842 .15182 m
.4129 .15803 L
s
.70415 .15217 m
.70781 .15762 L
s
.45389 .17258 m
.45811 .18423 L
s
.39002 .95939 m
.38861 .88887 L
s
.52348 .16424 m
.52766 .17151 L
s
.66721 .15281 m
.67098 .1583 L
s
.63023 .15289 m
.63411 .15841 L
s
.44965 .16193 m
.45389 .17258 L
s
.19239 .52371 m
.19775 .52595 L
s
.59329 .15437 m
.59729 .16049 L
s
.48648 .16762 m
.49076 .17435 L
s
.44534 .15316 m
.44965 .16193 L
s
.37853 .76803 m
.38351 .76342 L
s
.22105 .37261 m
.22242 .41275 L
s
.55633 .158 m
.56042 .16305 L
s
.51928 .15803 m
.52348 .16424 L
s
.4039 .14602 m
.40842 .15182 L
s
.73748 .14594 m
.74107 .15161 L
s
.70044 .14645 m
.70415 .15217 L
s
.66339 .14691 m
.66721 .15281 L
s
.44095 .14622 m
.44534 .15316 L
s
.62635 .14804 m
.63023 .15289 L
s
.18788 .38926 m
.18886 .4304 L
s
.17368 .61272 m
.18087 .59921 L
s
.48223 .15821 m
.48648 .16762 L
s
.58927 .14855 m
.59329 .15437 L
s
.18669 .52408 m
.19239 .52371 L
s
.51506 .15194 m
.51928 .15803 L
s
.5522 .15137 m
.55633 .158 L
s
.47797 .14883 m
.48223 .15821 L
s
.39935 .14023 m
.4039 .14602 L
s
.43652 .14021 m
.44095 .14622 L
s
.73387 .14037 m
.73748 .14594 L
s
.6967 .14054 m
.70044 .14645 L
s
.65954 .14072 m
.66339 .14691 L
s
.24228 .68561 m
.24008 .77229 L
s
.62242 .14241 m
.62635 .14804 L
s
.58525 .14386 m
.58927 .14855 L
s
.47366 .14096 m
.47797 .14883 L
s
.4037 .97 m
.40445 .96566 L
s
.28684 .92681 m
.29652 .86108 L
s
.54804 .14441 m
.5522 .15137 L
s
.51082 .14428 m
.51506 .15194 L
s
.2672 .77352 m
.27882 .6925 L
s
.43205 .13437 m
.43652 .14021 L
s
.73023 .13467 m
.73387 .14037 L
s
.69296 .13487 m
.6967 .14054 L
s
.46931 .13445 m
.47366 .14096 L
s
.6557 .13526 m
.65954 .14072 L
s
.1805 .52837 m
.18669 .52408 L
s
.30942 .32708 m
.31237 .35722 L
s
.61845 .13615 m
.62242 .14241 L
s
.14867 .4066 m
.14558 .47721 L
s
.5812 .13824 m
.58525 .14386 L
s
.31237 .35722 m
.31773 .35504 L
s
.50657 .13613 m
.51082 .14428 L
s
.54387 .13783 m
.54804 .14441 L
s
.42755 .12851 m
.43205 .13437 L
s
.46492 .12849 m
.46931 .13445 L
s
.72656 .12871 m
.73023 .13467 L
s
.68919 .12899 m
.69296 .13487 L
s
.22242 .41275 m
.22428 .4492 L
s
.65185 .12994 m
.6557 .13526 L
s
.50229 .12891 m
.50657 .13613 L
s
.61447 .13034 m
.61845 .13615 L
s
.16567 .63263 m
.17368 .61272 L
s
.53967 .13091 m
.54387 .13783 L
s
.57709 .13158 m
.5812 .13824 L
s
.18886 .4304 m
.19164 .45645 L
s
.46051 .12259 m
.46492 .12849 L
s
.49798 .12261 m
.50229 .12891 L
s
.72286 .12268 m
.72656 .12871 L
s
.25053 .39408 m
.25003 .45821 L
s
.68539 .12301 m
.68919 .12899 L
s
.64796 .12404 m
.65185 .12994 L
s
.61048 .12495 m
.61447 .13034 L
s
.17368 .53749 m
.1805 .52837 L
s
.53546 .12364 m
.53967 .13091 L
s
.57297 .12479 m
.57709 .13158 L
s
.20477 .49258 m
.2089 .50687 L
s
.20031 .48134 m
.20477 .49258 L
s
.2089 .50687 m
.21262 .52521 L
s
.27886 .37431 m
.27845 .44317 L
s
.45607 .11666 m
.46051 .12259 L
s
.49365 .11664 m
.49798 .12261 L
s
.19574 .47105 m
.20031 .48134 L
s
.71916 .11693 m
.72286 .12268 L
s
.6816 .11733 m
.68539 .12301 L
s
.53123 .11686 m
.53546 .12364 L
s
.64402 .11783 m
.64796 .12404 L
s
.19164 .45645 m
.19574 .47105 L
s
.56883 .11805 m
.57297 .12479 L
s
.60645 .11881 m
.61048 .12495 L
s
.21262 .52521 m
.21574 .54967 L
s
.22428 .4492 m
.22599 .48796 L
s
.48929 .11068 m
.49365 .11664 L
s
.52697 .11068 m
.53123 .11686 L
s
.71544 .11102 m
.71916 .11693 L
s
.67778 .11163 m
.6816 .11733 L
s
.64009 .11197 m
.64402 .11783 L
s
.56467 .11126 m
.56883 .11805 L
s
.60239 .11216 m
.60645 .11881 L
s
.21574 .54967 m
.21817 .58146 L
s
.16631 .55065 m
.17368 .53749 L
s
.48491 .10468 m
.48929 .11068 L
s
.52269 .10466 m
.52697 .11068 L
s
.71169 .10499 m
.71544 .11102 L
s
.56049 .10477 m
.56467 .11126 L
s
.15667 .6599 m
.16567 .63263 L
s
.67392 .10556 m
.67778 .11163 L
s
.63613 .10603 m
.64009 .11197 L
s
.5983 .10551 m
.60239 .11216 L
s
.51839 .09863 m
.52269 .10466 L
s
.55629 .09862 m
.56049 .10477 L
s
.70793 .0991 m
.71169 .10499 L
s
.5942 .09894 m
.5983 .10551 L
s
.67003 .0994 m
.67392 .10556 L
s
.63213 .09962 m
.63613 .10603 L
s
.32448 .75003 m
.33278 .6984 L
s
.28445 .50327 m
.29326 .46024 L
s
.21817 .58146 m
.21992 .62086 L
s
.22599 .48796 m
.22697 .53514 L
s
.51407 .09257 m
.51839 .09863 L
s
.55207 .09254 m
.55629 .09862 L
s
.59008 .09259 m
.5942 .09894 L
s
.70414 .09314 m
.70793 .0991 L
s
.66613 .09333 m
.67003 .0994 L
s
.6281 .09306 m
.63213 .09962 L
s
.325 .93854 m
.32532 .91863 L
s
.24008 .77229 m
.23597 .88416 L
s
.14558 .47721 m
.14498 .52978 L
s
.54783 .08645 m
.55207 .09254 L
s
.2854 .93745 m
.28684 .92681 L
s
.58594 .08643 m
.59008 .09259 L
s
.15884 .56378 m
.16631 .55065 L
s
.62406 .0866 m
.6281 .09306 L
s
.70032 .08696 m
.70414 .09314 L
s
.6622 .08706 m
.66613 .09333 L
s
.25003 .45821 m
.2486 .53469 L
s
.31874 .67647 m
.31953 .74545 L
s
.25061 .77587 m
.26764 .63742 L
s
.54356 .08032 m
.54783 .08645 L
s
.58178 .08029 m
.58594 .08643 L
s
.62 .0803 m
.62406 .0866 L
s
.69648 .08074 m
.70032 .08696 L
s
.65824 .0806 m
.6622 .08706 L
s
.27845 .44317 m
.27959 .49554 L
s
.14658 .69523 m
.15667 .6599 L
s
.21992 .62086 m
.22043 .67419 L
s
.5776 .07412 m
.58178 .08029 L
s
.61593 .0741 m
.62 .0803 L
s
.65426 .07419 m
.65824 .0806 L
s
.69262 .07447 m
.69648 .08074 L
s
.25415 .86841 m
.2672 .77352 L
s
.22697 .53514 m
.22673 .59621 L
s
.57339 .06792 m
.5776 .07412 L
s
.61183 .0679 m
.61593 .0741 L
s
.65027 .06789 m
.65426 .07419 L
s
.68872 .06807 m
.69262 .07447 L
s
.15213 .56973 m
.15884 .56378 L
s
.14498 .52978 m
.14724 .56032 L
s
.60771 .06166 m
.61183 .0679 L
s
.64626 .06163 m
.65027 .06789 L
s
.68481 .06168 m
.68872 .06807 L
s
.259 .67555 m
.27284 .57597 L
s
.60357 .05539 m
.60771 .06166 L
s
.64223 .05536 m
.64626 .06163 L
s
.68089 .05534 m
.68481 .06168 L
s
.14724 .56032 m
.15213 .56973 L
s
.27959 .49554 m
.28445 .50327 L
s
.31953 .74545 m
.32448 .75003 L
s
.63817 .04905 m
.64223 .05536 L
s
.67694 .04902 m
.68089 .05534 L
s
.22043 .67419 m
.21862 .75375 L
s
.63409 .0427 m
.63817 .04905 L
s
.67297 .04268 m
.67694 .04902 L
s
.13531 .73874 m
.14658 .69523 L
s
.2486 .53469 m
.24665 .61968 L
s
.66898 .0363 m
.67297 .04268 L
s
.22673 .59621 m
.22491 .67601 L
s
.66497 .02988 m
.66898 .0363 L
s
.23535 .90033 m
.23597 .88416 L
s
.1229 .78993 m
.13531 .73874 L
s
.21464 .85488 m
.21862 .75375 L
s
.25211 .88329 m
.25415 .86841 L
s
.24665 .61968 m
.24605 .6921 L
s
.22491 .67601 m
.2216 .77444 L
s
.24966 .71787 m
.259 .67555 L
s
.24137 .84415 m
.25061 .77587 L
s
.11148 .83888 m
.1229 .78993 L
s
.24605 .6921 m
.24966 .71787 L
s
.2199 .82751 m
.2216 .77444 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.26484 .17139 m
.2696 .17691 L
s
[(0.5)] .25533 .16034 .86068 1 Mshowa
.44047 .09754 m
.44484 .10337 L
s
[(1)] .43173 .08588 .74944 1 Mshowa
.62906 .01825 m
.63298 .02439 L
s
[(1.5)] .62122 .00596 .6382 1 Mshowa
.125 Mabswid
.13279 .22691 m
.1358 .23008 L
s
.16514 .21331 m
.16811 .21652 L
s
.19792 .19953 m
.20086 .20277 L
s
.23115 .18555 m
.23405 .18883 L
s
.299 .15703 m
.30181 .16038 L
s
.33363 .14247 m
.33639 .14585 L
s
.36874 .1277 m
.37146 .13113 L
s
.40435 .11273 m
.40703 .11619 L
s
.47711 .08214 m
.47968 .08567 L
s
.51427 .06651 m
.51679 .07008 L
s
.55198 .05066 m
.55444 .05427 L
s
.59024 .03457 m
.59265 .03822 L
s
.66846 .00168 m
.67075 .0054 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(200)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(400)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(600)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(800)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.04063 .83233 m
.04126 .82801 L
s
.06868 .85207 m
.06927 .84774 L
s
.09596 .87127 m
.09651 .86693 L
s
.14833 .90812 m
.14881 .90378 L
s
.17348 .92582 m
.17392 .92147 L
s
.19797 .94306 m
.19838 .9387 L
s
.24508 .97621 m
.24543 .97185 L
s
.26775 .99217 m
.26808 .9878 L
s
.28986 1.00772 m
.29016 1.00336 L
s
.33248 1.03771 m
.33271 1.03335 L
s
.35302 1.05217 m
.35323 1.0478 L
s
.37308 1.06628 m
.37326 1.06192 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00f_ooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G?ooool00=cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Foooool00=cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Jooooo`00g?ooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo05_ooooo003Looooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c01Looooo`00g?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05ko
oooo003Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G_ooool00=[ooooo00?o
EEEEofIVI_l000003Oooool4o`0000Wooooo0_l0001Booooo`00m?ooool3o`000003ooooool0003o
oooo057ooooo003booooo`;o00001?ooool2o`00057ooooo003`ooooo`;o00001_ooool00ol0003o
ooooo`00001@ooooo`00kOooool3o`0000Sooooo00?o0000ooooool00000D?ooool009Gooooo0_l0
0002ooooo`03oa0@4?l0003o000004oooooo0ol0000:ooooo`04o`000?ooooooooooo`0004oooooo
002Fooooo`05o`000?ooooook^k^oc8b<_o<c<`0C_ooool2o`0000?ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool0001?ooooo`00U_ooool01?l0003oV9RHoc8b<_o<c<a<ooooo`?o
00003oooool01Ol0003ooooooooooooooooo000004kooooo002Fooooo`03o`000?l@413oV9RH04_o
oooo0_l0000@ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0Boooool009Kooooo
00Co0000onk^k_mEEEGoQhN7B?ooool2o`0001?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`1;ooooo`00U_ooool01Ol0003oooooodA4A?l0003o410@04Cooooo0ol00002ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`1:ooooo`00
U_ooool00ol0003oooooooooo`14ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`;o0000
1?ooool00ol0003oooooooooo`1:ooooo`00U_ooool00ol0003oooooooooo`12ooooo`;o00004_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOoo
ool009Gooooo0_l0000Pooooo`Co000000?o410@ooooooooool06_ooool3o`0001Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Sooooo002ioooo
o`03o`000?oooooooooo01[ooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`18oooo
o`00^Oooool00ol0003oooooooooo`0Gooooo`?o00004_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo04Oooooo002iooooo`03o`00
0?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo04Kooooo002iooooo`03o`000?oo
oooooooo01?ooooo0_l0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
A_ooool00;Wooooo00?o0000ooooooooool04?ooool3o`0000;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo04Gooooo002iooooo`03o`000?oo
oooooooo00kooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`15ooooo`00]oooool00omEEEGoIVIVo`00000>ooooo`;o00003_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`14ooooo`00aOooool3o`00013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00<?ooooo0_l00003oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0@oooool00<7ooooo0_l0000=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04;ooooo002nooooo`?o00003oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`00_?ooool3o`00
01;ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`11ooooo`00^_ooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo002gooooo`?o00003oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo002eooooo`;o00004oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?oooool00;?ooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`00/?ooool3
o`0000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool0
07[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01kooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03gooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool06_ooool3o`0000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool007[ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oooooo0_l00002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0??ooool007[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo
001jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Co
oooo0ol0000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0koooo
o`00N_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool2o`00
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo001joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Booooo`;o00000_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0jooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>Oooool009[ooooo0ol0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0hooooo`00VOooool3o`0001;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo002Fooooo`?o00003Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2
o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Oooooo002Dooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo002Booooo`;o00004oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Ko
oooo002?ooooo`?o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o0000
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=Oooool008gooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Ooo
ool008[ooooo0ol0000Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`00R?ooool3o`00
00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool008Ko
oooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00Goooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01oooooo0ol0000;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03;ooooo001Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool2o`0000oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0booooo`00Goooool01Ol@413ooooooooooooooooo410@01_ooooo0_l000000ooo
oooo0000ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`00Goooool01Ol0003ooooooooooooooooo
000001Sooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0`ooooo`00Goooool01Ol0003ooooooooooooooooo000001Gooooo0ol0000?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo001Oooooo`05oa0@4?oooooo
ooooooooool@41005?ooool3o`00017ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0_ooooo`00Goooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0ol0000<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`00Gooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000_l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool0077ooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00002?ooool3o`0000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool006kooooo0ol000000ooooooo0000oooo
o`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0]ooooo`00K?ooool2o`00013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool006Wooooo0ol0000;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool006Oooooo0ol0000=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool2o`0000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool006Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool006Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00?o0000ooooooooool00_l00008oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo001Uooooo`?o00003oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`00I_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool005_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`07o`000?ooooooooooooooool0003oooooo`00000;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool0
05_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`00Foooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo
001Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Kooooo001Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09Oooool005_ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool01_l0003ooooooooo
ool0003oooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o
00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo001Kooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oo
oooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool005_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`00
000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02?ooooo001Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0S
ooooo`00I?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo0000ooooool000002?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0R
ooooo`00I?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo1Ol00003
ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo001Tooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`Co00001oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08Oooool006Cooooo00?o0000ooooooooool03_ooool3o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool006?ooooo0_l0
000Aooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool006?ooooo
00?o0000ooooooooool04?ooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`00
Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000;o00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool006?ooooo00?o0000
ooooooooool04?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01_l0003o
ooooooooool0003oooooo`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01kooooo001Sooooo`03o`000?oooooooooo013ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03o`00
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo001Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01gooooo001Rooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00oooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`0000Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool006;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool0
0oooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Sooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool006;ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool2o`000003ooooool0
003ooooo00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo0ol00006ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000oooo
o`05ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00?ooooo1?l0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o0000ooooool00006oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`00HOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo001Qooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool02Ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool3
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool0067ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo001Qooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o00001_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000004ooooo`;o00001_ooool2o`0000Kooooo0ol00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001P
ooooo`?o00004_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00006
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo001Qooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`?o00001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000ooo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Eooooo`00?_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000003ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool003kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000_l00006
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000n
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool02?l0003oooooooooool0003oooooo`000?oooooo00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0ol00004ooooo`04o`000?oooooo
ooooooooo`?o00000oooool00ol0003oooooooooo`03ooooo`Co00001_ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00?_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000003ooooo`?o00001?ooool01?l0003oooooooooooooool3
o`0000?ooooo00?o0000ooooooooool00oooool4o`0000Oooooo0_l000000ooooooo0000ooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`00?_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool01?l0003oooooo`000?l00004ooooo`04o`000?ooooooooooooooo`?o
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`00
0003ooooool0003ooooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l0
0007ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`00?_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000Kooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00;ooooo00Co0000ooooool0003o00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool2o`00
00Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`00?_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool2o`0001Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`06o`000?ooooooooooooooool0003o
oooo0_l00002ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00009
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool003kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool3o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo00Co0000oooo
ool0003o00001?ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooooooool2o`0000Wooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`06ooooo`;o00002?ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooooooo`?o00004_ooool005oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
0003ooooool0003ooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0
003oooooooooo`;o00001Oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`07ooooo`?o00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0ol00002ooooo`03o`000?oooooooooo013ooooo001Oooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooool0003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo
0_l000001?oooooo0000ooooooooool2o`0000Gooooo00Ko0000ooooool0003o0000ooooool00004
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`000004ooooool0003o
ooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`02o`0000Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0@ooooo`00
Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003
ooooo`Co000000?oooooo`000?ooool00ol00005ooooo`06o`000?oooooo0000o`000?oooooo0000
1?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0ol000001?oooooo0000
ooooool00002ooooo`;o00001?ooool01?l0003oooooo`000?l00005ooooo`;o000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo1?l00008
ooooo`03o`000?oooooooooo013ooooo001Oooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0000?ooooo0ol000001?oooooo0000ooooooooool3o`0000Gooooo
0_l000001?oooooo0000ooooool00004ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o
00001oooool2o`000005ooooool0003o0000ooooool000000_ooool2o`0000Cooooo00Go0000oooo
ool0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000000ol0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03o`000?oooooooooo013ooooo001O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0
0002ooooo`?o000000Coooooo`000?oooooooooo0ol00002ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo
0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l00004ooooo`05o`000?oooooo0000oooo
ool000002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`Co00003oooool00ol0003oooooooooo`0?ooooo`00G_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`03o`0000Cooooo1?l000001?oooooo
0000ooooooooool4o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o00001oooool2o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`05o`000?oo
oooo0000ooooool000002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool3o`0001;ooooo
00?o0000ooooooooool03oooool005kooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?l00004ooooo`?o000000?oooooo`000?l000000oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooo00000oooool3o`0000Oooooo
0_l00004ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`000003ooooool0003ooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?l0000E
ooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003o000000;o00000oooool01?l0003oooooo`000?l00002
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?l000001?ooool3o`0000Oooooo0_l00005ooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?ooool01oooool01?l0003oooooooooooooool2o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0ol0000Hooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004o`0000?ooooo
00Co0000ooooool0003o00000_ooool2o`000005ooooool0003oooooooooool000000_ooool00ol0
003oooooooooo`02o`000003ooooool0003o000000Cooooo0ol00006ooooo`04o`000?oooooooooo
o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0?ooooo`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`02ooooo`04o`000?oooooo0000
o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Ko0000ooooool0003ooooo
o`000?ooool2o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool3o`00
01kooooo00?o0000ooooooooool03oooool005kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool03?l0003o
ooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0ol000000ooooooo
0000ooooo`02o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool3o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool03oooool005kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go00000_ooool0
3?l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0_l00002
ooooo`04o`000?oooooo0000o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo0ol0000Uoooo
o`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`02
o`000003ooooool0003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0
0005ooooo`?o00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1Ol0000Vooooo`03
o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool2
o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001?oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool01_ooool2o`000004ooooool0003oooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo1?l0000[ooooo`03o`000?oooooooooo00kooooo001Moooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000oooo
ool000000_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo0_l000001?oooooo0000
ooooool00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`Co0000;Oooool00ol0003oooooooooo`0>ooooo`00G?ooool2o`0001Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`000005ooooool0003o0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Cooooo1Ol00004ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool005go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o00000_ooool00ol0003o
ooooooooo`02o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo1?l0000coooo
o`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o000000Coooooo`000?oooooo00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`00
00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00G?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooo
ooooooooo`000009ooooo`0<o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00kooooo001Looooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool4o`000005ooooool0003ooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000_l00004ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooo
ool0003ooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`?o000000Coooooo`00
0?l0003o0000>_ooool00ol0003oooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo0_l00003ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo0ol00003ooooo`04o`000?oooooooooooooo
o`;o00002?ooool2o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`0000Kooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo0_l00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00000
1Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000;o
oooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04o`0000Wooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03
o`000?oooooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003ooooo
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo1_l00003
ooooo`?o00002?ooool2o`000003ooooool0003ooooo00;ooooo0_l00006ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00gooooo001Looooo`;o00005_ooool00ol0
003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05
ooooo`;o00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003o00001?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool3o`0000Kooooo0ol00008ooooo`Co00000_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo00Co
oooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00gooooo001Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?ooool00oooool0
0ol0003oooooo`000002o`000005ooooool0003oooooooooool000000oooool3o`0000Kooooo0ol0
0007ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool03Oooool003Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002o`0000?ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo0ol00006ooooo`?o0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o000000Goooooo`000?oooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00go
oooo0006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo00Oooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool3
o`0000Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooo
oooooooooooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00001oooool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413o
gMgM00Oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4003ooooo`Go00001Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0
003oooooooooool00002ooooo`0=o`000?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`;o00001?ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
0000ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool00ol0003ooooooooo
o`06ooooo`Co00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`03
ooooo`06ofIVI_l0003o0000odA4A?o<c<co00000_ooool00ol0003oooooooooo`05ooooo`03oeEE
EOnHV9Sooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03ohN7QomVIVKooooo00Ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooo
oooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
0oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l000001_oooooo
0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006
ooooo`04o`000?oooooo0000ooooo`So000000?oooooo`000?l000001Oooool00ol0003ooooooooo
o`03ooooo`Co00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`02
ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0ol00008ooooo`03o`000?oooooooooo00;ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003
ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo0_l00003ooooo`04o`000?oooooo0000o`0000;ooooo
00?o0000ooooool000000oooool3o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooool0
00001_ooool:o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo00?o00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l000001_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00000oooool0
1?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Cooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000001Oooool7o`000004ooooool0003o0000o`0000?ooooo
0_l00005ooooo`?o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
0_l0000;ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03?ooool000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oc8b<_oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^ko
A4A4o`000005ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`04ooooo`;o
00001?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000005oooo
o`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooool000000_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04o`00
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo00002oooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?ok^k^o`000?ooool01_ooool00ol0003oooooooooo`04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?oMgMgo`000?ooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooo`000005ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooool000000_l00003ooooo`;o00001Oooool3o`0000Co
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0000;ooooo`04oeEEEOmgMgOo
oooooa0@40Go00001?ooool00omgMgOoEEEEooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l0
000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000_ooool00ol0003oooooo`000005ooooo`?o000000Coooooo`000?oooooo
oooo0_l00003ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002o`0000;o
oooo00?o0000ooooool000000_ooool3o`000003ooooool0003ooooo00Cooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00_ooooo0006ooooo`03o`000?oooooooooo01?o
oooo00?ogMgMoa0@4?o^k^h00_ooool00ol0003oooooooooo`04ooooo`03onk^k_l@413ogMgM00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Co
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool2o`00
00Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`000003ooooool0003o
oooo00Cooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`03o`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool000001?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02ooo
ool000Kooooo00?o0000ooooooooool05?ooool01OmgMgOoIVIVoooooooooooo000000Kooooo00?o
IVIVogMgMoooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`000004ooooool0003oooooooooo`;o
00001_ooool2o`0000;ooooo00?o0000ooooool000000_l00002ooooo`?o000000?oooooo`000?oo
ool01?ooool00ol0003oooooo`000008o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool005[ooooo00?o0000ooooooooool0
5oooool01?l0003oooooooooool0000>ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o
00001Oooool2o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool005Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooo`00000>ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003o
ooooo`000003ooooo`;o000000Coooooo`000?oooooooooo0_l00006ooooo`;o00000_ooool00ol0
003oooooo`000002o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00004oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03Oooool3o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooool0
00000oooool2o`000004ooooool0003oooooooooo`;o00001_ooool2o`0000;ooooo00Oo0000oooo
oooooooo0000ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`04o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02[ooooo0ol0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooo000000?ooooo0_l0
00001?oooooo0000ooooooooool2o`0000Kooooo0_l00002ooooo`04o`000?oooooo0000ooooo`Go
00000_ooool3o`0000;ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`;o
000000Coooooo`000?oooooooooo0_l00006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool02?l00003ooooo`;o00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02Wooooo1ol00000
0ooooooo0000ooooo`05ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Co00000_ooool2o`000004ooooool0003oooooo`0000?ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo001Hooooo`;o00009Oooool6o`000004
ooooool0003oooooo`0000?ooooo0_l00006ooooo`;o00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooooooo1?l000000ooooooo
0000ooooo`02ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool3o`0003cooooo00?o0000ooooooooool02_ooool005Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo0_l00005ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?oooooooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo0ol00002ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool02_ooool005Sooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`000005ooooool0003o
ooooooooool000000oooool2o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5_ooool3o`0000Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`00F?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o0000
0oooool2o`0000Cooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?l00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?l0
0002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04oooool3o`0000[ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000003ooooo`;o0000
1?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co00000_ooool0
0ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo1?l0000>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
2_ooool005Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`;o000000Go
ooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003ooooo
ooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?l000001_oooooo0000o`000?oooooo0000ooooo`;o0000
0_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000003_ooool3o`0001?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo1?l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`Co000000Koooooo`000?l0003oooooo`000?ooool2o`0000;ooooo
00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000_ooooo0ol0000Fooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`;o00000_ooool00ol0003oooooo`000004ooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko0000oooooooooooo
0000ooooool00004ooooo`Co000000?oooooo`000?ooool00_l000001Ooooooo0000oooooooooooo
000000;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00006_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo00?o0000ooooool000001?ooool00ol0003oooooo`000004
o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`Go000000Ooooooo`000?l0003oooooo`000?oooooo
000000;ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol0000Oooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02Oooool005Oooooo0_l0000Qooooo`03o`000?oooooo
oooo00[ooooo0_l00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000000_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00007ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool5o`000007ooooool0003oooooooooool0003oooooo`00
0002ooooo`03o`000?oooooooooo00?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo0_l00002ooooo`03o`000?oooooo000000;o00008oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo0_l00002ooooo`03
o`000?oooooo000000?ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`03o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`;o000000Coooooo`000?l0003o00009oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo00Co0000oooo
ool0003o00000oooool01?l0003oooooo`000?l00006ooooo`;o00000_ooool00ol0003oooooo`00
0003ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool5o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
Eoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`04o`000?oooooo0000o`0000?ooooo00Co0000ooooool0
003o00001_ooool2o`0000;ooooo00?o0000ooooool000000oooool2o`000007ooooool0003ooooo
ooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool00_l0
000Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0;ooooo`;o00000oooool2o`0000Cooooo0_l00004
ooooo`03o`000?oooooo000000;ooooo0ol00003ooooo`04o`000?oooooo0000o`0000Kooooo0_l0
0002ooooo`03o`000?oooooo000000?ooooo0_l000001ooooooo0000oooooooooooo0000ooooool0
00000oooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool02Oooool005Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`;o0000
0oooool2o`0000?ooooo00?o0000ooooool000000oooool01_l0003ooooooooooooooooo0000oooo
o`?o00000oooool2o`000003ooooool0003ooooo00Gooooo0_l00002ooooo`03o`000?oooooo0000
00?ooooo0_l000001ooooooo0000oooooooooooo0000ooooool000000oooool2o`0000Gooooo00?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo001Fooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool03?ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool0
0ol0003oooooo`000003ooooo`;o000000Ooooooo`000?ooooooooooo`000?oooooo000000?ooooo
0_l00005ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00
E_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o0000
0oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o
oooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool2o`0000Gooooo1?l00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool005Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0=ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000?ooooo0_l00003
ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo001Foooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool2o`0000?ooooo0_l00003oooo
o`;o00001?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool01Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo1Ol00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`08ooooo`00EOooool3o`0001oooooo00?o0000ooooooooool03Oooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000
ooooo`;o000000?oooooo`000?ooool01Oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1?l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`;o0000
0oooool2o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`04o`00
0?oooooo0000ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool003?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool03_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`07ooooo`00<oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00kooooo0_l00003ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Kooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`04oooo
o`03o`000?oooooo000000;ooooo0_l00003ooooo`Go00000_ooool2o`0000Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool01oooool003?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool01?oo
ool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000oooo
ooooool2o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool01oooool003?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oEEEEo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`00
00;ooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo00;ooooo1?l00002ooooo`?o000000?oooooo`000?ooool00_l000001?oo
oooo0000ooooooooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00<oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo00Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001Ol00002ooooo`06o`000?oooooo0000o`000?oooooo
00000_ooool2o`0000Cooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`00<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0@ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo
1Ol00002ooooo`;o00000_ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o0000oooo
ooooool00oooool2o`0000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o410@1?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo013ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;o00000_ooool4o`000005ooooool0003ooooooooo
ool000000_ooool01_l0003ooooooooooooooooo0000ooooo`;o000000Goooooo`000?oooooooooo
o`000005ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool005Co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`000004
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05o`00
00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`07ooooo`00E?ooool2o`0001kooooo00?o0000ooooooooool0
4?ooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oo
oooo1Ol00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000003gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`00E?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo
00000oooool00ol0003oooooooooo`05ooooo`?o00000oooool00ol0003oooooooooo`02o`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo0ol00002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000?o00001_ooool02_l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool00004oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000005
ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0003oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`00
Doooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooool00000
0oooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0000:ooooo`03o`000?oooooo000000;o
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000000oooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00010ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01_ooool005?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000ooooo`0:ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooool0
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Kooooo001Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
4Oooool2o`0000Cooooo1Ol00003ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o
00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
ool0003o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00012ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool005?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l000000_l00003ooooo`05o`00
0?ooooooooooooooool000002oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00003ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`00Doooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo
0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`04
o`000?oooooo0000o`0000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Gooooo001Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
3oooool5o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04
o`000?oooooo0000o`0000[ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000004Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`00D_ooool2o`0001gooooo00?o0000ooooooooool03?oo
ool3o`0000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
2_ooool4o`0000[ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003ooooo00;o
oooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo000004Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05oooo
o`00D_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo1?l00006ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo1?l0000:oooo
o`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00000oooool3o`0000Cooooo00?o
0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
A_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo001Booooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01_ooool3o`0000[ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool02oooool3o`0000[ooooo00Co0000ooooool0003o
00000_ooool01?l0003oooooooooool00003ooooo`?o00001?ooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000016ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool005;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`03ooooo`?o00003Oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0;ooooo`?o00002_ooool4o`000003ooooool0003o000000;ooooo00Co0000
oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo000004Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`05ooooo`00D_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000000?o00004?oo
ool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04o`00
0?oooooo0000o`0000[ooooo1_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000004Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`00D_ooool0
0ol0003oooooooooo`0Jooooo`?o00005?ooool2o`0000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`0000[ooooo1_l00003ooooo`04o`00
0?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01?ooool005;ooooo00?o0000ooooooooool05oooool4o`0001Kooooo0_l00004ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool02oooool01?l0003oooooo`000?l0000:oooo
o`;o000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool3o`0000?ooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001Aooooo`03o`000?oo
oooooooo01Gooooo0ol00003ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02o`0000[ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool00000E?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Cooooo001Aooooo`03o`000?oooooooooo017ooooo1?l00006ooooo`03
o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02o`0000_ooooo00Go0000ooooool0003oooooo`000002oooo
o`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooooooooooo000000cooooo00Co0000
oooooooooooo0000E?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001A
ooooo`03o`000?oooooooooo00kooooo0ol0000:ooooo`03o`000?oooooooooo01Cooooo0_l00004
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
o`0000_ooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`02ooooo`;o000000Co
ooooo`000?oooooo00003Oooool01?l0003oooooooooool0001Eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool0057ooooo00?o0000ooooooooool02oooool3o`0000gooooo
00?o0000ooooooooool05?ooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;o00003?ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`000004ooooool0003oooooo`0000gooooo00Co0000oooooooooooo0000E_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo001@ooooo`;o00002Oooool4o`0000oo
oooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooooooo`;o00003?ooool3o`0000?ooooo00?o0000oooo
ooooool00_ooool2o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0001Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?oo
ool0057ooooo00?o0000ooooooooool01?ooool3o`0001?ooooo00?o0000ooooooooool05Oooool2
o`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo
ooooooooo`;o00003?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0
003oooooo`0000?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0001Hooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool0053ooooo00?o0000ooooooooool0
0_ooool3o`0001Kooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo0000F?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo001@ooooo`03o`000?oooooo000000;o00006Oooool00ol0003ooooooooo
o`0Eooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool01ol0003ooooooooo
oooooooo0000ooooool000003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`000005ooooool0003oooooooooool000002_ooool01?l0003oooooooooool0
001Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool0053ooooo0_l0000K
ooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000002ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0005[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`00D_oo
ool2o`0001Wooooo00?o0000ooooooooool05Oooool00ol0003oooooo`000004ooooo`;o00000ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002ooo
ool2o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo0000ooooool0
00003?ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool005?ooooo0_l0000Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool0
00001?ooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000_ooooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool3o`00
00gooooo00Co0000oooooooooooo0000G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00?ooooo001Booooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooo`000004ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000G?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooo`000004ooooo`;o00000oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go
0000ooooooooooooooooo`00000Cooooo`04o`000?ooooooooooo`0005gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`02ooooo`00Eoooool2o`0001?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooo`000004ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Co0000oooooooooooo
00005?ooool01?l0003oooooooooool0001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool005Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooo000000Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooo
oooo00005?ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`00F_ooool2o`00013ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool0
000Dooooo`05o`000?ooooooooooooooool00000Goooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00;ooooo001Jooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000002_ooool00ol0003oooooo`000004ooooo`04o`000?oo
ooooooooo`0001Cooooo00Go0000ooooooooooooooooo`00001Oooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00_ooool005gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo0000063ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`00C_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Cooooo00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo0000067ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00C_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00gooooo0_l0000Sooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo
000006;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00C_ooool01Ol@
413ooooooooooooooooo410@00kooooo0_l0000Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0001Cooooo
00Go0000ooooooooooooooooo`00001Sooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00Oooool004kooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo0000027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo001>
ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0Tooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wo
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`00000Eooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00Oooool004kooooo00Go410@oooooooooooooooooa0@400Booooo`;o00009?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000005Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo007ooooo001>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2o`00
02;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
5Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo001>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h05Oooool2o`00027ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001Zooooo`03o`000?oo
oooooooo01kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001[ooooo`03o`000?oooooooooo
01gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
5Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0:ooooo`7o00000Oooool1ooooo`00K?ooool3o`0001cooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooool000005Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool1ooooo`00K_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`00000Eooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`?o0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Fooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`7ooooo001aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o00005oooool01ol0003ooooooooooooooooo0000ooooool00000J?ooool00ol0003o
ooooooooo`07ooooo`7o00000Oooool1ooooo`00L_ooool2o`0001Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`;o00005oooool01ol0003ooooooooooooooooo0000
ooooool00000JOooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00M?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000001Oooooo00Oo0000ooooooooooooooooo`000?oooooo000006[ooooo00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool007Gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool01ol0
003ooooooooooooooooo0000ooooool000005oooool01ol0003ooooooooooooooooo0000ooooool0
0000Joooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00MOooool3o`00023ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l0000Hooooo`07o`000?ooooooooooooooool0003oooooo`00
001/ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`;o00006?ooool01ol0003ooooooooooooooooo0000oooo
ool00000K?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Wooooo0_l0000Looooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00006?ooool01ol0003ooooooooooooooooo0000ooooool00000
KOooool00ol0003oooooooooo`03ooooo`7o00000Oooool0067ooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool2o`0001Sooooo00Oo0000ooooooooooooooooo`00
0?oooooo000006kooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Qooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00006_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0001Sooooo00Oo
0000ooooooooooooooooo`000?oooooo000006oooooo00Go0000ooooooooooooooooo`000001oooo
o`00H_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Oooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
6?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06oooooo00Co0000oooooooooooo
00000Oooool006?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Kooo
ool01?l0003oooooooooool00001ooooo`00I?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Eooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool00Ol0000006Gooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`09ooooo`;o00008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l0000Hooooo`03o`000?oooooooooo07Kooooo0Ol00001ooooo`7o0000001Qooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`1g
ooooo`;o0000001Qooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o00007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03
o`000?oooooooooo07Kooooo0ol0000008Kooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000oooooooo
ool0LOooool5o`0000?ooooo0027ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo06go
oooo1?l00008ooooo`00Qoooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Wooooo
1?l0000<ooooo`00R_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Cooooo1Ol0
000@ooooo`00Roooool2o`0001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo063ooooo1?l0000Eooooo`00SOooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05_ooooo1Ol0000Iooooo`00SOooool3o`0001Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Eoooool4o`0001kooooo002@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
D_ooool5o`0002;ooooo002Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_oo
ool4o`0002Oooooo001mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000@ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04[ooooo1?l0000[ooooo`00O_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04Gooooo1Ol0000_ooooo`00Noooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Ooo
ool4o`0003Cooooo001kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001oooool2o`0000_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0??ooool5o`0003Sooooo001kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0>?ooool4o`0003gooooo001looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0dooooo`Co0000@Oooool007cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo
1Ol00015ooooo`00OOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0ol0000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0[ooooo`Co0000B_ooool009kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09_ooool5o`0004kooooo002Oooooo`;o00004oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool4o`0005?ooooo002Q
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01kooooo1?l0001Gooooo`00X_ooool2o`00013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo1Ol0001Koooo
o`00Xoooool2o`0000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Gooooo1?l0001Pooooo`00YOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`Go0000
I?ooool00:Kooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0<ooooo`Co0000JOooool00:Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool5
o`0006gooooo002Booooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo1?l0001booooo`00
T_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`Co0000M_ooool009;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool5o`0007[ooooo
0023ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool2
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`Co0000Ooooool0
08?ooooo00Go410@okZj^_o^k^koMgMgoa0@400:ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool5o`0008?ooooo0023ooooo`03o`00
0?oooooooooo00cooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4009ooooo`05o`000?oooooo0000ooooool000002_ooool4
o`0008Sooooo0023ooooo`03o`000?oooooooooo00cooooo00?ogMgMoa0@4?nHV9P01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000?o
ooooo`000?ooool01Oooool4o`0008cooooo0023ooooo`03o`000?oooooooooo00gooooo00Coc<c<
odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`?o000000?oooooo`000?l000000ol0002@ooooo`00POooool00ol@413o0000
o`000003o`0002gooooo0_l0002Eooooo`00Poooool00ol0003oooooooooo`35ooooo`00Poooool0
0ol0003oooooooooo`35ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00Y_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo002V
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@402@ooooo`00Y_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000T?ooool0
0:Kooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@402@oooo
o`00Y_ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093o
oooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodco
oooo003oooooodcooooo003oooooodcooooo003;ooooo`04oa0@4?l0003o0000o`0007cooooo003<
ooooo`03o`000?oooooooooo07cooooo003<ooooo`03o`000?oooooooooo07cooooo002Nooooo`05
o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`000?mgMgOo410@o`0000Cooooo00?o
8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4okZj^PSooooo00Ko410@oc8b<_l0
003o0000oa0@4?nYZJT3ooooo`09o`000?mgMgOo0000o`000?mEEEGok^k^ooooooo^k^koEEEE00;o
000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4A4Coc<c<00?ooooo00OoV9RHo`00
0?l0003oA4A4okZj^_oooooo410@00Go00001?ooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o
00000_ooool01Ol0003oooooooooool0003o410@04Sooooo002Mooooo`06ojVYZOl0003oQhN7oiRH
V?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o^[Zj
0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Sooooo00Ko0000ojVYZOoooooooooookZj^_l0
0003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgooooooo^k^koMgMgoa0@
4002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`17ooooo`00WOooool01_mEEEGoQhN7odA4A?mE
EEGoMgMgoeEEE@;ooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`04oa0@4?nj^[[oV9RHoc8b
<P?ooooo00?o0000ooooooooool03?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo04Oooooo002Mooooo`06o`000?oM
gMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002o`0000?ooooo00KoV9RHoc8b<_oo
oooooooooa0@4?nj^[X2ooooo`Ko00002?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP?ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`0000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Aoooool009co
oooo00SoZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZ@Cooooo00Ooc<c<o`000?oooooooooo
onk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b
2?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00go0000oeEEEOo^k^koooooogMgMomV
IVKooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q04Wooooo002Looooo`?o
00000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0_ooool00ol@413o0000o`000002oooo
o`?o000000?oooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`07ooooo`06ojVYZOlQ8B7o0000
o`000?lb<S;o00000_ooool00ol@413o0000ogMgM`02o`000005ofIVI_o^k^koooooonk^k_mEEED0
0_l000001_m4A4Cok^k^ooooooooooook^k^ofIVIP;o000000CoA4A4o`000?oooooo410@1Ol00003
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o0000ooooooooool2o`000009oooo
ool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY04Wooooo003Tooooo`03o`000?oooooooooo
06Cooooo003Tooooo`03o`000?oooooooooo06Cooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.225172, -0.107519, \
0.00427749, 0.00427749}}]
}, Open  ]],

Cell[TextData[{
  "Evidently the cascade to large wavenumbers has been suppressed by the \
dispersive term in the ",
  "KdV",
  " equation. Modes in the upper half of the spectral range have negligible \
amplitude. This implies that our cutoff of the spectrum at ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\[PlusMinus]M\)\)]],
  " does not affect the result. This can be verified by taking larger (or \
somewhat smaller) values of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ": the answer does not change. "
}], "Text"],

Cell[TextData[{
  "\tThus, when dispersion is added in the KdV equation, wavebreaking no \
longer occurs.  Is this due to the relatively small amplitude of the  wave \
chosen in the above example? The answer is no - even for large amplitudes, \
the wavebreaking is suppressed. However, it is harder to see this \
numerically, because more  modes must be kept, making the problem somewhat \
harder to integrate.  In Fig. ",
  ButtonBox["7.7",
    ButtonData:>"Fig. 7.7",
    ButtonStyle->"Hyperlink"],
  ", we show an example of a sinusoidal initial condition with eight times \
the previous amplitude. The solution still breaks up into solitons, and the \
spectrum (Fig. ",
  ButtonBox["7.8",
    ButtonData:>"Fig. 7.8",
    ButtonStyle->"Hyperlink"],
  ") still remains peaked in the lower half of the spectral range."
}], "Text"],

Cell[BoxData[
    \( (*\ movie\ goes\ here\ *) \)], "Input"],

Cell["Fig. 7.7 (animation)  A solution of the KdV equation", "Caption",
  CellTags->"Fig. 7.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 -1.11022e-16 1.16608 [
[.5 1.098 -41.125 0 ]
[.5 1.098 41.125 24.5 ]
[.09072 .22988 -5.91576 -9 ]
[.09072 .22988 .08424 0 ]
[.22151 .17463 -5.64878 -9 ]
[.22151 .17463 .35122 0 ]
[.35968 .11629 -5.38181 -9 ]
[.35968 .11629 .61819 0 ]
[.50588 .0546 -5.11483 -9 ]
[.50588 .0546 .88517 0 ]
[.66081 -0.01073 -4.84785 -9 ]
[.66081 -0.01073 1.15215 0 ]
[.30907 .06148 -8.98592 -12 ]
[.30907 .06148 1.01408 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.12079 .90442 -6.71106 0 ]
[.12079 .90442 5.28894 9 ]
[.22056 .97437 -6.52538 0 ]
[.22056 .97437 5.47462 9 ]
[.31055 1.03745 -6.36418 0 ]
[.31055 1.03745 5.63582 9 ]
[.39213 1.09464 -6.2229 0 ]
[.39213 1.09464 5.7771 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.0469 .42724 -18 -2.76445 ]
[.0469 .42724 0 6.23555 ]
[.01721 .61309 -18 -2.93177 ]
[.01721 .61309 0 6.06823 ]
[-0.03373 .52941 -45.25 -3.77786 ]
[-0.03373 .52941 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -102.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(spectrum) show
69.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.23115 .18555 m
.23598 .19102 L
s
[(1)] .22151 .17463 .88293 1 Mshowa
.36874 .1277 m
.37327 .13341 L
s
[(2)] .35968 .11629 .79394 1 Mshowa
.51427 .06651 m
.51847 .07247 L
s
[(3)] .50588 .0546 .70494 1 Mshowa
.66846 .00168 m
.67228 .00789 L
s
[(4)] .66081 -0.01073 .61595 1 Mshowa
.125 Mabswid
.12637 .22961 m
.12939 .23277 L
s
.15215 .21877 m
.15514 .22196 L
s
.1782 .20782 m
.18116 .21104 L
s
.20453 .19675 m
.20746 .19999 L
s
.25807 .17424 m
.26093 .17754 L
s
.28528 .16279 m
.28811 .16613 L
s
.31279 .15123 m
.31558 .15459 L
s
.34061 .13953 m
.34337 .14292 L
s
.39719 .11574 m
.39987 .11919 L
s
.42596 .10364 m
.42861 .10713 L
s
.45507 .09141 m
.45767 .09492 L
s
.4845 .07903 m
.48706 .08257 L
s
.54439 .05385 m
.54687 .05745 L
s
.57487 .04103 m
.5773 .04467 L
s
.6057 .02807 m
.60808 .03173 L
s
.63689 .01495 m
.63923 .01865 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(10)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(20)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(30)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(40)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.0605 .42199 m
.0673 .41937 L
s
[(0.1)] .0469 .42724 1 -0.38568 Mshowa
.03097 .60829 m
.03785 .60589 L
s
[(0.2)] .01721 .61309 1 -0.3485 Mshowa
.125 Mabswid
.0817 .28822 m
.08574 .28655 L
s
.07658 .32051 m
.08063 .31886 L
s
.07134 .35355 m
.0754 .35193 L
s
.06598 .38737 m
.07005 .38577 L
s
.05488 .45746 m
.05897 .45591 L
s
.04912 .49378 m
.05322 .49226 L
s
.04322 .53101 m
.04733 .52951 L
s
.03717 .56917 m
.04129 .5677 L
s
.02461 .64842 m
.02875 .64701 L
s
.01809 .6896 m
.02224 .68822 L
s
.01139 .73186 m
.01555 .73051 L
s
.00452 .77524 m
.00869 .77393 L
s
gsave
-0.03373 .52941 -106.25 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
75.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 13.000 moveto
(H) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
(\\310) show
104.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4186 .578 m
.42216 .58164 L
s
.41502 .57434 m
.4186 .578 L
s
.41143 .57067 m
.41502 .57434 L
s
.40782 .56698 m
.41143 .57067 L
s
.40419 .56327 m
.40782 .56698 L
s
.40055 .55955 m
.40419 .56327 L
s
.39689 .55581 m
.40055 .55955 L
s
.39322 .55206 m
.39689 .55581 L
s
.38953 .54829 m
.39322 .55206 L
s
.49063 .58498 m
.49428 .57325 L
s
.38583 .5445 m
.38953 .54829 L
s
.3821 .54069 m
.38583 .5445 L
s
.37836 .53687 m
.3821 .54069 L
s
.49981 .59432 m
.50342 .58113 L
s
.48648 .63203 m
.49063 .58498 L
s
.37461 .53303 m
.37836 .53687 L
s
.37084 .52917 m
.37461 .53303 L
s
.51839 .65405 m
.52202 .58017 L
s
.50899 .62234 m
.51265 .59042 L
s
.36705 .5253 m
.37084 .52917 L
s
.49595 .62742 m
.49981 .59432 L
s
.36324 .52141 m
.36705 .5253 L
s
.35941 .5175 m
.36324 .52141 L
s
.35557 .51357 m
.35941 .5175 L
s
.35171 .50962 m
.35557 .51357 L
s
.34784 .50566 m
.35171 .50962 L
s
.58494 .55129 m
.59004 .64304 L
s
.58314 .63365 m
.58494 .55129 L
s
.50521 .65711 m
.50899 .62234 L
s
.34394 .50168 m
.34784 .50566 L
s
.54712 .60891 m
.55047 .60111 L
s
.48216 .68228 m
.48648 .63203 L
s
.55672 .60375 m
.56 .59442 L
s
.49194 .66516 m
.49595 .62742 L
s
.34003 .49768 m
.34394 .50168 L
s
.64246 .51401 m
.64644 .53742 L
s
.64055 .54553 m
.64246 .51401 L
s
.3361 .49366 m
.34003 .49768 L
s
.47389 .53374 m
.47658 .59536 L
s
.46998 .54544 m
.47389 .53374 L
s
.5439 .64832 m
.54712 .60891 L
s
.33215 .48963 m
.3361 .49366 L
s
.55359 .63611 m
.55672 .60375 L
s
.5357 .53821 m
.53922 .5549 L
s
.53231 .58621 m
.5357 .53821 L
s
.60484 .56987 m
.60809 .57098 L
s
.44159 .71848 m
.44528 .72261 L
s
.43189 .73081 m
.43565 .73295 L
s
.64918 .51081 m
.65279 .52424 L
s
.64611 .51104 m
.64918 .51081 L
s
.53922 .5549 m
.54293 .60368 L
s
.32819 .48557 m
.33215 .48963 L
s
.66262 .52072 m
.66584 .52518 L
s
.61458 .56613 m
.61788 .56949 L
s
.60383 .52568 m
.60783 .55481 L
s
.60071 .53061 m
.60383 .52568 L
s
.4796 .71049 m
.48353 .69307 L
s
.65279 .52424 m
.65629 .53505 L
s
.43794 .71273 m
.44159 .71848 L
s
.60188 .58184 m
.60484 .56987 L
s
.67234 .51401 m
.67559 .51949 L
s
.48324 .53991 m
.48602 .60762 L
s
.47922 .5616 m
.48324 .53991 L
s
.42812 .72801 m
.43189 .73081 L
s
.3242 .4815 m
.32819 .48557 L
s
.6595 .51863 m
.66262 .52072 L
s
.59531 .58241 m
.59904 .60215 L
s
.5918 .57177 m
.59531 .58241 L
s
.43429 .70606 m
.43794 .71273 L
s
.58891 .592 m
.5918 .57177 L
s
.46395 .56137 m
.46657 .61963 L
s
.46015 .56319 m
.46395 .56137 L
s
.68216 .50909 m
.68543 .51512 L
s
.51452 .7385 m
.51839 .65405 L
s
.56664 .62217 m
.57001 .6212 L
s
.61148 .57027 m
.61458 .56613 L
s
.70123 .48786 m
.70472 .49834 L
s
.66911 .50914 m
.67234 .51401 L
s
.6987 .49435 m
.70123 .48786 L
s
.69193 .50263 m
.69517 .50845 L
s
.64414 .5404 m
.64611 .51104 L
s
.43064 .69931 m
.43429 .70606 L
s
.46515 .60075 m
.46998 .54544 L
s
.6792 .50917 m
.68216 .50909 L
s
.5013 .69627 m
.50521 .65711 L
s
.42435 .72485 m
.42812 .72801 L
s
.3202 .4774 m
.3242 .4815 L
s
.71148 .4893 m
.71463 .49416 L
s
.66577 .50215 m
.66911 .50914 L
s
.68928 .50796 m
.69193 .50263 L
s
.42696 .69321 m
.43064 .69931 L
s
.65633 .5161 m
.6595 .51863 L
s
.59815 .56123 m
.60071 .53061 L
s
.62458 .56913 m
.62803 .57747 L
s
.72141 .48466 m
.72453 .48932 L
s
.60783 .55481 m
.61148 .57027 L
s
.66288 .50538 m
.66577 .50215 L
s
.70824 .48315 m
.71148 .4893 L
s
.56369 .66116 m
.56664 .62217 L
s
.62158 .5755 m
.62458 .56913 L
s
.42323 .68832 m
.42696 .69321 L
s
.45477 .63365 m
.46015 .56319 L
s
.31617 .47329 m
.3202 .4774 L
s
.49266 .54796 m
.49493 .68846 L
s
.48849 .58932 m
.49266 .54796 L
s
.42056 .72164 m
.42435 .72485 L
s
.73128 .4787 m
.73445 .48444 L
s
.6343 .56213 m
.63786 .57386 L
s
.63183 .58247 m
.6343 .56213 L
s
.48786 .69932 m
.49194 .66516 L
s
.71842 .48216 m
.72141 .48466 L
s
.67636 .51219 m
.6792 .50917 L
s
.65306 .51142 m
.65633 .5161 L
s
.70503 .47761 m
.70824 .48315 L
s
.63861 .57851 m
.64055 .54553 L
s
.41943 .68495 m
.42323 .68832 L
s
.59875 .5885 m
.60188 .58184 L
s
.59646 .48736 m
.60068 .52616 L
s
.59344 .4999 m
.59646 .48736 L
s
.74133 .47507 m
.74449 .48072 L
s
.72846 .47831 m
.73128 .4787 L
s
.6964 .50528 m
.6987 .49435 L
s
.31213 .46916 m
.31617 .47329 L
s
.41674 .71866 m
.42056 .72164 L
s
.47479 .78074 m
.4796 .71049 L
s
.70275 .48807 m
.70503 .47761 L
s
.6495 .50017 m
.65306 .51142 L
s
.64664 .50615 m
.6495 .50017 L
s
.47769 .73258 m
.48216 .68228 L
s
.75146 .47187 m
.75452 .4765 L
s
.68675 .51621 m
.68928 .50796 L
s
.54906 .57933 m
.55282 .61511 L
s
.5456 .58207 m
.54906 .57933 L
s
.61433 .54836 m
.61798 .56293 L
s
.61132 .55656 m
.61433 .54836 L
s
.73875 .4776 m
.74133 .47507 L
s
.71557 .48211 m
.71842 .48216 L
s
.41556 .68308 m
.41943 .68495 L
s
.66019 .51383 m
.66288 .50538 L
s
.30807 .46501 m
.31213 .46916 L
s
.55023 .65043 m
.55359 .63611 L
s
.61798 .56293 m
.62158 .5755 L
s
.41289 .71609 m
.41674 .71866 L
s
.54293 .60368 m
.54664 .63854 L
s
.47463 .61348 m
.47922 .5616 L
s
.76147 .46672 m
.76467 .47333 L
s
.72565 .47846 m
.72846 .47831 L
s
.58671 .65212 m
.58891 .592 L
s
.7488 .47286 m
.75146 .47187 L
s
.67358 .51705 m
.67636 .51219 L
s
.54057 .68854 m
.5439 .64832 L
s
.47658 .59536 m
.47943 .65399 L
s
.77174 .46447 m
.77466 .46782 L
s
.53777 .67641 m
.54131 .68201 L
s
.59159 .56432 m
.59531 .58277 L
s
.58809 .55628 m
.59159 .56432 L
s
.304 .46084 m
.30807 .46501 L
s
.75865 .46507 m
.76147 .46672 L
s
.41163 .68224 m
.41556 .68308 L
s
.59531 .58277 m
.59875 .5885 L
s
.409 .71405 m
.41289 .71609 L
s
.71246 .47839 m
.71557 .48211 L
s
.58533 .58727 m
.58809 .55628 L
s
.54221 .60525 m
.5456 .58207 L
s
.54108 .52867 m
.5449 .58355 L
s
.53759 .53761 m
.54108 .52867 L
s
.73613 .47997 m
.73875 .4776 L
s
.53432 .71217 m
.53777 .67641 L
s
.78186 .45985 m
.78488 .46457 L
s
.57675 .64162 m
.58072 .67671 L
s
.57436 .70948 m
.57675 .64162 L
s
.64439 .52912 m
.64664 .50615 L
s
.76878 .46076 m
.77174 .46447 L
s
.2999 .45665 m
.304 .46084 L
s
.72269 .47655 m
.72565 .47846 L
s
.69404 .51605 m
.6964 .50528 L
s
.43573 .71603 m
.43923 .72968 L
s
.43213 .7059 m
.43573 .71603 L
s
.74628 .47593 m
.7488 .47286 L
s
.59036 .51185 m
.59344 .4999 L
s
.64216 .57175 m
.64414 .5404 L
s
.4284 .69998 m
.43213 .7059 L
s
.68401 .52107 m
.68675 .51621 L
s
.60828 .56542 m
.61132 .55656 L
s
.70898 .46861 m
.71246 .47839 L
s
.75605 .46663 m
.75865 .46507 L
s
.40767 .68156 m
.41163 .68224 L
s
.52878 .63195 m
.53231 .58621 L
s
.70056 .5008 m
.70275 .48807 L
s
.40506 .71252 m
.409 .71405 L
s
.66276 .48151 m
.66653 .497 L
s
.65988 .48596 m
.66276 .48151 L
s
.43923 .72968 m
.44269 .74551 L
s
.79214 .45662 m
.79515 .46154 L
s
.62876 .58633 m
.63183 .58247 L
s
.70629 .47213 m
.70898 .46861 L
s
.77909 .45813 m
.78186 .45985 L
s
.65731 .51875 m
.66019 .51383 L
s
.46657 .61963 m
.46943 .67107 L
s
.67033 .51275 m
.67358 .51705 L
s
.60068 .52616 m
.60472 .55557 L
s
.55089 .52934 m
.55511 .60996 L
s
.54746 .53803 m
.55089 .52934 L
s
.42454 .69797 m
.4284 .69998 L
s
.29578 .45244 m
.2999 .45665 L
s
.55282 .61511 m
.55667 .65583 L
s
.7656 .4545 m
.76878 .46076 L
s
.66653 .497 m
.67033 .51275 L
s
.44269 .74551 m
.44614 .76163 L
s
.80243 .4532 m
.80538 .45762 L
s
.59529 .58242 m
.59815 .56123 L
s
.71984 .47666 m
.72269 .47655 L
s
.58177 .75246 m
.58314 .63365 L
s
.78943 .45529 m
.79214 .45662 L
s
.54664 .63854 m
.55023 .65043 L
s
.48602 .60762 m
.48872 .69428 L
s
.73308 .47644 m
.73613 .47997 L
s
.60703 .51214 m
.61066 .5249 L
s
.60378 .51394 m
.60703 .51214 L
s
.49729 .73244 m
.5013 .69627 L
s
.44614 .76163 m
.44966 .77551 L
s
.40109 .71137 m
.40506 .71252 L
s
.76303 .45597 m
.7656 .4545 L
s
.52324 .48877 m
.52683 .55262 L
s
.51957 .5143 m
.52324 .48877 L
s
.40372 .67994 m
.40767 .68156 L
s
.44966 .77551 m
.45329 .78467 L
s
.61066 .5249 m
.61485 .55719 L
s
.77626 .45589 m
.77909 .45813 L
s
.81275 .4496 m
.81567 .4539 L
s
.29165 .44822 m
.29578 .45244 L
s
.64631 .47947 m
.65001 .49341 L
s
.64313 .4787 m
.64631 .47947 L
s
.42056 .69849 m
.42454 .69797 L
s
.75353 .46939 m
.75605 .46663 L
s
.79978 .45211 m
.80243 .4532 L
s
.74337 .47409 m
.74628 .47593 L
s
.53413 .57696 m
.53759 .53761 L
s
.48381 .72336 m
.48786 .69932 L
s
.65001 .49341 m
.6539 .51194 L
s
.68065 .51432 m
.68401 .52107 L
s
.62523 .57709 m
.62876 .58633 L
s
.72969 .46824 m
.73308 .47644 L
s
.70387 .48063 m
.70629 .47213 L
s
.65691 .48907 m
.65988 .48596 L
s
.56037 .67509 m
.56369 .66116 L
s
.45358 .51591 m
.4558 .58752 L
s
.44997 .50571 m
.45358 .51591 L
s
.63598 .59452 m
.63861 .57851 L
s
.78657 .45242 m
.78943 .45529 L
s
.67693 .50055 m
.68065 .51432 L
s
.67367 .49611 m
.67693 .50055 L
s
.82311 .446 m
.82608 .45099 L
s
.62205 .57904 m
.62523 .57709 L
s
.6539 .51194 m
.65731 .51875 L
s
.4443 .57269 m
.44997 .50571 L
s
.56705 .51456 m
.57088 .54238 L
s
.56468 .60301 m
.56705 .51456 L
s
.71681 .47425 m
.71984 .47666 L
s
.81 .44715 m
.81275 .4496 L
s
.28749 .44397 m
.29165 .44822 L
s
.72641 .46162 m
.72969 .46824 L
s
.39709 .71028 m
.40109 .71137 L
s
.39982 .67656 m
.40372 .67994 L
s
.53138 .5631 m
.53504 .59836 L
s
.52779 .56371 m
.53138 .5631 L
s
.60472 .55557 m
.60828 .56542 L
s
.52445 .70037 m
.52807 .75832 L
s
.52055 .86616 m
.52445 .70037 L
s
.69117 .51804 m
.69404 .51605 L
s
.60996 .49157 m
.61394 .51644 L
s
.60666 .49156 m
.60996 .49157 L
s
.77323 .45147 m
.77626 .45589 L
s
.63944 .46514 m
.64313 .4787 L
s
.63622 .4641 m
.63944 .46514 L
s
.48371 .6665 m
.48849 .58932 L
s
.60018 .50252 m
.60378 .51394 L
s
.59679 .50012 m
.60018 .50252 L
s
.58687 .50602 m
.59036 .51185 L
s
.66277 .46011 m
.66678 .48028 L
s
.65936 .45309 m
.66277 .46011 L
s
.83355 .44277 m
.83639 .44673 L
s
.76055 .45904 m
.76303 .45597 L
s
.74024 .46943 m
.74337 .47409 L
s
.58415 .53308 m
.58805 .55968 L
s
.58059 .52429 m
.58415 .53308 L
s
.79701 .44999 m
.79978 .45211 L
s
.54414 .57621 m
.54746 .53803 L
s
.72352 .46107 m
.72641 .46162 L
s
.41655 .69923 m
.42056 .69849 L
s
.82024 .44203 m
.82311 .446 L
s
.67049 .49367 m
.67367 .49611 L
s
.69793 .50665 m
.70056 .5008 L
s
.61994 .4879 m
.62428 .52209 L
s
.61657 .48436 m
.61994 .4879 L
s
.4603 .64966 m
.46515 .60075 L
s
.5774 .53755 m
.58059 .52429 L
s
.28331 .4397 m
.28749 .44397 L
s
.78366 .44917 m
.78657 .45242 L
s
.65613 .45039 m
.65936 .45309 L
s
.39596 .67152 m
.39982 .67656 L
s
.75074 .46894 m
.75353 .46939 L
s
.76993 .44392 m
.77323 .45147 L
s
.71327 .46413 m
.71681 .47425 L
s
.5834 .50189 m
.58687 .50602 L
s
.80732 .44567 m
.81 .44715 L
s
.53869 .61509 m
.54221 .60525 L
s
.84397 .43903 m
.84684 .44345 L
s
.70969 .4532 m
.71327 .46413 L
s
.39308 .7088 m
.39709 .71028 L
s
.7068 .45373 m
.70969 .4532 L
s
.67293 .45797 m
.67679 .47413 L
s
.66965 .45344 m
.67293 .45797 L
s
.73723 .46658 m
.74024 .46943 L
s
.8307 .43891 m
.83355 .44277 L
s
.64175 .54341 m
.64439 .52912 L
s
.62996 .48412 m
.63441 .51903 L
s
.62651 .47737 m
.62996 .48412 L
s
.59386 .51947 m
.59679 .50012 L
s
.61876 .57848 m
.62205 .57904 L
s
.63386 .48759 m
.63622 .4641 L
s
.65342 .48056 m
.65691 .48907 L
s
.52414 .61583 m
.52779 .56371 L
s
.76725 .44406 m
.76993 .44392 L
s
.60353 .4991 m
.60666 .49156 L
s
.66678 .48028 m
.67049 .49367 L
s
.61485 .55719 m
.61876 .57848 L
s
.81752 .43985 m
.82024 .44203 L
s
.64975 .46782 m
.65342 .48056 L
s
.64638 .46243 m
.64975 .46782 L
s
.39212 .66582 m
.39596 .67152 L
s
.56099 .54955 m
.56583 .65966 L
s
.55741 .54054 m
.56099 .54955 L
s
.79405 .4459 m
.79701 .44999 L
s
.55667 .65583 m
.56037 .67509 L
s
.68777 .51073 m
.69117 .51804 L
s
.27912 .43541 m
.28331 .4397 L
s
.61346 .49023 m
.61657 .48436 L
s
.47943 .65399 m
.48252 .70351 L
s
.59589 .46003 m
.59974 .48128 L
s
.59312 .48652 m
.59589 .46003 L
s
.61394 .51644 m
.61763 .5303 L
s
.67679 .47413 m
.68083 .4938 L
s
.78083 .447 m
.78366 .44917 L
s
.85448 .43574 m
.85733 .44011 L
s
.58272 .63193 m
.58533 .58727 L
s
.57088 .54238 m
.57564 .62666 L
s
.58024 .51611 m
.5834 .50189 L
s
.72055 .45959 m
.72352 .46107 L
s
.55442 .59844 m
.55741 .54054 L
s
.62378 .49332 m
.62651 .47737 L
s
.65267 .4427 m
.65613 .45039 L
s
.4126 .69766 m
.41655 .69923 L
s
.84121 .43572 m
.84397 .43903 L
s
.46301 .52547 m
.46532 .60343 L
s
.45933 .51729 m
.46301 .52547 L
s
.61763 .5303 m
.62148 .54926 L
s
.66645 .45097 m
.66965 .45344 L
s
.53708 .71462 m
.54057 .68854 L
s
.70106 .48326 m
.70387 .48063 L
s
.55936 .62779 m
.56342 .67762 L
s
.55581 .62324 m
.55936 .62779 L
s
.68439 .5039 m
.68777 .51073 L
s
.47315 .77895 m
.47769 .73258 L
s
.5449 .58355 m
.54873 .62492 L
s
.75783 .45923 m
.76055 .45904 L
s
.80455 .44329 m
.80732 .44567 L
s
.82774 .43404 m
.8307 .43891 L
s
.38824 .66063 m
.39212 .66582 L
s
.38908 .70661 m
.39308 .7088 L
s
.73396 .46018 m
.73723 .46658 L
s
.74769 .4653 m
.75074 .46894 L
s
.58805 .55968 m
.59191 .58225 L
s
.64346 .46891 m
.64638 .46243 L
s
.59191 .58225 m
.59529 .58242 L
s
.45423 .56953 m
.45933 .51729 L
s
.64955 .44339 m
.65267 .4427 L
s
.53083 .7938 m
.53432 .71217 L
s
.86499 .43204 m
.86779 .43623 L
s
.79099 .44079 m
.79405 .4459 L
s
.2749 .4311 m
.27912 .43541 L
s
.49813 .6006 m
.50126 .67428 L
s
.49307 .73031 m
.49813 .6006 L
s
.46943 .67107 m
.47262 .70781 L
s
.8149 .43879 m
.81752 .43985 L
s
.70358 .44913 m
.7068 .45373 L
s
.63976 .59394 m
.64216 .57175 L
s
.85174 .43236 m
.85448 .43574 L
s
.68083 .4938 m
.68439 .5039 L
s
.43948 .53845 m
.44292 .55622 L
s
.43289 .62696 m
.43948 .53845 L
s
.67982 .45003 m
.68348 .46203 L
s
.6766 .44669 m
.67982 .45003 L
s
.6948 .50424 m
.69793 .50665 L
s
.41884 .84723 m
.42284 .84686 L
s
.68348 .46203 m
.68737 .47832 L
s
.76467 .44568 m
.76725 .44406 L
s
.53504 .59836 m
.53869 .61509 L
s
.55238 .63536 m
.55581 .62324 L
s
.73036 .44929 m
.73396 .46018 L
s
.72692 .44063 m
.73036 .44929 L
s
.77773 .44185 m
.78083 .447 L
s
.59974 .48128 m
.60353 .4991 L
s
.63302 .60279 m
.63598 .59452 L
s
.62148 .54926 m
.62579 .58183 L
s
.83842 .43226 m
.84121 .43572 L
s
.38428 .65677 m
.38824 .66063 L
s
.82495 .43096 m
.82774 .43404 L
s
.40876 .69212 m
.4126 .69766 L
s
.71714 .45163 m
.72055 .45959 L
s
.66357 .45562 m
.66645 .45097 L
s
.87555 .42843 m
.87836 .43287 L
s
.68992 .44471 m
.6938 .46062 L
s
.68662 .43947 m
.68992 .44471 L
s
.74431 .45737 m
.74769 .4653 L
s
.72377 .43635 m
.72692 .44063 L
s
.47005 .65607 m
.47463 .61348 L
s
.78802 .4369 m
.79099 .44079 L
s
.38508 .70385 m
.38908 .70661 L
s
.80168 .44011 m
.80455 .44329 L
s
.51052 .80636 m
.51452 .7385 L
s
.86227 .42866 m
.86499 .43204 L
s
.51569 .57854 m
.51957 .5143 L
s
.27067 .42677 m
.2749 .4311 L
s
.47988 .73363 m
.48381 .72336 L
s
.68737 .47832 m
.69128 .49495 L
s
.7 .43856 m
.70358 .44913 L
s
.44292 .55622 m
.44507 .62482 L
s
.71353 .44061 m
.71714 .45163 L
s
.62428 .52209 m
.62842 .54866 L
s
.44899 .71235 m
.45477 .63365 L
s
.52611 .65626 m
.52977 .68973 L
s
.52247 .65731 m
.52611 .65626 L
s
.7101 .43243 m
.71353 .44061 L
s
.69679 .43454 m
.7 .43856 L
s
.53312 .51832 m
.53679 .54169 L
s
.52952 .53978 m
.53312 .51832 L
s
.75479 .4556 m
.75783 .45923 L
s
.74091 .44922 m
.74431 .45737 L
s
.84894 .42864 m
.85174 .43236 L
s
.77433 .43325 m
.77773 .44185 L
s
.57457 .5777 m
.5774 .53755 L
s
.40505 .68301 m
.40876 .69212 L
s
.67343 .44461 m
.6766 .44669 L
s
.69766 .47596 m
.70106 .48326 L
s
.60996 .4835 m
.61346 .49023 L
s
.6938 .46062 m
.69766 .47596 L
s
.38023 .65446 m
.38428 .65677 L
s
.69128 .49495 m
.6948 .50424 L
s
.64678 .45323 m
.64955 .44339 L
s
.88616 .42494 m
.88896 .42946 L
s
.81212 .43626 m
.8149 .43879 L
s
.70693 .42863 m
.7101 .43243 L
s
.83553 .42803 m
.83842 .43226 L
s
.68367 .44081 m
.68662 .43947 L
s
.40138 .67253 m
.40505 .68301 L
s
.46927 .88161 m
.47479 .78074 L
s
.87279 .42454 m
.87555 .42843 L
s
.77132 .42932 m
.77433 .43325 L
s
.73768 .44347 m
.74091 .44922 L
s
.82234 .42977 m
.82495 .43096 L
s
.41482 .84767 m
.41884 .84723 L
s
.39766 .66324 m
.40138 .67253 L
s
.72049 .43048 m
.72377 .43635 L
s
.49332 .75458 m
.49729 .73244 L
s
.78518 .43465 m
.78802 .4369 L
s
.63441 .51903 m
.6384 .54004 L
s
.38106 .70105 m
.38508 .70385 L
s
.26641 .42242 m
.27067 .42677 L
s
.39382 .65688 m
.39766 .66324 L
s
.60684 .49154 m
.60996 .4835 L
s
.79862 .43506 m
.80168 .44011 L
s
.85954 .4253 m
.86227 .42866 L
s
.58437 .71245 m
.58671 .65212 L
s
.52513 .65936 m
.52878 .63195 L
s
.6384 .54004 m
.64175 .54341 L
s
.76174 .44317 m
.76467 .44568 L
s
.5792 .46875 m
.58298 .48803 L
s
.5758 .47203 m
.5792 .46875 L
s
.69414 .44059 m
.69679 .43454 L
s
.64083 .48395 m
.64346 .46891 L
s
.89682 .42145 m
.89958 .4258 L
s
.75154 .44936 m
.75479 .4556 L
s
.84615 .42503 m
.84894 .42864 L
s
.88338 .42062 m
.88616 .42494 L
s
.7342 .43444 m
.73768 .44347 L
s
.83243 .42187 m
.83553 .42803 L
s
.71725 .42519 m
.72049 .43048 L
s
.67001 .43783 m
.67343 .44461 L
s
.37611 .65319 m
.38023 .65446 L
s
.70431 .43418 m
.70693 .42863 L
s
.38982 .65377 m
.39382 .65688 L
s
.87012 .4214 m
.87279 .42454 L
s
.5187 .70164 m
.52247 .65731 L
s
.5772 .54094 m
.58024 .51611 L
s
.52852 .47522 m
.53217 .48805 L
s
.52485 .51937 m
.52852 .47522 L
s
.76848 .42779 m
.77132 .42932 L
s
.80913 .43171 m
.81212 .43626 L
s
.53679 .54169 m
.54053 .57526 L
s
.73074 .42563 m
.7342 .43444 L
s
.53848 .46677 m
.54216 .48457 L
s
.53497 .50166 m
.53848 .46677 L
s
.59063 .52757 m
.59386 .51947 L
s
.66044 .45576 m
.66357 .45562 L
s
.79541 .42844 m
.79862 .43506 L
s
.53217 .48805 m
.53594 .54049 L
s
.26214 .41805 m
.26641 .42242 L
s
.7481 .44071 m
.75154 .44936 L
s
.52683 .55262 m
.53051 .58515 L
s
.62069 .49966 m
.62378 .49332 L
s
.90751 .41789 m
.91025 .42226 L
s
.37699 .69879 m
.38106 .70105 L
s
.62975 .60269 m
.63302 .60279 L
s
.52807 .75832 m
.53196 .92289 L
s
.81962 .42764 m
.82234 .42977 L
s
.62842 .54866 m
.63256 .57444 L
s
.85673 .42138 m
.85954 .4253 L
s
.41075 .84835 m
.41482 .84767 L
s
.78205 .42913 m
.78518 .43465 L
s
.72752 .42055 m
.73074 .42563 L
s
.59561 .44643 m
.59982 .48084 L
s
.59226 .44848 m
.59561 .44643 L
s
.53051 .58515 m
.53413 .57696 L
s
.89408 .4173 m
.89682 .42145 L
s
.58298 .48803 m
.58693 .51444 L
s
.66698 .43935 m
.67001 .43783 L
s
.74442 .42881 m
.7481 .44071 L
s
.74101 .42073 m
.74442 .42881 L
s
.82973 .41964 m
.83243 .42187 L
s
.62579 .58183 m
.62975 .60269 L
s
.47262 .70781 m
.47612 .72863 L
s
.68089 .4461 m
.68367 .44081 L
s
.75844 .43627 m
.76174 .44317 L
s
.71423 .4237 m
.71725 .42519 L
s
.84332 .4213 m
.84615 .42503 L
s
.54873 .62492 m
.55238 .63536 L
s
.88066 .41688 m
.88338 .42062 L
s
.46869 .53565 m
.47221 .55465 L
s
.46366 .59313 m
.46869 .53565 L
s
.63118 .50416 m
.63386 .48759 L
s
.79228 .42279 m
.79541 .42844 L
s
.54216 .48457 m
.54618 .55277 L
s
.80612 .427 m
.80913 .43171 L
s
.38571 .65271 m
.38982 .65377 L
s
.47612 .72863 m
.47988 .73363 L
s
.738 .4182 m
.74101 .42073 L
s
.54849 .46477 m
.55231 .49542 L
s
.54515 .50345 m
.54849 .46477 L
s
.86741 .41814 m
.87012 .4214 L
s
.25784 .41366 m
.26214 .41805 L
s
.37197 .65183 m
.37611 .65319 L
s
.52977 .68973 m
.53345 .71557 L
s
.48252 .70351 m
.48588 .73908 L
s
.77865 .42071 m
.78205 .42913 L
s
.75493 .4267 m
.75844 .43627 L
s
.90481 .41385 m
.90751 .41789 L
s
.72437 .41654 m
.72752 .42055 L
s
.4367 .48038 m
.43981 .51097 L
s
.43096 .53598 m
.4367 .48038 L
s
.76529 .42211 m
.76848 .42779 L
s
.57143 .75071 m
.57436 .70948 L
s
.57246 .48092 m
.5758 .47203 L
s
.85383 .41674 m
.85673 .42138 L
s
.37285 .69742 m
.37699 .69879 L
s
.53345 .71557 m
.53708 .71462 L
s
.8913 .41291 m
.89408 .4173 L
s
.75151 .41838 m
.75493 .4267 L
s
.55511 .60996 m
.55932 .67534 L
s
.59007 .50385 m
.59312 .48652 L
s
.54053 .57526 m
.54414 .57621 L
s
.78929 .41881 m
.79228 .42279 L
s
.77539 .41403 m
.77865 .42071 L
s
.8167 .42374 m
.81962 .42764 L
s
.64395 .4628 m
.64678 .45323 L
s
.56342 .67762 m
.56765 .73387 L
s
.65695 .44806 m
.66044 .45576 L
s
.84034 .41613 m
.84332 .4213 L
s
.47221 .55465 m
.47414 .67186 L
s
.87799 .41375 m
.88066 .41688 L
s
.4266 .49305 m
.42888 .54791 L
s
.41926 .58832 m
.4266 .49305 L
s
.82702 .41746 m
.82973 .41964 L
s
.69143 .44612 m
.69414 .44059 L
s
.63655 .59506 m
.63976 .59394 L
s
.40665 .84944 m
.41075 .84835 L
s
.80303 .42167 m
.80612 .427 L
s
.60363 .49766 m
.60684 .49154 L
s
.65319 .43436 m
.65695 .44806 L
s
.64953 .42305 m
.65319 .43436 L
s
.64637 .42387 m
.64953 .42305 L
s
.7484 .41415 m
.75151 .41838 L
s
.71144 .42618 m
.71423 .4237 L
s
.25352 .40924 m
.25784 .41366 L
s
.76191 .41409 m
.76529 .42211 L
s
.4558 .58752 m
.4585 .64389 L
s
.70163 .43948 m
.70431 .43418 L
s
.73512 .41771 m
.738 .4182 L
s
.8646 .41409 m
.86741 .41814 L
s
.58905 .45862 m
.59226 .44848 L
s
.60593 .45081 m
.60972 .46663 L
s
.60252 .44903 m
.60593 .45081 L
s
.63256 .57444 m
.63655 .59506 L
s
.66398 .44224 m
.66698 .43935 L
s
.38159 .65133 m
.38571 .65271 L
s
.7723 .40943 m
.77539 .41403 L
s
.9021 .40988 m
.90481 .41385 L
s
.72107 .41059 m
.72437 .41654 L
s
.85104 .41312 m
.85383 .41674 L
s
.36786 .64927 m
.37197 .65183 L
s
.8885 .40848 m
.8913 .41291 L
s
.58693 .51444 m
.59063 .52757 L
s
.83719 .4096 m
.84034 .41613 L
s
.75876 .40922 m
.76191 .41409 L
s
.78613 .41301 m
.78929 .41881 L
s
.48872 .69428 m
.49159 .78196 L
s
.43593 .77253 m
.43956 .78554 L
s
.43178 .77822 m
.43593 .77253 L
s
.51852 .50432 m
.52217 .52753 L
s
.51461 .55509 m
.51852 .50432 L
s
.61751 .50454 m
.62069 .49966 L
s
.81358 .41784 m
.8167 .42374 L
s
.79977 .41453 m
.80303 .42167 L
s
.36864 .69692 m
.37285 .69742 L
s
.52585 .55216 m
.52952 .53978 L
s
.43956 .78554 m
.44254 .82441 L
s
.60972 .46663 m
.61387 .49471 L
s
.67779 .44574 m
.68089 .4461 L
s
.87526 .41016 m
.87799 .41375 L
s
.74539 .4116 m
.7484 .41415 L
s
.63807 .49703 m
.64083 .48395 L
s
.71814 .41044 m
.72107 .41059 L
s
.45564 .68286 m
.4603 .64966 L
s
.82412 .41363 m
.82702 .41746 L
s
.24919 .40481 m
.25352 .40924 L
s
.59877 .43448 m
.60252 .44903 L
s
.59569 .44857 m
.59877 .43448 L
s
.76929 .40581 m
.7723 .40943 L
s
.86168 .40918 m
.8646 .41409 L
s
.83443 .40679 m
.83719 .4096 L
s
.48949 .75692 m
.49332 .75458 L
s
.79649 .40737 m
.79977 .41453 L
s
.89933 .40548 m
.9021 .40988 L
s
.40249 .8511 m
.40665 .84944 L
s
.78288 .40646 m
.78613 .41301 L
s
.84816 .40893 m
.85104 .41312 L
s
.88587 .40548 m
.8885 .40848 L
s
.81038 .41125 m
.81358 .41784 L
s
.75599 .40926 m
.75876 .40922 L
s
.61255 .43943 m
.61654 .4614 L
s
.60891 .42922 m
.61255 .43943 L
s
.59982 .48084 m
.60363 .49766 L
s
.37755 .64745 m
.38159 .65133 L
s
.36379 .64542 m
.36786 .64927 L
s
.64299 .41986 m
.64637 .42387 L
s
.55231 .49542 m
.55665 .57438 L
s
.60588 .44187 m
.60891 .42922 L
s
.73209 .41552 m
.73512 .41771 L
s
.57962 .65482 m
.58272 .63193 L
s
.62266 .4323 m
.62697 .46266 L
s
.61904 .42252 m
.62266 .4323 L
s
.43981 .51097 m
.44209 .57394 L
s
.67024 .41899 m
.67412 .43462 L
s
.66689 .41443 m
.67024 .41899 L
s
.7934 .40226 m
.79649 .40737 L
s
.70866 .42914 m
.71144 .42618 L
s
.51751 .47032 m
.52112 .51965 L
s
.51381 .46391 m
.51751 .47032 L
s
.87246 .40606 m
.87526 .41016 L
s
.5587 .47731 m
.56251 .49968 L
s
.55546 .51122 m
.5587 .47731 L
s
.46862 .8166 m
.47315 .77895 L
s
.61587 .42798 m
.61904 .42252 L
s
.24483 .40035 m
.24919 .40481 L
s
.77978 .40163 m
.78288 .40646 L
s
.36439 .69689 m
.36864 .69692 L
s
.80723 .40526 m
.81038 .41125 L
s
.82106 .40822 m
.82412 .41363 L
s
.68812 .4414 m
.69143 .44612 L
s
.74235 .40865 m
.74539 .4116 L
s
.56917 .49738 m
.57246 .48092 L
s
.85872 .40401 m
.86168 .40918 L
s
.48588 .73908 m
.48949 .75692 L
s
.52217 .52753 m
.52585 .55216 L
s
.66067 .43895 m
.66398 .44224 L
s
.89644 .40019 m
.89933 .40548 L
s
.76654 .40568 m
.76929 .40581 L
s
.52142 .6627 m
.52513 .65936 L
s
.52035 .66291 m
.52414 .61583 L
s
.67412 .43462 m
.67779 .44574 L
s
.84509 .40304 m
.84816 .40893 L
s
.83155 .40295 m
.83443 .40679 L
s
.69858 .43872 m
.70163 .43948 L
s
.49493 .68846 m
.49708 .87833 L
s
.62811 .51086 m
.63118 .50416 L
s
.63289 .42821 m
.63704 .4521 L
s
.62927 .41836 m
.63289 .42821 L
s
.64075 .46389 m
.64395 .4628 L
s
.37363 .64088 m
.37755 .64745 L
s
.35972 .64126 m
.36379 .64542 L
s
.88316 .40196 m
.88587 .40548 L
s
.7153 .41203 m
.71814 .41044 L
s
.63971 .41867 m
.64299 .41986 L
s
.50971 .52794 m
.51381 .46391 L
s
.43886 .62425 m
.4443 .57269 L
s
.62628 .42731 m
.62927 .41836 L
s
.5433 .55682 m
.54704 .57709 L
s
.53966 .55786 m
.5433 .55682 L
s
.42735 .79127 m
.43178 .77822 L
s
.79037 .398 m
.7934 .40226 L
s
.57412 .5685 m
.5772 .54094 L
s
.52658 .42357 m
.5303 .46257 L
s
.52284 .45861 m
.52658 .42357 L
s
.41748 .44914 m
.41993 .49573 L
s
.40914 .56001 m
.41748 .44914 L
s
.6637 .41352 m
.66689 .41443 L
s
.61387 .49471 m
.61751 .50454 L
s
.80405 .39915 m
.80723 .40526 L
s
.39828 .85345 m
.40249 .8511 L
s
.61654 .4614 m
.62039 .47806 L
s
.81784 .40146 m
.82106 .40822 L
s
.86958 .40143 m
.87246 .40606 L
s
.72884 .41036 m
.73209 .41552 L
s
.77694 .39993 m
.77978 .40163 L
s
.85587 .39992 m
.85872 .40401 L
s
.24045 .39588 m
.24483 .40035 L
s
.4657 .67919 m
.47005 .65607 L
s
.68452 .4316 m
.68812 .4414 L
s
.75316 .40881 m
.75599 .40926 L
s
.89375 .3966 m
.89644 .40019 L
s
.36973 .63353 m
.37363 .64088 L
s
.5854 .44904 m
.58905 .45862 L
s
.84197 .39677 m
.84509 .40304 L
s
.6812 .42721 m
.68452 .4316 L
s
.50126 .67428 m
.50354 .89681 L
s
.73933 .40644 m
.74235 .40865 L
s
.65705 .42895 m
.66067 .43895 L
s
.5817 .43692 m
.5854 .44904 L
s
.57832 .44368 m
.5817 .43692 L
s
.57163 .61786 m
.57457 .5777 L
s
.58655 .50088 m
.59007 .50385 L
s
.52757 .47172 m
.53127 .4926 L
s
.52385 .48901 m
.52757 .47172 L
s
.46532 .60343 m
.46783 .67934 L
s
.56251 .49968 m
.56681 .55684 L
s
.44936 .60572 m
.45423 .56953 L
s
.44585 .50262 m
.44915 .52964 L
s
.44121 .52497 m
.44585 .50262 L
s
.35559 .63779 m
.35972 .64126 L
s
.82847 .39729 m
.83155 .40295 L
s
.36011 .69666 m
.36439 .69689 L
s
.65342 .41896 m
.65705 .42895 L
s
.80098 .39423 m
.80405 .39915 L
s
.81464 .39489 m
.81784 .40146 L
s
.53594 .54049 m
.53966 .55786 L
s
.62039 .47806 m
.62443 .50028 L
s
.55087 .60596 m
.55442 .59844 L
s
.36575 .62756 m
.36973 .63353 L
s
.88033 .3975 m
.88316 .40196 L
s
.44507 .62482 m
.44786 .6732 L
s
.65012 .41679 m
.65342 .41896 L
s
.78734 .39387 m
.79037 .398 L
s
.76366 .40425 m
.76654 .40568 L
s
.72538 .40226 m
.72884 .41036 L
s
.54704 .57709 m
.55087 .60596 L
s
.70562 .42837 m
.70866 .42914 L
s
.83907 .39265 m
.84197 .39677 L
s
.86659 .39596 m
.86958 .40143 L
s
.69531 .43461 m
.69858 .43872 L
s
.40191 .69574 m
.40554 .70916 L
s
.3979 .69204 m
.40191 .69574 L
s
.23604 .39138 m
.24045 .39588 L
s
.58277 .48559 m
.58655 .50088 L
s
.5792 .48083 m
.58277 .48559 L
s
.57564 .62666 m
.57962 .65482 L
s
.5983 .4117 m
.60211 .42787 L
s
.59535 .43205 m
.5983 .4117 L
s
.63673 .42629 m
.63971 .41867 L
s
.8529 .39489 m
.85587 .39992 L
s
.47904 .72177 m
.48371 .6665 L
s
.44254 .82441 m
.44501 .88764 L
s
.63704 .4521 m
.64075 .46389 L
s
.5177 .66005 m
.52142 .6627 L
s
.40554 .70916 m
.40882 .73238 L
s
.89106 .39311 m
.89375 .3966 L
s
.67764 .41831 m
.6812 .42721 L
s
.66024 .40712 m
.6637 .41352 L
s
.53127 .4926 m
.53497 .50166 L
s
.81169 .39099 m
.81464 .39489 L
s
.82536 .39149 m
.82847 .39729 L
s
.63478 .49699 m
.63807 .49703 L
s
.72187 .39348 m
.72538 .40226 L
s
.67383 .40467 m
.67764 .41831 L
s
.67062 .40299 m
.67383 .40467 L
s
.77412 .39878 m
.77694 .39993 L
s
.61248 .42698 m
.61587 .42798 L
s
.62697 .46266 m
.631 .48356 L
s
.36165 .62375 m
.36575 .62756 L
s
.7122 .4099 m
.7153 .41203 L
s
.35138 .63531 m
.35559 .63779 L
s
.79804 .39074 m
.80098 .39423 L
s
.394 .8565 m
.39828 .85345 L
s
.73625 .40347 m
.73933 .40644 L
s
.74999 .40424 m
.75316 .40881 L
s
.59256 .46282 m
.59569 .44857 L
s
.60211 .42787 m
.60588 .44187 L
s
.87743 .39261 m
.88033 .3975 L
s
.68778 .40941 m
.69177 .426 L
s
.68413 .39879 m
.68778 .40941 L
s
.71879 .39135 m
.72187 .39348 L
s
.86358 .39036 m
.86659 .39596 L
s
.78445 .39151 m
.78734 .39387 L
s
.68072 .39292 m
.68413 .39879 L
s
.62443 .50028 m
.62811 .51086 L
s
.57587 .49209 m
.5792 .48083 L
s
.35584 .69565 m
.36011 .69666 L
s
.39365 .69354 m
.3979 .69204 L
s
.84984 .38912 m
.8529 .39489 L
s
.83607 .38766 m
.83907 .39265 L
s
.69177 .426 m
.69531 .43461 L
s
.23162 .38685 m
.23604 .39138 L
s
.65689 .40369 m
.66024 .40712 L
s
.51479 .74669 m
.5187 .70164 L
s
.64703 .42022 m
.65012 .41679 L
s
.82238 .38709 m
.82536 .39149 L
s
.76058 .40045 m
.76366 .40425 L
s
.56765 .73387 m
.57143 .75071 L
s
.51381 .69316 m
.5177 .66005 L
s
.47788 .57681 m
.48088 .63737 L
s
.47293 .63844 m
.47788 .57681 L
s
.88825 .38877 m
.89106 .39311 L
s
.80881 .38792 m
.81169 .39099 L
s
.70212 .4204 m
.70562 .42837 L
s
.35745 .62119 m
.36165 .62375 L
s
.51644 .45209 m
.52009 .49107 L
s
.51261 .46548 m
.51644 .45209 L
s
.52112 .51965 m
.52485 .51937 L
s
.56152 .64068 m
.56468 .60301 L
s
.42888 .54791 m
.43084 .6171 L
s
.44915 .52964 m
.45176 .58729 L
s
.62317 .43434 m
.62628 .42731 L
s
.7466 .39681 m
.74999 .40424 L
s
.87448 .3874 m
.87743 .39261 L
s
.67767 .39396 m
.68072 .39292 L
s
.86064 .38544 m
.86358 .39036 L
s
.631 .48356 m
.63478 .49699 L
s
.40882 .73238 m
.41195 .7606 L
s
.79497 .38612 m
.79804 .39074 L
s
.34712 .63328 m
.35138 .63531 L
s
.66734 .40049 m
.67062 .40299 L
s
.70876 .40276 m
.7122 .4099 L
s
.42297 .80123 m
.42735 .79127 L
s
.84685 .38403 m
.84984 .38912 L
s
.69836 .40801 m
.70212 .4204 L
s
.6947 .39721 m
.69836 .40801 L
s
.54151 .50636 m
.54515 .50345 L
s
.73295 .39781 m
.73625 .40347 L
s
.77125 .39724 m
.77412 .39878 L
s
.60932 .43507 m
.61248 .42698 L
s
.57498 .4549 m
.57832 .44368 L
s
.51543 .41129 m
.51906 .45836 L
s
.51148 .44691 m
.51543 .41129 L
s
.83311 .3832 m
.83607 .38766 L
s
.69126 .39049 m
.6947 .39721 L
s
.56588 .51841 m
.56917 .49738 L
s
.4585 .64389 m
.46181 .67577 L
s
.50638 .86645 m
.51052 .80636 L
s
.22718 .38231 m
.23162 .38685 L
s
.71549 .38618 m
.71879 .39135 L
s
.78162 .39 m
.78445 .39151 L
s
.81949 .38362 m
.82238 .38709 L
s
.65375 .40526 m
.65689 .40369 L
s
.74325 .39022 m
.7466 .39681 L
s
.51176 .61145 m
.51569 .57854 L
s
.35159 .69387 m
.35584 .69565 L
s
.56675 .69772 m
.57074 .72906 L
s
.56316 .69749 m
.56675 .69772 L
s
.53674 .44003 m
.54052 .46467 L
s
.53306 .44445 m
.53674 .44003 L
s
.38966 .8602 m
.394 .8565 L
s
.70505 .3913 m
.70876 .40276 L
s
.75746 .39635 m
.76058 .40045 L
s
.70173 .38615 m
.70505 .3913 L
s
.88532 .38349 m
.88825 .38877 L
s
.58144 .74812 m
.58437 .71245 L
s
.55932 .67534 m
.56316 .69749 L
s
.54618 .55277 m
.55009 .58999 L
s
.87148 .3818 m
.87448 .3874 L
s
.5303 .46257 m
.53407 .49248 L
s
.85766 .38036 m
.86064 .38544 L
s
.80588 .38449 m
.80881 .38792 L
s
.35325 .61828 m
.35745 .62119 L
s
.68825 .39171 m
.69126 .39049 L
s
.38943 .69364 m
.39365 .69354 L
s
.60148 .39793 m
.60565 .42608 L
s
.59831 .40843 m
.60148 .39793 L
s
.72951 .39016 m
.73295 .39781 L
s
.79183 .38088 m
.79497 .38612 L
s
.52714 .92588 m
.53083 .7938 L
s
.84391 .37959 m
.84685 .38403 L
s
.63365 .43243 m
.63673 .42629 L
s
.45142 .69237 m
.45564 .68286 L
s
.74007 .38588 m
.74325 .39022 L
s
.8303 .38032 m
.83311 .3832 L
s
.34286 .63097 m
.34712 .63328 L
s
.71224 .38199 m
.71549 .38618 L
s
.22271 .37774 m
.22718 .38231 L
s
.66377 .39214 m
.66734 .40049 L
s
.56583 .65966 m
.57049 .74007 L
s
.64392 .42384 m
.64703 .42022 L
s
.72611 .38323 m
.72951 .39016 L
s
.76812 .39269 m
.77125 .39724 L
s
.88235 .37804 m
.88532 .38349 L
s
.81657 .38006 m
.81949 .38362 L
s
.6986 .38461 m
.70173 .38615 L
s
.52009 .49107 m
.52385 .48901 L
s
.57912 .80919 m
.58177 .75246 L
s
.86852 .37663 m
.87148 .3818 L
s
.67468 .39692 m
.67767 .39396 L
s
.75414 .39 m
.75746 .39635 L
s
.66018 .38341 m
.66377 .39214 L
s
.46181 .67577 m
.4657 .67919 L
s
.85473 .37573 m
.85766 .38036 L
s
.77862 .3867 m
.78162 .39 L
s
.34732 .69182 m
.35159 .69387 L
s
.78896 .37871 m
.79183 .38088 L
s
.41993 .49573 m
.42183 .56121 L
s
.84108 .37619 m
.84391 .37959 L
s
.34908 .61431 m
.35325 .61828 L
s
.80283 .38 m
.80588 .38449 L
s
.41195 .7606 m
.41522 .78587 L
s
.53779 .49854 m
.54151 .50636 L
s
.45889 .62965 m
.46366 .59313 L
s
.44313 .78508 m
.44899 .71235 L
s
.43005 .48859 m
.43317 .52029 L
s
.42584 .49123 m
.43005 .48859 L
s
.72288 .37904 m
.72611 .38323 L
s
.657 .38398 m
.66018 .38341 L
s
.73676 .38013 m
.74007 .38588 L
s
.57073 .58086 m
.57412 .5685 L
s
.21822 .37316 m
.22271 .37774 L
s
.45516 .5268 m
.45825 .56779 L
s
.45098 .53338 m
.45516 .5268 L
s
.65055 .40627 m
.65375 .40526 L
s
.70929 .38274 m
.71224 .38199 L
s
.46423 .84022 m
.46862 .8166 L
s
.5725 .50437 m
.57587 .49209 L
s
.43676 .53788 m
.44121 .52497 L
s
.61569 .41056 m
.61969 .43046 L
s
.61212 .40437 m
.61569 .41056 L
s
.55193 .52407 m
.55546 .51122 L
s
.38546 .68737 m
.38943 .69364 L
s
.54052 .46467 m
.5444 .50071 L
s
.41131 .43219 m
.4144 .46121 L
s
.40347 .52207 m
.41131 .43219 L
s
.44993 .75903 m
.45313 .79485 L
s
.4459 .75939 m
.44993 .75903 L
s
.82745 .37717 m
.8303 .38032 L
s
.61969 .43046 m
.62317 .43434 L
s
.33859 .6282 m
.34286 .63097 L
s
.87942 .37296 m
.88235 .37804 L
s
.75062 .38114 m
.75414 .39 L
s
.58898 .45834 m
.59256 .46282 L
s
.38527 .86439 m
.38966 .8602 L
s
.76471 .38502 m
.76812 .39269 L
s
.42563 .57298 m
.43096 .53598 L
s
.53407 .49248 m
.53779 .49854 L
s
.86561 .37202 m
.86852 .37663 L
s
.37816 .66001 m
.38176 .67467 L
s
.37442 .64844 m
.37816 .66001 L
s
.37043 .64192 m
.37442 .64844 L
s
.68477 .3847 m
.68825 .39171 L
s
.81361 .37623 m
.81657 .38006 L
s
.41888 .80045 m
.42297 .80123 L
s
.58513 .44122 m
.58898 .45834 L
s
.58141 .43042 m
.58513 .44122 L
s
.52932 .43212 m
.53306 .44445 L
s
.52558 .43466 m
.52932 .43212 L
s
.59195 .43566 m
.59535 .43205 L
s
.85185 .37169 m
.85473 .37573 L
s
.44786 .6732 m
.45142 .69237 L
s
.57801 .43863 m
.58141 .43042 L
s
.42554 .73168 m
.43289 .62696 L
s
.60565 .42608 m
.60932 .43507 L
s
.74722 .37386 m
.75062 .38114 L
s
.44209 .57394 m
.44522 .60878 L
s
.38176 .67467 m
.38546 .68737 L
s
.77546 .38176 m
.77862 .3867 L
s
.6956 .38574 m
.6986 .38461 L
s
.34491 .60995 m
.34908 .61431 L
s
.79962 .37392 m
.80283 .38 L
s
.73349 .37494 m
.73676 .38013 L
s
.34302 .69 m
.34732 .69182 L
s
.76135 .37807 m
.76471 .38502 L
s
.57074 .72906 m
.57517 .78752 L
s
.6186 .38329 m
.62262 .40355 L
s
.61545 .39103 m
.6186 .38329 L
s
.60855 .39877 m
.61212 .40437 L
s
.50848 .52072 m
.51261 .46548 L
s
.83823 .37282 m
.84108 .37619 L
s
.78596 .37532 m
.78896 .37871 L
s
.71988 .37847 m
.72288 .37904 L
s
.54704 .44977 m
.5509 .47652 L
s
.54332 .44371 m
.54704 .44977 L
s
.51055 .60791 m
.51461 .55509 L
s
.36627 .63849 m
.37043 .64192 L
s
.21371 .36855 m
.21822 .37316 L
s
.57149 .45988 m
.57498 .4549 L
s
.6814 .38009 m
.68477 .3847 L
s
.87653 .36832 m
.87942 .37296 L
s
.60468 .38275 m
.60855 .39877 L
s
.60169 .40019 m
.60468 .38275 L
s
.63013 .42698 m
.63365 .43243 L
s
.74409 .37027 m
.74722 .37386 L
s
.51906 .45836 m
.52284 .45861 L
s
.64054 .42173 m
.64392 .42384 L
s
.8627 .3675 m
.86561 .37202 L
s
.33429 .62553 m
.33859 .6282 L
s
.82445 .37262 m
.82745 .37717 L
s
.41522 .78587 m
.41888 .80045 L
s
.67133 .3931 m
.67468 .39692 L
s
.75801 .37143 m
.76135 .37807 L
s
.56681 .55684 m
.57073 .58086 L
s
.81059 .3719 m
.81361 .37623 L
s
.79638 .36763 m
.79962 .37392 L
s
.84905 .3684 m
.85185 .37169 L
s
.65377 .38409 m
.657 .38398 L
s
.43984 .83727 m
.4459 .75939 L
s
.77209 .37454 m
.77546 .38176 L
s
.73037 .37216 m
.73349 .37494 L
s
.34069 .6062 m
.34491 .60995 L
s
.59499 .41505 m
.59831 .40843 L
s
.53962 .44313 m
.54332 .44371 L
s
.44522 .60878 m
.44936 .60572 L
s
.64715 .40297 m
.65055 .40627 L
s
.70626 .38264 m
.70929 .38274 L
s
.42082 .51595 m
.42584 .49123 L
s
.55009 .58999 m
.55388 .60591 L
s
.51651 .67866 m
.52035 .66291 L
s
.20918 .36391 m
.21371 .36855 L
s
.33867 .68852 m
.34302 .69 L
s
.62638 .41544 m
.63013 .42698 L
s
.62262 .40355 m
.62638 .41544 L
s
.36211 .63451 m
.36627 .63849 L
s
.67828 .38038 m
.6814 .38009 L
s
.83534 .36913 m
.83823 .37282 L
s
.78271 .36918 m
.78596 .37532 L
s
.87369 .36415 m
.87653 .36832 L
s
.49159 .78196 m
.49476 .85588 L
s
.38082 .86883 m
.38527 .86439 L
s
.56827 .6361 m
.57163 .61786 L
s
.75479 .36651 m
.75801 .37143 L
s
.50908 .63007 m
.51275 .66086 L
s
.50527 .62693 m
.50908 .63007 L
s
.76858 .36578 m
.77209 .37454 L
s
.85982 .36328 m
.8627 .3675 L
s
.79333 .36354 m
.79638 .36763 L
s
.74076 .36428 m
.74409 .37027 L
s
.56242 .53103 m
.56588 .51841 L
s
.82133 .36717 m
.82445 .37262 L
s
.44501 .88764 m
.44725 .96614 L
s
.55388 .60591 m
.55775 .62838 L
s
.52178 .44551 m
.52558 .43466 L
s
.44667 .54274 m
.45098 .53338 L
s
.58817 .42292 m
.59195 .43566 L
s
.58447 .41427 m
.58817 .42292 L
s
.32992 .62358 m
.33429 .62553 L
s
.71679 .37686 m
.71988 .37847 L
s
.4144 .46121 m
.41676 .51153 L
s
.69236 .38297 m
.6956 .38574 L
s
.46316 1.00133 m
.46927 .88161 L
s
.66769 .38383 m
.67133 .3931 L
s
.43317 .52029 m
.43676 .53788 L
s
.80745 .36653 m
.81059 .3719 L
s
.55665 .57438 m
.5608 .6222 L
s
.63692 .41371 m
.64054 .42173 L
s
.62928 .38695 m
.63304 .39871 L
s
.62581 .38343 m
.62928 .38695 L
s
.63304 .39871 m
.63692 .41371 L
s
.76544 .36146 m
.76858 .36578 L
s
.3364 .60329 m
.34069 .6062 L
s
.8462 .36488 m
.84905 .3684 L
s
.77943 .36296 m
.78271 .36918 L
s
.58106 .42146 m
.58447 .41427 L
s
.66407 .37508 m
.66769 .38383 L
s
.51429 .403 m
.51804 .41893 L
s
.51019 .45361 m
.51429 .403 L
s
.72728 .37016 m
.73037 .37216 L
s
.64351 .39408 m
.64715 .40297 L
s
.43421 .64293 m
.43886 .62425 L
s
.20463 .35926 m
.20918 .36391 L
s
.5509 .47652 m
.55488 .51096 L
s
.35806 .62811 m
.36211 .63451 L
s
.50961 .76737 m
.51381 .69316 L
s
.51704 .37141 m
.52076 .40859 L
s
.51301 .41922 m
.51704 .37141 L
s
.45313 .79485 m
.45643 .82871 L
s
.52833 .40672 m
.53211 .42649 L
s
.52455 .41924 m
.52833 .40672 L
s
.75173 .36366 m
.75479 .36651 L
s
.73762 .36101 m
.74076 .36428 L
s
.8708 .35971 m
.87369 .36415 L
s
.83233 .36451 m
.83534 .36913 L
s
.81824 .36204 m
.82133 .36717 L
s
.6504 .38155 m
.65377 .38409 L
s
.5359 .44287 m
.53962 .44313 L
s
.56898 .51013 m
.5725 .50437 L
s
.50108 .6684 m
.50527 .62693 L
s
.57462 .44966 m
.57801 .43863 L
s
.5679 .4603 m
.57149 .45988 L
s
.66079 .37372 m
.66407 .37508 L
s
.33428 .68715 m
.33867 .68852 L
s
.63988 .38588 m
.64351 .39408 L
s
.85698 .35957 m
.85982 .36328 L
s
.79018 .35843 m
.79333 .36354 L
s
.54821 .51888 m
.55193 .52407 L
s
.7028 .37579 m
.70626 .38264 L
s
.5444 .50071 m
.54821 .51888 L
s
.80422 .36035 m
.80745 .36653 L
s
.6079 .36694 m
.61188 .38575 L
s
.60489 .3832 m
.6079 .36694 L
s
.51804 .41893 m
.52178 .44551 L
s
.61188 .38575 m
.61545 .39103 L
s
.55746 .4595 m
.56134 .48091 L
s
.55374 .45247 m
.55746 .4595 L
s
.77625 .35789 m
.77943 .36296 L
s
.45176 .58729 m
.45488 .62734 L
s
.46783 .67934 m
.47092 .73103 L
s
.35407 .62033 m
.35806 .62811 L
s
.48088 .63737 m
.48263 .80292 L
s
.67486 .37537 m
.67828 .38038 L
s
.76236 .35811 m
.76544 .36146 L
s
.32547 .62253 m
.32992 .62358 L
s
.68861 .37159 m
.69236 .38297 L
s
.55775 .62838 m
.56152 .64068 L
s
.50423 .58616 m
.50797 .60291 L
s
.50021 .60501 m
.50423 .58616 L
s
.62224 .37771 m
.62581 .38343 L
s
.68502 .36304 m
.68861 .37159 L
s
.63635 .38041 m
.63988 .38588 L
s
.33206 .60067 m
.3364 .60329 L
s
.45825 .56779 m
.46083 .637 L
s
.84321 .36017 m
.8462 .36488 L
s
.71356 .37342 m
.71679 .37686 L
s
.40923 .41503 m
.41187 .45622 L
s
.40294 .46408 m
.40923 .41503 L
s
.20005 .35458 m
.20463 .35926 L
s
.50797 .60291 m
.51176 .61145 L
s
.37633 .87321 m
.38082 .86883 L
s
.6994 .37026 m
.7028 .37579 L
s
.51089 .76083 m
.51479 .74669 L
s
.81514 .35696 m
.81824 .36204 L
s
.86781 .35451 m
.8708 .35971 L
s
.82919 .35866 m
.83233 .36451 L
s
.53211 .42649 m
.5359 .44287 L
s
.55006 .45255 m
.55374 .45247 L
s
.35004 .61327 m
.35407 .62033 L
s
.80106 .35492 m
.80422 .36035 L
s
.59123 .40408 m
.59499 .41505 L
s
.68191 .36345 m
.68502 .36304 L
s
.43553 .5003 m
.43927 .51354 L
s
.43165 .49201 m
.43553 .5003 L
s
.72413 .36742 m
.72728 .37016 L
s
.78708 .3541 m
.79018 .35843 L
s
.46013 .84499 m
.46423 .84022 L
s
.73451 .3584 m
.73762 .36101 L
s
.57811 .76433 m
.58144 .74812 L
s
.7485 .3589 m
.75173 .36366 L
s
.58748 .39357 m
.59123 .40408 L
s
.50735 .49204 m
.51148 .44691 L
s
.43927 .51354 m
.44283 .53311 L
s
.85411 .35575 m
.85698 .35957 L
s
.64701 .37913 m
.6504 .38155 L
s
.47469 .74583 m
.47904 .72177 L
s
.77326 .35528 m
.77625 .35789 L
s
.58407 .39991 m
.58748 .39357 L
s
.51275 .66086 m
.51651 .67866 L
s
.32987 .68563 m
.33428 .68715 L
s
.61896 .38144 m
.62224 .37771 L
s
.67125 .36689 m
.67486 .37537 L
s
.42789 .47964 m
.43165 .49201 L
s
.42391 .47373 m
.42789 .47964 L
s
.633 .38017 m
.63635 .38041 L
s
.65755 .37377 m
.66079 .37372 L
s
.50567 .55466 m
.50971 .52794 L
s
.34589 .60777 m
.35004 .61327 L
s
.56134 .48091 m
.56525 .5026 L
s
.84014 .35488 m
.84321 .36017 L
s
.75938 .3561 m
.76236 .35811 L
s
.69594 .36383 m
.6994 .37026 L
s
.56427 .46049 m
.5679 .4603 L
s
.19545 .34987 m
.20005 .35458 L
s
.82597 .35223 m
.82919 .35866 L
s
.3277 .5978 m
.33206 .60067 L
s
.43084 .6171 m
.43421 .64293 L
s
.71013 .36708 m
.71356 .37342 L
s
.86494 .35035 m
.86781 .35451 L
s
.81198 .35138 m
.81514 .35696 L
s
.32094 .62207 m
.32547 .62253 L
s
.66786 .36307 m
.67125 .36689 L
s
.79794 .35012 m
.80106 .35492 L
s
.59829 .40402 m
.60169 .40019 L
s
.44283 .53311 m
.44667 .54274 L
s
.48779 .84905 m
.49307 .73031 L
s
.78404 .35059 m
.78708 .3541 L
s
.74512 .35248 m
.7485 .3589 L
s
.47414 .67186 m
.47619 .79813 L
s
.41936 .48336 m
.42391 .47373 L
s
.57762 .42932 m
.58106 .42146 L
s
.72072 .36121 m
.72413 .36742 L
s
.55874 .52982 m
.56242 .53103 L
s
.85111 .35085 m
.85411 .35575 L
s
.73131 .35479 m
.73451 .3584 L
s
.56525 .5026 m
.56898 .51013 L
s
.51976 .35644 m
.52352 .39421 L
s
.51578 .3962 m
.51976 .35644 L
s
.34168 .60309 m
.34589 .60777 L
s
.6922 .35287 m
.69594 .36383 L
s
.82287 .3471 m
.82597 .35223 L
s
.45643 .82871 m
.46013 .84499 L
s
.83702 .34925 m
.84014 .35488 L
s
.68917 .35436 m
.6922 .35287 L
s
.5463 .4455 m
.55006 .45255 L
s
.70641 .35633 m
.71013 .36708 L
s
.64361 .37675 m
.64701 .37913 L
s
.77007 .35054 m
.77326 .35528 L
s
.41099 .70177 m
.41926 .58832 L
s
.32544 .68404 m
.32987 .68563 L
s
.54249 .42963 m
.5463 .4455 L
s
.5387 .4188 m
.54249 .42963 L
s
.19082 .34515 m
.19545 .34987 L
s
.80887 .34647 m
.81198 .35138 L
s
.67841 .35725 m
.68191 .36345 L
s
.70312 .35273 m
.70641 .35633 L
s
.37182 .87728 m
.37633 .87321 L
s
.56464 .63715 m
.56827 .6361 L
s
.53112 .39466 m
.53491 .40763 L
s
.52734 .40278 m
.53112 .39466 L
s
.55488 .51096 m
.55874 .52982 L
s
.45488 .62734 m
.45889 .62965 L
s
.53491 .40763 m
.5387 .4188 L
s
.74178 .34657 m
.74512 .35248 L
s
.79498 .34713 m
.79794 .35012 L
s
.86202 .34596 m
.86494 .35035 L
s
.32335 .59465 m
.3277 .5978 L
s
.66462 .36276 m
.66786 .36307 L
s
.7562 .35195 m
.75938 .3561 L
s
.51695 1.0359 m
.52055 .86616 L
s
.62938 .37328 m
.633 .38017 L
s
.71728 .35468 m
.72072 .36121 L
s
.57107 .45417 m
.57462 .44966 L
s
.6542 .37188 m
.65755 .37377 L
s
.52076 .40859 m
.52455 .41924 L
s
.78107 .348 m
.78404 .35059 L
s
.57517 .78752 m
.57912 .80919 L
s
.84797 .34488 m
.85111 .35085 L
s
.31637 .62182 m
.32094 .62207 L
s
.33746 .59826 m
.34168 .60309 L
s
.5606 .45905 m
.56427 .46049 L
s
.50224 .90305 m
.50638 .86645 L
s
.83387 .34337 m
.83702 .34925 L
s
.41676 .51153 m
.42082 .51595 L
s
.42183 .56121 m
.42563 .57298 L
s
.81982 .34244 m
.82287 .3471 L
s
.61134 .35708 m
.61518 .37019 L
s
.60825 .36996 m
.61134 .35708 L
s
.72797 .34949 m
.73131 .35479 L
s
.67486 .35011 m
.67841 .35725 L
s
.61518 .37019 m
.61896 .38144 L
s
.76688 .34583 m
.77007 .35054 L
s
.468 .6886 m
.47293 .63844 L
s
.80586 .34264 m
.80887 .34647 L
s
.73864 .34354 m
.74178 .34657 L
s
.18618 .3404 m
.19082 .34515 L
s
.62568 .36424 m
.62938 .37328 L
s
.4415 .49945 m
.44523 .51375 L
s
.43754 .49294 m
.4415 .49945 L
s
.58065 .40862 m
.58407 .39991 L
s
.71373 .34664 m
.71728 .35468 L
s
.69956 .34476 m
.70312 .35273 L
s
.64004 .3709 m
.64361 .37675 L
s
.32095 .68279 m
.32544 .68404 L
s
.85902 .34098 m
.86202 .34596 L
s
.5608 .6222 m
.56464 .63715 L
s
.59448 .3918 m
.59829 .40402 L
s
.59072 .3816 m
.59448 .3918 L
s
.31896 .59151 m
.32335 .59465 L
s
.44523 .51375 m
.44871 .53833 L
s
.50702 .76085 m
.51089 .76083 L
s
.79194 .34351 m
.79498 .34713 L
s
.75285 .34573 m
.7562 .35195 L
s
.60143 .38454 m
.60489 .3832 L
s
.84489 .33943 m
.84797 .34488 L
s
.62224 .36342 m
.62568 .36424 L
s
.6716 .349 m
.67486 .35011 L
s
.46423 .57392 m
.46711 .635 L
s
.46036 .565 m
.46423 .57392 L
s
.33324 .59313 m
.33746 .59826 L
s
.58729 .38761 m
.59072 .3816 L
s
.83082 .33861 m
.83387 .34337 L
s
.71053 .34406 m
.71373 .34664 L
s
.54534 .40895 m
.54916 .42231 L
s
.54157 .40377 m
.54534 .40895 L
s
.6964 .34367 m
.69956 .34476 L
s
.72459 .34379 m
.72797 .34949 L
s
.68584 .35106 m
.68917 .35436 L
s
.57049 .74007 m
.57454 .76837 L
s
.81675 .33781 m
.81982 .34244 L
s
.43355 .48718 m
.43754 .49294 L
s
.49592 .6427 m
.50021 .60501 L
s
.57454 .76837 m
.57811 .76433 L
s
.65074 .36808 m
.6542 .37188 L
s
.45612 .57212 m
.46036 .565 L
s
.7779 .34331 m
.78107 .348 L
s
.76372 .34181 m
.76688 .34583 L
s
.54916 .42231 m
.553 .43781 L
s
.66128 .36076 m
.66462 .36276 L
s
.36728 .88101 m
.37182 .87728 L
s
.41187 .45622 m
.41505 .485 L
s
.18151 .33562 m
.18618 .3404 L
s
.55683 .45129 m
.5606 .45905 L
s
.63647 .36513 m
.64004 .3709 L
s
.31176 .6216 m
.31637 .62182 L
s
.80284 .3389 m
.80586 .34264 L
s
.57403 .43074 m
.57762 .42932 L
s
.74945 .3391 m
.75285 .34573 L
s
.85594 .33544 m
.85902 .34098 L
s
.73543 .33987 m
.73864 .34354 L
s
.84186 .33462 m
.84489 .33943 L
s
.553 .43781 m
.55683 .45129 L
s
.41505 .485 m
.41936 .48336 L
s
.32899 .58812 m
.33324 .59313 L
s
.42596 .46203 m
.42969 .47664 L
s
.42197 .45517 m
.42596 .46203 L
s
.61831 .3479 m
.62224 .36342 L
s
.61496 .35095 m
.61831 .3479 L
s
.31453 .58863 m
.31896 .59151 L
s
.82777 .33384 m
.83082 .33861 L
s
.78878 .33869 m
.79194 .34351 L
s
.31639 .68235 m
.32095 .68279 L
s
.42969 .47664 m
.43355 .48718 L
s
.7213 .33949 m
.72459 .34379 L
s
.53777 .39472 m
.54157 .40377 L
s
.56738 .45095 m
.57107 .45417 L
s
.47092 .73103 m
.47469 .74583 L
s
.81374 .3339 m
.81675 .33781 L
s
.52352 .39421 m
.52734 .40278 L
s
.50273 .81547 m
.50702 .76085 L
s
.53395 .38174 m
.53777 .39472 L
s
.53015 .38517 m
.53395 .38174 L
s
.7745 .33619 m
.7779 .34331 L
s
.63267 .35368 m
.63647 .36513 L
s
.68222 .3429 m
.68584 .35106 L
s
.74622 .33485 m
.74945 .3391 L
s
.62918 .35084 m
.63267 .35368 L
s
.7072 .33985 m
.71053 .34406 L
s
.64712 .36082 m
.65074 .36808 L
s
.66833 .348 m
.6716 .349 L
s
.76044 .33641 m
.76372 .34181 L
s
.17682 .33083 m
.18151 .33562 L
s
.44871 .53833 m
.45223 .56291 L
s
.41755 .45979 m
.42197 .45517 L
s
.85294 .33064 m
.85594 .33544 L
s
.5225 .3481 m
.52632 .37461 L
s
.51856 .38051 m
.5225 .3481 L
s
.5976 .37221 m
.60143 .38454 L
s
.59394 .36681 m
.5976 .37221 L
s
.69321 .34263 m
.6964 .34367 L
s
.79978 .33487 m
.80284 .3389 L
s
.6578 .35626 m
.66128 .36076 L
s
.32469 .58352 m
.32899 .58812 L
s
.49806 .52586 m
.50187 .53916 L
s
.49382 .55419 m
.49806 .52586 L
s
.8389 .33056 m
.84186 .33462 L
s
.40661 .40946 m
.41006 .43087 L
s
.40063 .44869 m
.40661 .40946 L
s
.73216 .33559 m
.73543 .33987 L
s
.50657 .62024 m
.51055 .60791 L
s
.67874 .33724 m
.68222 .3429 L
s
.50187 .53916 m
.50567 .55466 L
s
.77126 .33102 m
.7745 .33619 L
s
.82468 .32891 m
.82777 .33384 L
s
.7856 .33382 m
.78878 .33869 L
s
.30713 .62128 m
.31176 .6216 L
s
.64348 .35339 m
.64712 .36082 L
s
.49476 .85588 m
.49832 .90001 L
s
.31005 .58609 m
.31453 .58863 L
s
.71799 .33523 m
.7213 .33949 L
s
.36271 .88455 m
.36728 .88101 L
s
.56357 .44082 m
.56738 .45095 L
s
.55973 .42706 m
.56357 .44082 L
s
.5559 .41531 m
.55973 .42706 L
s
.5521 .40583 m
.5559 .41531 L
s
.50444 .53857 m
.50848 .52072 L
s
.81068 .32959 m
.81374 .3339 L
s
.75709 .33033 m
.76044 .33641 L
s
.57708 .41174 m
.58065 .40862 L
s
.58383 .39452 m
.58729 .38761 L
s
.1721 .32601 m
.17682 .33083 L
s
.57031 .42607 m
.57403 .43074 L
s
.31172 .68295 m
.31639 .68235 L
s
.74305 .33152 m
.74622 .33485 L
s
.7036 .33153 m
.7072 .33985 L
s
.49903 .57734 m
.50281 .59579 L
s
.49482 .6036 m
.49903 .57734 L
s
.4966 .72787 m
.50108 .6684 L
s
.59053 .37371 m
.59394 .36681 L
s
.84996 .32612 m
.85294 .33064 L
s
.54828 .39609 m
.5521 .40583 L
s
.44725 .96614 m
.44963 1.04552 L
s
.60465 .36665 m
.60825 .36996 L
s
.6256 .34621 m
.62918 .35084 L
s
.32035 .57926 m
.32469 .58352 L
s
.63986 .34676 m
.64348 .35339 L
s
.43748 .84186 m
.44313 .78508 L
s
.65423 .35031 m
.6578 .35626 L
s
.45223 .56291 m
.45612 .57212 L
s
.67549 .3365 m
.67874 .33724 L
s
.79652 .32893 m
.79978 .33487 L
s
.37721 .70701 m
.38075 .72562 L
s
.37315 .6999 m
.37721 .70701 L
s
.83589 .32609 m
.8389 .33056 L
s
.72895 .33233 m
.73216 .33559 L
s
.76808 .32676 m
.77126 .33102 L
s
.66492 .34484 m
.66833 .348 L
s
.54448 .38845 m
.54828 .39609 L
s
.8216 .32421 m
.82468 .32891 L
s
.70048 .33133 m
.7036 .33153 L
s
.78225 .32718 m
.7856 .33382 L
s
.61166 .35694 m
.61496 .35095 L
s
.41006 .43087 m
.41338 .45658 L
s
.75387 .32606 m
.75709 .33033 L
s
.71475 .33229 m
.71799 .33523 L
s
.68969 .33604 m
.69321 .34263 L
s
.62166 .33117 m
.6256 .34621 L
s
.61855 .34161 m
.62166 .33117 L
s
.30552 .5839 m
.31005 .58609 L
s
.50281 .59579 m
.50657 .62024 L
s
.80756 .32485 m
.81068 .32959 L
s
.52632 .37461 m
.53015 .38517 L
s
.6362 .33933 m
.63986 .34676 L
s
.56653 .41841 m
.57031 .42607 L
s
.16736 .32116 m
.1721 .32601 L
s
.36901 .69404 m
.37315 .6999 L
s
.30247 .62074 m
.30713 .62128 L
s
.54064 .37688 m
.54448 .38845 L
s
.43576 .47275 m
.43957 .48572 L
s
.43183 .46394 m
.43576 .47275 L
s
.35776 .6528 m
.36146 .66747 L
s
.35387 .6417 m
.35776 .6528 L
s
.65062 .34346 m
.65423 .35031 L
s
.53682 .36782 m
.54064 .37688 L
s
.84702 .32208 m
.84996 .32612 L
s
.79329 .32343 m
.79652 .32893 L
s
.31597 .57517 m
.32035 .57926 L
s
.7398 .32746 m
.74305 .33152 L
s
.38075 .72562 m
.38366 .75897 L
s
.40099 .65711 m
.40914 .56001 L
s
.34984 .63316 m
.35387 .6417 L
s
.43957 .48572 m
.44334 .50049 L
s
.46083 .637 m
.46392 .6871 L
s
.77899 .32179 m
.78225 .32718 L
s
.41338 .45658 m
.41755 .45979 L
s
.6008 .35411 m
.60465 .36665 L
s
.59725 .35397 m
.6008 .35411 L
s
.50896 .44275 m
.51301 .41922 L
s
.36146 .66747 m
.36513 .68284 L
s
.50615 .47172 m
.51019 .45361 L
s
.83278 .32085 m
.83589 .32609 L
s
.68608 .32819 m
.68969 .33604 L
s
.42792 .45397 m
.43183 .46394 L
s
.533 .3692 m
.53682 .36782 L
s
.81854 .31982 m
.8216 .32421 L
s
.3581 .88805 m
.36271 .88455 L
s
.76476 .32095 m
.76808 .32676 L
s
.44719 .51217 m
.45103 .52432 L
s
.44334 .50049 m
.44719 .51217 L
s
.30694 .68465 m
.31172 .68295 L
s
.56273 .40969 m
.56653 .41841 L
s
.45103 .52432 m
.45463 .54658 L
s
.63277 .33848 m
.6362 .33933 L
s
.34578 .62488 m
.34984 .63316 L
s
.72552 .32626 m
.72895 .33233 L
s
.66144 .3405 m
.66492 .34484 L
s
.36513 .68284 m
.36901 .69404 L
s
.7507 .32254 m
.75387 .32606 L
s
.42404 .44284 m
.42792 .45397 L
s
.64708 .33883 m
.65062 .34346 L
s
.67216 .33457 m
.67549 .3365 L
s
.41992 .43833 m
.42404 .44284 L
s
.57338 .40896 m
.57708 .41174 L
s
.80433 .31919 m
.80756 .32485 L
s
.71112 .32349 m
.71475 .33229 L
s
.1626 .31629 m
.16736 .32116 L
s
.55891 .40024 m
.56273 .40969 L
s
.68277 .32592 m
.68608 .32819 L
s
.50339 .49499 m
.50735 .49204 L
s
.79004 .31786 m
.79329 .32343 L
s
.30093 .58208 m
.30552 .5839 L
s
.34175 .616 m
.34578 .62488 L
s
.6971 .32698 m
.70048 .33133 L
s
.39582 .52834 m
.40294 .46408 L
s
.77587 .318 m
.77899 .32179 L
s
.31156 .57125 m
.31597 .57517 L
s
.844 .31747 m
.84702 .32208 L
s
.73653 .32324 m
.7398 .32746 L
s
.49832 .90001 m
.50224 .90305 L
s
.55507 .38931 m
.55891 .40024 L
s
.76153 .31643 m
.76476 .32095 L
s
.82961 .31524 m
.83278 .32085 L
s
.70781 .31997 m
.71112 .32349 L
s
.72222 .32221 m
.72552 .32626 L
s
.29781 .61985 m
.30247 .62074 L
s
.43143 .99377 m
.43984 .83727 L
s
.55123 .37894 m
.55507 .38931 L
s
.3377 .60721 m
.34175 .616 L
s
.58022 .39522 m
.58383 .39452 L
s
.81542 .31494 m
.81854 .31982 L
s
.58702 .37829 m
.59053 .37371 L
s
.50064 .51843 m
.50444 .53857 L
s
.49677 .50791 m
.50064 .51843 L
s
.40332 .81021 m
.40657 .83911 L
s
.39868 .81853 m
.40332 .81021 L
s
.54741 .37075 m
.55123 .37894 L
s
.65788 .33483 m
.66144 .3405 L
s
.51177 .41714 m
.51578 .3962 L
s
.80114 .31394 m
.80433 .31919 L
s
.52914 .35337 m
.533 .3692 L
s
.52528 .3426 m
.52914 .35337 L
s
.64339 .33078 m
.64708 .33883 L
s
.49242 .54073 m
.49677 .50791 L
s
.45463 .54658 m
.45802 .57992 L
s
.41566 .43723 m
.41992 .43833 L
s
.33359 .59926 m
.3377 .60721 L
s
.59383 .36061 m
.59725 .35397 L
s
.74745 .31829 m
.7507 .32254 L
s
.49959 .47481 m
.50339 .49499 L
s
.49548 .48724 m
.49959 .47481 L
s
.15781 .31139 m
.1626 .31629 L
s
.78686 .3131 m
.79004 .31786 L
s
.52136 .36743 m
.52528 .3426 L
s
.60789 .3481 m
.61166 .35694 L
s
.4083 .4036 m
.41179 .42516 L
s
.40364 .41074 m
.4083 .4036 L
s
.62891 .32628 m
.63277 .33848 L
s
.62542 .325 m
.62891 .32628 L
s
.5696 .40175 m
.57338 .40896 L
s
.69349 .31917 m
.6971 .32698 L
s
.30711 .56751 m
.31156 .57125 L
s
.30204 .68741 m
.30694 .68465 L
s
.54355 .35964 m
.54741 .37075 L
s
.66872 .33093 m
.67216 .33457 L
s
.84089 .31215 m
.844 .31747 L
s
.82653 .31049 m
.82961 .31524 L
s
.77257 .31243 m
.77587 .318 L
s
.35345 .8916 m
.3581 .88805 L
s
.53973 .35498 m
.54355 .35964 L
s
.73311 .31713 m
.73653 .32324 L
s
.29628 .58057 m
.30093 .58208 L
s
.63987 .32728 m
.64339 .33078 L
s
.67947 .32428 m
.68277 .32592 L
s
.32942 .59207 m
.33359 .59926 L
s
.75835 .31273 m
.76153 .31643 L
s
.60411 .33875 m
.60789 .3481 L
s
.48645 .6935 m
.49009 .72529 L
s
.48197 .72715 m
.48645 .6935 L
s
.71871 .3154 m
.72222 .32221 L
s
.81227 .30991 m
.81542 .31494 L
s
.70455 .31755 m
.70781 .31997 L
s
.65432 .32953 m
.65788 .33483 L
s
.5052 .84341 m
.50961 .76737 L
s
.46711 .635 m
.46971 .71958 L
s
.39597 .59689 m
.40347 .52207 L
s
.38366 .75897 m
.38639 .79791 L
s
.79797 .30914 m
.80114 .31394 L
s
.69009 .31519 m
.69349 .31917 L
s
.60067 .34319 m
.60411 .33875 L
s
.56576 .39181 m
.5696 .40175 L
s
.29314 .61862 m
.29781 .61985 L
s
.61501 .34001 m
.61855 .34161 L
s
.15299 .30647 m
.15781 .31139 L
s
.78376 .30948 m
.78686 .3131 L
s
.74412 .31326 m
.74745 .31829 L
s
.32521 .58523 m
.32942 .59207 L
s
.4916 .67249 m
.49592 .6427 L
s
.43791 .46176 m
.44174 .47489 L
s
.43398 .4515 m
.43791 .46176 L
s
.56191 .3813 m
.56576 .39181 L
s
.72972 .31177 m
.73311 .31713 L
s
.83774 .30657 m
.84089 .31215 L
s
.44174 .47489 m
.44552 .49023 L
s
.76925 .3067 m
.77257 .31243 L
s
.57647 .39039 m
.58022 .39522 L
s
.30262 .56393 m
.30711 .56751 L
s
.71526 .30959 m
.71871 .3154 L
s
.82344 .30584 m
.82653 .31049 L
s
.43005 .4412 m
.43398 .4515 L
s
.55806 .37081 m
.56191 .3813 L
s
.41179 .42516 m
.41566 .43723 L
s
.53588 .35101 m
.53973 .35498 L
s
.53199 .33098 m
.53588 .35101 L
s
.52813 .33891 m
.53199 .33098 L
s
.66519 .32569 m
.66872 .33093 L
s
.48928 .59814 m
.49382 .55419 L
s
.80914 .30524 m
.81227 .30991 L
s
.55422 .36206 m
.55806 .37081 L
s
.65067 .32258 m
.65432 .32953 L
s
.42616 .42979 m
.43005 .4412 L
s
.63622 .32075 m
.63987 .32728 L
s
.62209 .32903 m
.62542 .325 L
s
.75512 .30853 m
.75835 .31273 L
s
.46392 .6871 m
.468 .6886 L
s
.44552 .49023 m
.44925 .50799 L
s
.42212 .42223 m
.42616 .42979 L
s
.40657 .83911 m
.40816 .91766 L
s
.32098 .57858 m
.32521 .58523 L
s
.2916 .57922 m
.29628 .58057 L
s
.50231 .45473 m
.50615 .47172 L
s
.49835 .45149 m
.50231 .45473 L
s
.79477 .30408 m
.79797 .30914 L
s
.67605 .32082 m
.67947 .32428 L
s
.49027 .65028 m
.49482 .6036 L
s
.70099 .3105 m
.70455 .31755 L
s
.58336 .3771 m
.58702 .37829 L
s
.68681 .31355 m
.69009 .31519 L
s
.14816 .30153 m
.15299 .30647 L
s
.74075 .30776 m
.74412 .31326 L
s
.55037 .35297 m
.55422 .36206 L
s
.29703 .6912 m
.30204 .68741 L
s
.3938 .83186 m
.39868 .81853 L
s
.83465 .30168 m
.83774 .30657 L
s
.76608 .30296 m
.76925 .3067 L
s
.34876 .89513 m
.35345 .8916 L
s
.72634 .30673 m
.72972 .31177 L
s
.41842 .81983 m
.42554 .73168 L
s
.78049 .30412 m
.78376 .30948 L
s
.71208 .30808 m
.71526 .30959 L
s
.51458 .3933 m
.51856 .38051 L
s
.28844 .61728 m
.29314 .61862 L
s
.57265 .382 m
.57647 .39039 L
s
.41793 .41869 m
.42212 .42223 L
s
.64704 .31616 m
.65067 .32258 L
s
.39107 .32563 m
.39298 .38054 L
s
.38239 .41129 m
.39107 .32563 L
s
.61115 .3285 m
.61501 .34001 L
s
.82034 .3012 m
.82344 .30584 L
s
.63239 .31015 m
.63622 .32075 L
s
.6616 .31964 m
.66519 .32569 L
s
.2981 .5605 m
.30262 .56393 L
s
.44925 .50799 m
.45295 .52769 L
s
.3167 .57223 m
.32098 .57858 L
s
.60757 .32692 m
.61115 .3285 L
s
.5465 .34363 m
.55037 .35297 L
s
.59027 .36268 m
.59383 .36061 L
s
.62918 .31636 m
.63239 .31015 L
s
.45802 .57992 m
.46151 .61107 L
s
.80602 .30077 m
.80914 .30524 L
s
.69749 .30465 m
.70099 .3105 L
s
.39786 .44217 m
.40364 .41074 L
s
.7518 .30348 m
.75512 .30853 L
s
.56881 .37245 m
.57265 .382 L
s
.52459 1.03074 m
.52714 .92588 L
s
.79167 .30032 m
.79477 .30408 L
s
.54267 .34046 m
.5465 .34363 L
s
.49009 .72529 m
.49335 .80018 L
s
.73735 .30213 m
.74075 .30776 L
s
.49394 .48815 m
.49835 .45149 L
s
.1433 .29656 m
.14816 .30153 L
s
.67253 .31583 m
.67605 .32082 L
s
.50507 .4305 m
.50896 .44275 L
s
.50115 .4223 m
.50507 .4305 L
s
.6435 .31243 m
.64704 .31616 L
s
.28687 .57787 m
.2916 .57922 L
s
.59719 .34745 m
.60067 .34319 L
s
.56495 .36257 m
.56881 .37245 L
s
.77714 .29798 m
.78049 .30412 L
s
.83157 .29703 m
.83465 .30168 L
s
.7228 .29956 m
.72634 .30673 L
s
.31239 .56629 m
.3167 .57223 L
s
.49889 1.02164 m
.49708 .87833 L
s
.49097 .52933 m
.49548 .48724 L
s
.39436 .49065 m
.40063 .44869 L
s
.65799 .31354 m
.6616 .31964 L
s
.76288 .29894 m
.76608 .30296 L
s
.41017 .39382 m
.41391 .40973 L
s
.4058 .39328 m
.41017 .39382 L
s
.45295 .52769 m
.45668 .54682 L
s
.68342 .3104 m
.68681 .31355 L
s
.81722 .29646 m
.82034 .3012 L
s
.57958 .3712 m
.58336 .3771 L
s
.41391 .40973 m
.41793 .41869 L
s
.56109 .35291 m
.56495 .36257 L
s
.29353 .55724 m
.2981 .5605 L
s
.69421 .30286 m
.69749 .30465 L
s
.38779 .36866 m
.39011 .41476 L
s
.37888 .45784 m
.38779 .36866 L
s
.49681 .45522 m
.50115 .4223 L
s
.28369 .6162 m
.28844 .61728 L
s
.70858 .30193 m
.71208 .30808 L
s
.80274 .29493 m
.80602 .30077 L
s
.74848 .29857 m
.7518 .30348 L
s
.55723 .34436 m
.56109 .35291 L
s
.49775 .93529 m
.50273 .81547 L
s
.71965 .29824 m
.7228 .29956 L
s
.61832 .32047 m
.62209 .32903 L
s
.73404 .29796 m
.73735 .30213 L
s
.60414 .33202 m
.60757 .32692 L
s
.44013 .44897 m
.44396 .4633 L
s
.43622 .43729 m
.44013 .44897 L
s
.30802 .56075 m
.31239 .56629 L
s
.78842 .29512 m
.79167 .30032 L
s
.34403 .89844 m
.34876 .89513 L
s
.77393 .29365 m
.77714 .29798 L
s
.43229 .42588 m
.43622 .43729 L
s
.13841 .29156 m
.1433 .29656 L
s
.38639 .79791 m
.38962 .82625 L
s
.2919 .69595 m
.29703 .6912 L
s
.66894 .30979 m
.67253 .31583 L
s
.53878 .32922 m
.54267 .34046 L
s
.42836 .4148 m
.43229 .42588 L
s
.65431 .30624 m
.65799 .31354 L
s
.82849 .29247 m
.83157 .29703 L
s
.52421 .35211 m
.52813 .33891 L
s
.44396 .4633 m
.44775 .47956 L
s
.53488 .3183 m
.53878 .32922 L
s
.50787 .40484 m
.51177 .41714 L
s
.50393 .39775 m
.50787 .40484 L
s
.42431 .40712 m
.42836 .4148 L
s
.6396 .30027 m
.6435 .31243 L
s
.63629 .30332 m
.6396 .30027 L
s
.55336 .33475 m
.55723 .34436 L
s
.45668 .54682 m
.46039 .56786 L
s
.57575 .36282 m
.57958 .3712 L
s
.61456 .31294 m
.61832 .32047 L
s
.53103 .33196 m
.53488 .3183 L
s
.75959 .29415 m
.76288 .29894 L
s
.81409 .29187 m
.81722 .29646 L
s
.4694 .631 m
.47314 .65269 L
s
.46535 .62651 m
.4694 .631 L
s
.58655 .3593 m
.59027 .36268 L
s
.28213 .57638 m
.28687 .57787 L
s
.705 .29496 m
.70858 .30193 L
s
.79962 .29074 m
.80274 .29493 L
s
.54951 .32882 m
.55336 .33475 L
s
.28892 .55424 m
.29353 .55724 L
s
.67993 .30579 m
.68342 .3104 L
s
.46094 1.0469 m
.46316 1.00133 L
s
.45028 1.05975 m
.44963 1.04552 L
s
.74509 .29293 m
.74848 .29857 L
s
.44775 .47956 m
.45151 .49748 L
s
.6508 .30281 m
.65431 .30624 L
s
.30362 .55546 m
.30802 .56075 L
s
.57189 .35339 m
.57575 .36282 L
s
.42017 .40134 m
.42431 .40712 L
s
.49962 .43063 m
.50393 .39775 L
s
.66535 .30405 m
.66894 .30979 L
s
.40058 .41174 m
.4058 .39328 L
s
.78508 .28906 m
.78842 .29512 L
s
.69085 .30003 m
.69421 .30286 L
s
.73046 .29024 m
.73404 .29796 L
s
.1335 .28654 m
.13841 .29156 L
s
.61114 .31703 m
.61456 .31294 L
s
.27886 .61575 m
.28369 .6162 L
s
.46151 .61107 m
.46535 .62651 L
s
.77074 .28964 m
.77393 .29365 L
s
.51741 .36865 m
.52136 .36743 L
s
.38962 .82625 m
.3938 .83186 L
s
.62553 .31173 m
.62918 .31636 L
s
.51069 .37763 m
.51458 .3933 L
s
.50669 .37784 m
.51069 .37763 L
s
.56802 .3436 m
.57189 .35339 L
s
.70171 .29251 m
.705 .29496 L
s
.82534 .2873 m
.82849 .29247 L
s
.71621 .29294 m
.71965 .29824 L
s
.59354 .34638 m
.59719 .34745 L
s
.46039 .56786 m
.46393 .59864 L
s
.43233 .87423 m
.43748 .84186 L
s
.45151 .49748 m
.45521 .51867 L
s
.75629 .28944 m
.75959 .29415 L
s
.54563 .32213 m
.54951 .32882 L
s
.8108 .28577 m
.81409 .29187 L
s
.56415 .33491 m
.56802 .3436 L
s
.72728 .2882 m
.73046 .29024 L
s
.47314 .65269 m
.47635 .71038 L
s
.74179 .28877 m
.74509 .29293 L
s
.58274 .35225 m
.58655 .3593 L
s
.29918 .55029 m
.30362 .55546 L
s
.41616 .39167 m
.42017 .40134 L
s
.7964 .28576 m
.79962 .29074 L
s
.48784 .58243 m
.49242 .54073 L
s
.67636 .30007 m
.67993 .30579 L
s
.33929 .90131 m
.34403 .89844 L
s
.78186 .28444 m
.78508 .28906 L
s
.66168 .2969 m
.66535 .30405 L
s
.28425 .55156 m
.28892 .55424 L
s
.27736 .5748 m
.28213 .57638 L
s
.49196 .78526 m
.4966 .72787 L
s
.64699 .29303 m
.6508 .30281 L
s
.12856 .28149 m
.1335 .28654 L
s
.56027 .32588 m
.56415 .33491 L
s
.41223 .37977 m
.41616 .39167 L
s
.54171 .30834 m
.54563 .32213 L
s
.53786 .31357 m
.54171 .30834 L
s
.47717 .77379 m
.48197 .72715 L
s
.40779 .3803 m
.41223 .37977 L
s
.28666 .70147 m
.2919 .69595 L
s
.51351 .35075 m
.51741 .36865 L
s
.50944 .36479 m
.51351 .35075 L
s
.62168 .3015 m
.62553 .31173 L
s
.76747 .28491 m
.77074 .28964 L
s
.8222 .28249 m
.82534 .2873 L
s
.48731 .6911 m
.4916 .67249 L
s
.68739 .29568 m
.69085 .30003 L
s
.60056 .33288 m
.60414 .33202 L
s
.64349 .29095 m
.64699 .29303 L
s
.71262 .28563 m
.71621 .29294 L
s
.47619 .79813 m
.47904 .88772 L
s
.80766 .28125 m
.8108 .28577 L
s
.57888 .3434 m
.58274 .35225 L
s
.43853 .42117 m
.44244 .43394 L
s
.4346 .40934 m
.43853 .42117 L
s
.63278 .30171 m
.63629 .30332 L
s
.43061 .39907 m
.4346 .40934 L
s
.5564 .31818 m
.56027 .32588 L
s
.44244 .43394 m
.44629 .44864 L
s
.61821 .30289 m
.62168 .3015 L
s
.27391 .61628 m
.27886 .61575 L
s
.65814 .29274 m
.66168 .2969 L
s
.7529 .28369 m
.75629 .28944 L
s
.29471 .5453 m
.29918 .55029 L
s
.69837 .28977 m
.70171 .29251 L
s
.67278 .29439 m
.67636 .30007 L
s
.45521 .51867 m
.45885 .54396 L
s
.42655 .39102 m
.43061 .39907 L
s
.79308 .27983 m
.7964 .28576 L
s
.73824 .28139 m
.74179 .28877 L
s
.44629 .44864 m
.4501 .46554 L
s
.50239 .41243 m
.50669 .37784 L
s
.575 .33399 m
.57888 .3434 L
s
.77867 .2803 m
.78186 .28444 L
s
.58976 .34084 m
.59354 .34638 L
s
.1236 .27642 m
.12856 .28149 L
s
.70928 .28238 m
.71262 .28563 L
s
.72389 .28358 m
.72728 .2882 L
s
.27953 .54911 m
.28425 .55156 L
s
.55254 .31248 m
.5564 .31818 L
s
.39228 .32639 m
.39601 .34302 L
s
.38431 .39698 m
.39228 .32639 L
s
.27254 .57329 m
.27736 .5748 L
s
.57113 .32515 m
.575 .33399 L
s
.60763 .3193 m
.61114 .31703 L
s
.76417 .2801 m
.76747 .28491 L
s
.42246 .38317 m
.42655 .39102 L
s
.38753 .44268 m
.38984 .49076 L
s
.38315 .43978 m
.38753 .44268 L
s
.81893 .27648 m
.8222 .28249 L
s
.68384 .29017 m
.68739 .29568 L
s
.4501 .46554 m
.45385 .48507 L
s
.33302 .62058 m
.33693 .63313 L
s
.32905 .60889 m
.33302 .62058 L
s
.33693 .63313 m
.34078 .64694 L
s
.74959 .27926 m
.7529 .28369 L
s
.80447 .27642 m
.80766 .28125 L
s
.73499 .27829 m
.73824 .28139 L
s
.32504 .59795 m
.32905 .60889 L
s
.33455 .90354 m
.33929 .90131 L
s
.29019 .54065 m
.29471 .5453 L
s
.66912 .28752 m
.67278 .29439 L
s
.78986 .27509 m
.79308 .27983 L
s
.34078 .64694 m
.34452 .66256 L
s
.32097 .58772 m
.32504 .59795 L
s
.65441 .28483 m
.65814 .29274 L
s
.52028 .34064 m
.52421 .35211 L
s
.56725 .31638 m
.57113 .32515 L
s
.64005 .29095 m
.64349 .29095 L
s
.39601 .34302 m
.39879 .38137 L
s
.46393 .59864 m
.46734 .63884 L
s
.51633 .33076 m
.52028 .34064 L
s
.40296 .3892 m
.40779 .3803 L
s
.58592 .33287 m
.58976 .34084 L
s
.50495 1.01509 m
.50354 .89681 L
s
.41844 .37301 m
.42246 .38317 L
s
.62892 .29156 m
.63278 .30171 L
s
.31684 .57822 m
.32097 .58772 L
s
.69492 .28558 m
.69837 .28977 L
s
.52709 .33007 m
.53103 .33196 L
s
.54861 .30107 m
.55254 .31248 L
s
.7754 .27552 m
.77867 .2803 L
s
.48296 .9076 m
.48779 .84905 L
s
.11861 .27132 m
.1236 .27642 L
s
.34452 .66256 m
.34818 .67983 L
s
.26882 .61799 m
.27391 .61628 L
s
.59683 .32889 m
.60056 .33288 L
s
.72031 .27633 m
.72389 .28358 L
s
.54474 .29883 m
.54861 .30107 L
s
.5122 .35757 m
.51633 .33076 L
s
.39011 .41476 m
.39296 .45122 L
s
.41433 .36533 m
.41844 .37301 L
s
.8158 .27195 m
.81893 .27648 L
s
.62535 .2897 m
.62892 .29156 L
s
.39298 .38054 m
.39593 .41507 L
s
.56336 .30817 m
.56725 .31638 L
s
.31266 .5694 m
.31684 .57822 L
s
.65079 .27967 m
.65441 .28483 L
s
.28133 .70746 m
.28666 .70147 L
s
.70595 .27961 m
.70928 .28238 L
s
.66555 .28264 m
.66912 .28752 L
s
.27478 .54673 m
.27953 .54911 L
s
.45885 .54396 m
.46248 .57118 L
s
.76078 .27431 m
.76417 .2801 L
s
.68026 .28443 m
.68384 .29017 L
s
.45385 .48507 m
.45757 .50713 L
s
.61475 .30588 m
.61821 .30289 L
s
.58205 .32393 m
.58592 .33287 L
s
.53396 .31655 m
.53786 .31357 L
s
.28561 .53641 m
.29019 .54065 L
s
.80116 .27054 m
.80447 .27642 L
s
.39296 .45122 m
.39786 .44217 L
s
.3724 .56385 m
.38315 .43978 L
s
.74608 .27236 m
.74959 .27926 L
s
.26767 .57214 m
.27254 .57329 L
s
.52315 .31184 m
.52709 .33007 L
s
.51915 .32406 m
.52315 .31184 L
s
.48475 .63015 m
.48928 .59814 L
s
.40368 .7799 m
.41099 .70177 L
s
.44091 .40358 m
.44484 .41663 L
s
.43695 .3919 m
.44091 .40358 L
s
.34818 .67983 m
.35183 .6975 L
s
.78667 .27083 m
.78986 .27509 L
s
.30843 .56114 m
.31266 .5694 L
s
.43293 .38192 m
.43695 .3919 L
s
.44484 .41663 m
.44871 .43141 L
s
.73164 .27404 m
.73499 .27829 L
s
.55949 .30215 m
.56336 .30817 L
s
.39855 .31605 m
.40171 .34636 L
s
.39286 .34111 m
.39855 .31605 L
s
.40983 .3667 m
.41433 .36533 L
s
.71694 .2724 m
.72031 .27633 L
s
.57816 .31505 m
.58205 .32393 L
s
.11359 .2662 m
.11861 .27132 L
s
.42887 .37317 m
.43293 .38192 L
s
.39593 .41507 m
.40058 .41174 L
s
.77211 .27057 m
.7754 .27552 L
s
.44871 .43141 m
.45254 .44875 L
s
.69138 .2802 m
.69492 .28558 L
s
.384 .49088 m
.38723 .51898 L
s
.37459 .59056 m
.384 .49088 L
s
.3903 .55165 m
.39582 .52834 L
s
.3298 .90516 m
.33455 .90354 L
s
.30416 .55335 m
.30843 .56114 L
s
.75747 .26966 m
.76078 .27431 L
s
.59301 .32187 m
.59683 .32889 L
s
.67662 .27785 m
.68026 .28443 L
s
.81262 .2671 m
.8158 .27195 L
s
.64739 .28001 m
.65079 .27967 L
s
.60395 .31664 m
.60763 .3193 L
s
.48574 .68392 m
.49027 .65028 L
s
.74279 .26853 m
.74608 .27236 L
s
.35183 .6975 m
.35549 .71521 L
s
.66186 .27569 m
.66555 .28264 L
s
.4088 1.01836 m
.40816 .91766 L
s
.57428 .30643 m
.57816 .31505 L
s
.48939 .52504 m
.49394 .48815 L
s
.79794 .26565 m
.80116 .27054 L
s
.63623 .28194 m
.64005 .29095 L
s
.54087 .30227 m
.54474 .29883 L
s
.4248 .36405 m
.42887 .37317 L
s
.28098 .53249 m
.28561 .53641 L
s
.48263 .80292 m
.48475 .96877 L
s
.26999 .54436 m
.27478 .54673 L
s
.45757 .50713 m
.46126 .53169 L
s
.4923 .49222 m
.49681 .45522 L
s
.46971 .71958 m
.47295 .77587 L
s
.70252 .27548 m
.70595 .27961 L
s
.62192 .29282 m
.62535 .2897 L
s
.55557 .29263 m
.55949 .30215 L
s
.45254 .44875 m
.45632 .46831 L
s
.50516 .39815 m
.50944 .36479 L
s
.78341 .26599 m
.78667 .27083 L
s
.29983 .54602 m
.30416 .55335 L
s
.26359 .62083 m
.26882 .61799 L
s
.72807 .26698 m
.73164 .27404 L
s
.57039 .29822 m
.57428 .30643 L
s
.63258 .27743 m
.63623 .28194 L
s
.35549 .71521 m
.35902 .73588 L
s
.42072 .35503 m
.4248 .36405 L
s
.58914 .31337 m
.59301 .32187 L
s
.2627 .57165 m
.26767 .57214 L
s
.71362 .26952 m
.71694 .2724 L
s
.55167 .28703 m
.55557 .29263 L
s
.10855 .26104 m
.11359 .2662 L
s
.68781 .27446 m
.69138 .2802 L
s
.48304 .7018 m
.48731 .6911 L
s
.67303 .27257 m
.67662 .27785 L
s
.76873 .26485 m
.77211 .27057 L
s
.65819 .26927 m
.66186 .27569 L
s
.52999 .30072 m
.53396 .31655 L
s
.52603 .29821 m
.52999 .30072 L
s
.46248 .57118 m
.46617 .59761 L
s
.48642 .56272 m
.49097 .52933 L
s
.80932 .26122 m
.81262 .2671 L
s
.75398 .26311 m
.75747 .26966 L
s
.38984 .49076 m
.39436 .49065 L
s
.49335 .80018 m
.49686 .86482 L
s
.41644 .35101 m
.42072 .35503 L
s
.29545 .53916 m
.29983 .54602 L
s
.79475 .26129 m
.79794 .26565 L
s
.56651 .29169 m
.57039 .29822 L
s
.73946 .26439 m
.74279 .26853 L
s
.27593 .71357 m
.28133 .70746 L
s
.61111 .30423 m
.61475 .30588 L
s
.58525 .30466 m
.58914 .31337 L
s
.27631 .52873 m
.28098 .53249 L
s
.60014 .31043 m
.60395 .31664 L
s
.72468 .26255 m
.72807 .26698 L
s
.42792 .87723 m
.43233 .87423 L
s
.4054 .36557 m
.40983 .3667 L
s
.45632 .46831 m
.46006 .49079 L
s
.39879 .38137 m
.40296 .3892 L
s
.44336 .38446 m
.44731 .39738 L
s
.43937 .37313 m
.44336 .38446 L
s
.32504 .90634 m
.3298 .90516 L
s
.69899 .27019 m
.70252 .27548 L
s
.44731 .39738 m
.45122 .41206 L
s
.78012 .26098 m
.78341 .26599 L
s
.26516 .54215 m
.26999 .54436 L
s
.43532 .3632 m
.43937 .37313 L
s
.65478 .26904 m
.65819 .26927 L
s
.49516 .46501 m
.49962 .43063 L
s
.35902 .73588 m
.3622 .76394 L
s
.54782 .28867 m
.55167 .28703 L
s
.68418 .2681 m
.68781 .27446 L
s
.58136 .29617 m
.58525 .30466 L
s
.62917 .28021 m
.63258 .27743 L
s
.76542 .26005 m
.76873 .26485 L
s
.6436 .27201 m
.64739 .28001 L
s
.66937 .2661 m
.67303 .27257 L
s
.50085 .88234 m
.5052 .84341 L
s
.45122 .41206 m
.45508 .42884 L
s
.38723 .51898 m
.3903 .55165 L
s
.75067 .25885 m
.75398 .26311 L
s
.29103 .53273 m
.29545 .53916 L
s
.46126 .53169 m
.46492 .55953 L
s
.43125 .35385 m
.43532 .3632 L
s
.47635 .71038 m
.47949 .78112 L
s
.8061 .2562 m
.80932 .26122 L
s
.46734 .63884 m
.47089 .67563 L
s
.40171 .34636 m
.4054 .36557 L
s
.56259 .28311 m
.56651 .29169 L
s
.71019 .26539 m
.71362 .26952 L
s
.59628 .30244 m
.60014 .31043 L
s
.52201 .3218 m
.52603 .29821 L
s
.25762 .57198 m
.2627 .57165 L
s
.41207 .34862 m
.41644 .35101 L
s
.57747 .28805 m
.58136 .29617 L
s
.7915 .25642 m
.79475 .26129 L
s
.2078 .26967 m
.21171 .28257 L
s
.20346 .26039 m
.2078 .26967 L
s
.42717 .34454 m
.43125 .35385 L
s
.42415 .85806 m
.42792 .87723 L
s
.41988 .85502 m
.42415 .85806 L
s
.19689 .28005 m
.20035 .2969 L
s
.1929 .26777 m
.19689 .28005 L
s
.7359 .25749 m
.73946 .26439 L
s
.21171 .28257 m
.21511 .30022 L
s
.63989 .26591 m
.6436 .27201 L
s
.1885 .2589 m
.1929 .26777 L
s
.45508 .42884 m
.45889 .44834 L
s
.22256 .27274 m
.22631 .28719 L
s
.21835 .26242 m
.22256 .27274 L
s
.53689 .29024 m
.54087 .30227 L
s
.27161 .52504 m
.27631 .52873 L
s
.25825 .6245 m
.26359 .62083 L
s
.72136 .25951 m
.72468 .26255 L
s
.53292 .27848 m
.53689 .29024 L
s
.69543 .26449 m
.69899 .27019 L
s
.61832 .29187 m
.62192 .29282 L
s
.55868 .27659 m
.56259 .28311 L
s
.68059 .26263 m
.68418 .2681 L
s
.52898 .29793 m
.53292 .27848 L
s
.39053 .61827 m
.39597 .59689 L
s
.40442 .31612 m
.40807 .33661 L
s
.39977 .31889 m
.40442 .31612 L
s
.66568 .25936 m
.66937 .2661 L
s
.77676 .25532 m
.78012 .26098 L
s
.17786 .26699 m
.18178 .27984 L
s
.17347 .25782 m
.17786 .26699 L
s
.28655 .5267 m
.29103 .53273 L
s
.39467 .70208 m
.40099 .65711 L
s
.22631 .28719 m
.22954 .30671 L
s
.51502 .35063 m
.51915 .32406 L
s
.18178 .27984 m
.18513 .29743 L
s
.21383 .25485 m
.21835 .26242 L
s
.46617 .59761 m
.46989 .62431 L
s
.23716 .27738 m
.24068 .29428 L
s
.23315 .26528 m
.23716 .27738 L
s
.46006 .49079 m
.46377 .51614 L
s
.60733 .29877 m
.61111 .30423 L
s
.22877 .25665 m
.23315 .26528 L
s
.42298 .33814 m
.42717 .34454 L
s
.19884 .25341 m
.20346 .26039 L
s
.5924 .294 m
.59628 .30244 L
s
.76195 .25369 m
.76542 .26005 L
s
.57358 .28113 m
.57747 .28805 L
s
.26026 .54036 m
.26516 .54215 L
s
.18381 .25217 m
.1885 .2589 L
s
.80291 .25173 m
.8061 .2562 L
s
.20035 .2969 m
.20323 .31893 L
s
.24782 .26951 m
.25156 .2843 L
s
.24363 .25913 m
.24782 .26951 L
s
.74735 .25463 m
.75067 .25885 L
s
.32026 .90727 m
.32504 .90634 L
s
.16876 .25102 m
.17347 .25782 L
s
.21511 .30022 m
.21796 .32303 L
s
.16255 .26815 m
.16612 .2838 L
s
.15836 .25728 m
.16255 .26815 L
s
.7325 .2528 m
.7359 .25749 L
s
.70668 .26015 m
.71019 .26539 L
s
.63648 .26809 m
.63989 .26591 L
s
.22415 .25006 m
.22877 .25665 L
s
.23913 .25162 m
.24363 .25913 L
s
.48337 .60559 m
.48784 .58243 L
s
.25156 .2843 m
.25481 .30443 L
s
.24068 .29428 m
.2437 .31641 L
s
.45889 .44834 m
.46267 .4704 L
s
.55482 .27603 m
.55868 .27659 L
s
.44587 .36389 m
.44985 .3764 L
s
.44184 .35293 m
.44587 .36389 L
s
.1537 .24989 m
.15836 .25728 L
s
.58851 .28561 m
.5924 .294 L
s
.65103 .26176 m
.65478 .26904 L
s
.44985 .3764 m
.45379 .39054 L
s
.78821 .25134 m
.7915 .25642 L
s
.20912 .24877 m
.21383 .25485 L
s
.66226 .25833 m
.66568 .25936 L
s
.18513 .29743 m
.18787 .32035 L
s
.12857 .25273 m
.12401 .32561 L
s
.69181 .25825 m
.69543 .26449 L
s
.41294 .93246 m
.41988 .85502 L
s
.28202 .52097 m
.28655 .5267 L
s
.25837 .26283 m
.2623 .27591 L
s
.25406 .25374 m
.25837 .26283 L
s
.2705 .7195 m
.27593 .71357 L
s
.53984 .26277 m
.54385 .27888 L
s
.53595 .27857 m
.53984 .26277 L
s
.67694 .25625 m
.68059 .26263 L
s
.19406 .2476 m
.19884 .25341 L
s
.2623 .27591 m
.26573 .29432 L
s
.3622 .76394 m
.36509 .79894 L
s
.43778 .34288 m
.44184 .35293 L
s
.26686 .52151 m
.27161 .52504 L
s
.77344 .2504 m
.77676 .25532 L
s
.4187 .33338 m
.42298 .33814 L
s
.47883 .70487 m
.48304 .7018 L
s
.16612 .2838 m
.16899 .30502 L
s
.45379 .39054 m
.45769 .40675 L
s
.40807 .33661 m
.41207 .34862 L
s
.56967 .27299 m
.57358 .28113 L
s
.54385 .27888 m
.54782 .28867 L
s
.22954 .30671 m
.23229 .33117 L
s
.75864 .24921 m
.76195 .25369 L
s
.60348 .29125 m
.60733 .29877 L
s
.17898 .24649 m
.18381 .25217 L
s
.71794 .25532 m
.72136 .25951 L
s
.14306 .25797 m
.14634 .27565 L
s
.13865 .24854 m
.14306 .25797 L
s
.25243 .57308 m
.25762 .57198 L
s
.47295 .77587 m
.47717 .77379 L
s
.46492 .55953 m
.46859 .58907 L
s
.498 .44136 m
.50239 .41243 L
s
.6256 .27962 m
.62917 .28021 L
s
.16388 .24541 m
.16876 .25102 L
s
.4337 .33328 m
.43778 .34288 L
s
.27294 .2686 m
.27654 .2855 L
s
.26888 .25692 m
.27294 .2686 L
s
.58461 .27761 m
.58851 .28561 L
s
.2495 .24696 m
.25406 .25374 L
s
.23447 .24558 m
.23913 .25162 L
s
.26448 .24878 m
.26888 .25692 L
s
.14876 .24434 m
.1537 .24989 L
s
.64729 .25491 m
.65103 .26176 L
s
.45769 .40675 m
.46155 .42528 L
s
.61457 .28698 m
.61832 .29187 L
s
.2194 .2444 m
.22415 .25006 L
s
.79967 .2468 m
.80291 .25173 L
s
.7438 .24785 m
.74735 .25463 L
s
.38746 .5847 m
.39053 .61827 L
s
.38324 .57705 m
.38746 .5847 L
s
.50797 .38374 m
.5122 .35757 L
s
.70312 .25447 m
.70668 .26015 L
s
.25526 .53915 m
.26026 .54036 L
s
.56576 .26651 m
.56967 .27299 L
s
.72918 .24957 m
.7325 .2528 L
s
.20431 .24329 m
.20912 .24877 L
s
.42954 .32585 m
.4337 .33328 L
s
.68822 .25268 m
.69181 .25825 L
s
.20323 .31893 m
.2056 .3459 L
s
.27746 .51544 m
.28202 .52097 L
s
.5996 .28304 m
.60348 .29125 L
s
.67326 .24975 m
.67694 .25625 L
s
.46377 .51614 m
.46749 .54289 L
s
.26573 .29432 m
.26869 .31818 L
s
.25481 .30443 m
.25762 .32941 L
s
.28354 .26204 m
.28727 .2776 L
s
.27937 .25152 m
.28354 .26204 L
s
.78486 .24572 m
.78821 .25134 L
s
.1892 .24222 m
.19406 .2476 L
s
.25282 .62849 m
.25825 .6245 L
s
.46989 .62431 m
.47362 .6525 L
s
.14634 .27565 m
.14858 .30116 L
s
.21796 .32303 m
.22039 .35024 L
s
.27654 .2855 m
.27963 .30835 L
s
.58072 .27045 m
.58461 .27761 L
s
.31544 .90805 m
.32026 .90727 L
s
.46267 .4704 m
.46643 .4948 L
s
.76999 .24409 m
.77344 .2504 L
s
.41462 .32324 m
.4187 .33338 L
s
.25989 .2425 m
.26448 .24878 L
s
.17407 .24117 m
.17898 .24649 L
s
.38595 .38892 m
.39286 .34111 L
s
.2437 .31641 m
.24635 .34266 L
s
.27492 .24409 m
.27937 .25152 L
s
.39397 .34541 m
.39977 .31889 L
s
.26206 .51825 m
.26686 .52151 L
s
.41068 .30908 m
.41462 .32324 L
s
.40623 .30731 m
.41068 .30908 L
s
.24481 .24124 m
.2495 .24696 L
s
.54681 .2494 m
.55085 .26699 L
s
.54297 .26277 m
.54681 .2494 L
s
.37283 .69888 m
.38324 .57705 L
s
.16899 .30502 m
.17118 .33201 L
s
.75531 .24478 m
.75864 .24921 L
s
.28727 .2776 m
.29048 .29948 L
s
.15892 .24012 m
.16388 .24541 L
s
.18787 .32035 m
.19003 .34846 L
s
.41235 .86885 m
.41842 .81983 L
s
.64388 .25639 m
.64729 .25491 L
s
.22971 .24011 m
.23447 .24558 L
s
.48039 .64263 m
.48475 .63015 L
s
.46155 .42528 m
.46537 .4464 L
s
.48735 .8252 m
.49196 .78526 L
s
.71444 .25009 m
.71794 .25532 L
s
.47089 .67563 m
.47474 .69773 L
s
.59571 .2748 m
.5996 .28304 L
s
.7404 .24309 m
.7438 .24785 L
s
.29412 .25601 m
.29797 .27035 L
s
.28987 .24645 m
.29412 .25601 L
s
.42533 .31914 m
.42954 .32585 L
s
.65852 .25138 m
.66226 .25833 L
s
.55085 .26699 m
.55482 .27603 L
s
.31251 .57897 m
.31647 .59196 L
s
.30847 .56704 m
.31251 .57897 L
s
.45245 .35383 m
.45643 .36728 L
s
.44843 .3421 m
.45245 .35383 L
s
.21459 .23904 m
.2194 .2444 L
s
.56189 .26408 m
.56576 .26651 L
s
.31647 .59196 m
.32037 .60611 L
s
.30436 .55608 m
.30847 .56704 L
s
.44438 .33134 m
.44843 .3421 L
s
.61073 .27984 m
.61457 .28698 L
s
.45643 .36728 m
.46037 .38255 L
s
.79638 .24163 m
.79967 .2468 L
s
.69951 .24829 m
.70312 .25447 L
s
.27286 .51008 m
.27746 .51544 L
s
.66981 .24787 m
.67326 .24975 L
s
.29797 .27035 m
.3013 .29128 L
s
.19945 .23798 m
.20431 .24329 L
s
.68457 .24624 m
.68822 .25268 L
s
.5768 .26257 m
.58072 .27045 L
s
.30018 .54596 m
.30436 .55608 L
s
.32037 .60611 m
.32417 .62168 L
s
.23229 .33117 m
.23475 .35889 L
s
.63294 .26745 m
.63648 .26809 L
s
.28538 .23956 m
.28987 .24645 L
s
.78155 .24068 m
.78486 .24572 L
s
.44029 .32155 m
.44438 .33134 L
s
.27031 .23812 m
.27492 .24409 L
s
.18429 .23693 m
.1892 .24222 L
s
.47474 .69773 m
.47883 .70487 L
s
.76668 .23958 m
.76999 .24409 L
s
.2552 .23694 m
.25989 .2425 L
s
.62187 .27505 m
.6256 .27962 L
s
.24716 .57457 m
.25243 .57308 L
s
.46037 .38255 m
.46427 .40003 L
s
.72577 .24525 m
.72918 .24957 L
s
.59181 .26695 m
.59571 .2748 L
s
.3047 .25038 m
.30865 .26359 L
s
.30039 .24161 m
.3047 .25038 L
s
.29594 .53654 m
.30018 .54596 L
s
.48145 .69224 m
.48574 .68392 L
s
.16912 .23588 m
.17407 .24117 L
s
.30865 .26359 m
.31209 .28351 L
s
.32417 .62168 m
.32788 .63893 L
s
.2502 .53839 m
.25526 .53915 L
s
.26505 .72493 m
.2705 .7195 L
s
.24007 .23585 m
.24481 .24124 L
s
.43615 .31337 m
.44029 .32155 L
s
.42123 .30926 m
.42533 .31914 L
s
.65476 .24428 m
.65852 .25138 L
s
.22492 .23479 m
.22971 .24011 L
s
.25721 .51528 m
.26206 .51825 L
s
.60685 .27186 m
.61073 .27984 L
s
.5729 .25639 m
.5768 .26257 L
s
.75177 .23806 m
.75531 .24478 L
s
.26869 .31818 m
.27136 .34577 L
s
.27963 .30835 m
.28234 .33608 L
s
.71088 .24437 m
.71444 .25009 L
s
.29164 .52769 m
.29594 .53654 L
s
.46859 .58907 m
.47234 .61655 L
s
.46537 .4464 m
.46917 .46981 L
s
.73709 .23964 m
.7404 .24309 L
s
.47904 .88772 m
.48296 .9076 L
s
.3106 .90873 m
.31544 .90805 L
s
.69593 .24268 m
.69951 .24829 L
s
.20975 .23373 m
.21459 .23904 L
s
.25762 .32941 m
.26024 .35696 L
s
.29587 .23511 m
.30039 .24161 L
s
.41714 .29877 m
.42123 .30926 L
s
.26822 .50487 m
.27286 .51008 L
s
.68092 .24024 m
.68457 .24624 L
s
.29048 .29948 m
.29324 .32739 L
s
.46643 .4948 m
.47019 .52072 L
s
.28076 .2338 m
.28538 .23956 L
s
.31933 .25719 m
.32288 .276 L
s
.31529 .24503 m
.31933 .25719 L
s
.46749 .54289 m
.47125 .56945 L
s
.40116 .31884 m
.40623 .30731 L
s
.46427 .40003 m
.46813 .41987 L
s
.58791 .25966 m
.59181 .26695 L
s
.36509 .79894 m
.36809 .83288 L
s
.79304 .23604 m
.79638 .24163 L
s
.31093 .23692 m
.31529 .24503 L
s
.32788 .63893 m
.33149 .65805 L
s
.19457 .23268 m
.19945 .23798 L
s
.2056 .3459 m
.20764 .37641 L
s
.26562 .23266 m
.27031 .23812 L
s
.14858 .30116 m
.14994 .33383 L
s
.43199 .30512 m
.43615 .31337 L
s
.37269 .51083 m
.38239 .41129 L
s
.3013 .29128 m
.3041 .31929 L
s
.41273 .29591 m
.41714 .29877 L
s
.47362 .6525 m
.47743 .67825 L
s
.7781 .23437 m
.78155 .24068 L
s
.28731 .51927 m
.29164 .52769 L
s
.48499 .54097 m
.48939 .52504 L
s
.17937 .23162 m
.18429 .23693 L
s
.55791 .25492 m
.56189 .26408 L
s
.25046 .23159 m
.2552 .23694 L
s
.24736 .63225 m
.25282 .62849 L
s
.55386 .23919 m
.55791 .25492 L
s
.55004 .24952 m
.55386 .23919 L
s
.24635 .34266 m
.24891 .37032 L
s
.60296 .26376 m
.60685 .27186 L
s
.22039 .35024 m
.22263 .37971 L
s
.65136 .24516 m
.65476 .24428 L
s
.76334 .23486 m
.76668 .23958 L
s
.50086 .41849 m
.50516 .39815 L
s
.45911 .343 m
.46309 .35708 L
s
.45509 .3306 m
.45911 .343 L
s
.61804 .26814 m
.62187 .27505 L
s
.45104 .31933 m
.45509 .3306 L
s
.23528 .23052 m
.24007 .23585 L
s
.31209 .28351 m
.31496 .31143 L
s
.72227 .23997 m
.72577 .24525 L
s
.66607 .24084 m
.66981 .24787 L
s
.33001 .25106 m
.33368 .26863 L
s
.32589 .23989 m
.33001 .25106 L
s
.74839 .23339 m
.75177 .23806 L
s
.48791 .50932 m
.4923 .49222 L
s
.17118 .33201 m
.17277 .36435 L
s
.48206 .57388 m
.48642 .56272 L
s
.44695 .30931 m
.45104 .31933 L
s
.56901 .25246 m
.5729 .25639 L
s
.46309 .35708 m
.46704 .37318 L
s
.64034 .25554 m
.64388 .25639 L
s
.3064 .23072 m
.31093 .23692 L
s
.22009 .22947 m
.22492 .23479 L
s
.3215 .23234 m
.32589 .23989 L
s
.70729 .23826 m
.71088 .24437 L
s
.584 .25201 m
.58791 .25966 L
s
.42787 .29531 m
.43199 .30512 L
s
.29126 .22948 m
.29587 .23511 L
s
.19003 .34846 m
.19178 .38073 L
s
.62922 .26304 m
.63294 .26745 L
s
.28292 .51124 m
.28731 .51927 L
s
.52494 .3134 m
.52898 .29793 L
s
.69227 .23618 m
.69593 .24268 L
s
.67744 .23746 m
.68092 .24024 L
s
.32288 .276 m
.32584 .30346 L
s
.33149 .65805 m
.33499 .67936 L
s
.26355 .49984 m
.26822 .50487 L
s
.20488 .22841 m
.20975 .23373 L
s
.2523 .51246 m
.25721 .51528 L
s
.27609 .22838 m
.28076 .2338 L
s
.59907 .25601 m
.60296 .26376 L
s
.46813 .41987 m
.47198 .44198 L
s
.44282 .30026 m
.44695 .30931 L
s
.49686 .86482 m
.50085 .88234 L
s
.24509 .53764 m
.2502 .53839 L
s
.5179 .33814 m
.52201 .3218 L
s
.78973 .23087 m
.79304 .23604 L
s
.24186 .5759 m
.24716 .57457 L
s
.18965 .22735 m
.19457 .23268 L
s
.77481 .22992 m
.7781 .23437 L
s
.46704 .37318 m
.47095 .39152 L
s
.2609 .22731 m
.26562 .23266 L
s
.4237 .28681 m
.42787 .29531 L
s
.34071 .24515 m
.3445 .26132 L
s
.33653 .23491 m
.34071 .24515 L
s
.73367 .23515 m
.73709 .23964 L
s
.23475 .35889 m
.23724 .38687 L
s
.61416 .26033 m
.61804 .26814 L
s
.33368 .26863 m
.33677 .2951 L
s
.46917 .46981 m
.47298 .49454 L
s
.53198 .29169 m
.53595 .27857 L
s
.66233 .23395 m
.66607 .24084 L
s
.2457 .22624 m
.25046 .23159 L
s
.30573 .90936 m
.3106 .90873 L
s
.27849 .50355 m
.28292 .51124 L
s
.5801 .24607 m
.584 .25201 L
s
.31697 .22636 m
.3215 .23234 L
s
.33211 .22783 m
.33653 .23491 L
s
.43869 .29089 m
.44282 .30026 L
s
.23047 .22518 m
.23528 .23052 L
s
.75982 .22818 m
.76334 .23486 L
s
.71872 .23422 m
.72227 .23997 L
s
.40809 .29789 m
.41273 .29591 L
s
.47913 .60691 m
.48337 .60559 L
s
.3018 .22517 m
.3064 .23072 L
s
.38725 .66133 m
.39081 .68486 L
s
.37898 .74254 m
.38725 .66133 L
s
.49081 .47944 m
.49516 .46501 L
s
.3445 .26132 m
.34775 .28616 L
s
.59517 .24863 m
.59907 .25601 L
s
.2596 .72964 m
.26505 .72493 L
s
.70371 .23263 m
.70729 .23826 L
s
.36769 .58542 m
.37888 .45784 L
s
.47019 .52072 m
.47401 .54583 L
s
.47234 .61655 m
.47626 .63656 L
s
.74507 .2297 m
.74839 .23339 L
s
.41936 .28225 m
.4237 .28681 L
s
.68866 .23067 m
.69227 .23618 L
s
.21524 .22412 m
.22009 .22947 L
s
.35143 .23943 m
.35533 .25407 L
s
.34719 .23007 m
.35143 .23943 L
s
.2866 .22408 m
.29126 .22948 L
s
.47125 .56945 m
.47511 .59264 L
s
.47626 .63656 m
.48039 .64263 L
s
.27136 .34577 m
.27401 .37414 L
s
.51084 .36541 m
.51502 .35063 L
s
.47743 .67825 m
.48145 .69224 L
s
.56502 .24288 m
.56901 .25246 L
s
.25883 .49493 m
.26355 .49984 L
s
.28234 .33608 m
.2849 .36619 L
s
.46181 .31835 m
.46583 .3313 L
s
.45775 .30674 m
.46181 .31835 L
s
.47095 .39152 m
.47484 .41218 L
s
.61027 .25242 m
.61416 .26033 L
s
.43456 .28129 m
.43869 .29089 L
s
.46583 .3313 m
.46983 .34589 L
s
.6254 .25635 m
.62922 .26304 L
s
.19999 .22306 m
.20488 .22841 L
s
.33499 .67936 m
.33837 .70315 L
s
.27138 .22301 m
.27609 .22838 L
s
.26024 .35696 m
.26298 .38386 L
s
.27403 .4961 m
.27849 .50355 L
s
.45367 .29628 m
.45775 .30674 L
s
.35533 .25407 m
.35877 .27662 L
s
.29324 .32739 m
.29571 .35943 L
s
.78629 .2246 m
.78973 .23087 L
s
.65892 .23428 m
.66233 .23395 L
s
.25615 .22195 m
.2609 .22731 L
s
.24739 .50945 m
.2523 .51246 L
s
.46983 .34589 m
.47379 .36252 L
s
.34276 .22336 m
.34719 .23007 L
s
.53903 .27273 m
.54297 .26277 L
s
.47198 .44198 m
.47583 .46552 L
s
.32758 .222 m
.33211 .22783 L
s
.67369 .23014 m
.67744 .23746 L
s
.64782 .24391 m
.65136 .24516 L
s
.77145 .22485 m
.77481 .22992 L
s
.561 .23175 m
.56502 .24288 L
s
.73018 .22981 m
.73367 .23515 L
s
.63663 .25118 m
.64034 .25554 L
s
.44956 .28633 m
.45367 .29628 L
s
.3041 .31929 m
.3065 .3533 L
s
.43037 .27324 m
.43456 .28129 L
s
.24191 .63534 m
.24736 .63225 L
s
.2409 .22088 m
.2457 .22624 L
s
.57619 .24081 m
.5801 .24607 L
s
.75646 .22368 m
.75982 .22818 L
s
.59125 .24125 m
.59517 .24863 L
s
.31238 .22086 m
.31697 .22636 L
s
.36217 .23389 m
.36618 .24692 L
s
.35788 .22532 m
.36217 .23389 L
s
.24891 .37032 m
.25171 .39604 L
s
.36618 .24692 m
.36981 .26672 L
s
.55717 .23771 m
.561 .23175 L
s
.23998 .53643 m
.24509 .53764 L
s
.71513 .2282 m
.71872 .23422 L
s
.36809 .83288 m
.37158 .85761 L
s
.20764 .37641 m
.20963 .40794 L
s
.22564 .21981 m
.23047 .22518 L
s
.60638 .24483 m
.61027 .25242 L
s
.29715 .21977 m
.3018 .22517 L
s
.22263 .37971 m
.22503 .40822 L
s
.31496 .31143 m
.31731 .34716 L
s
.70005 .22606 m
.70371 .23263 L
s
.26953 .48886 m
.27403 .4961 L
s
.47949 .78112 m
.48311 .8264 L
s
.44544 .27628 m
.44956 .28633 L
s
.68514 .227 m
.68866 .23067 L
s
.47379 .36252 m
.47772 .38136 L
s
.21036 .21875 m
.21524 .22412 L
s
.62153 .24877 m
.6254 .25635 L
s
.28191 .2187 m
.2866 .22408 L
s
.41501 .27742 m
.41936 .28225 L
s
.47298 .49454 m
.47684 .51811 L
s
.25411 .48985 m
.25883 .49493 L
s
.23657 .57661 m
.24186 .5759 L
s
.3008 .9101 m
.30573 .90936 L
s
.37704 .24 m
.38086 .2569 L
s
.37293 .22852 m
.37704 .24 L
s
.14994 .33383 m
.15058 .37265 L
s
.39081 .68486 m
.39467 .70208 L
s
.32584 .30346 m
.32821 .34026 L
s
.37615 .46614 m
.38431 .39698 L
s
.74165 .22503 m
.74507 .2297 L
s
.78302 .22018 m
.78629 .2246 L
s
.35345 .21893 m
.35788 .22532 L
s
.42613 .26597 m
.43037 .27324 L
s
.47484 .41218 m
.47873 .43453 L
s
.26665 .21763 m
.27138 .22301 L
s
.66998 .22388 m
.67369 .23014 L
s
.44131 .2667 m
.44544 .27628 L
s
.33824 .21765 m
.34276 .22336 L
s
.36862 .22066 m
.37293 .22852 L
s
.47511 .59264 m
.47913 .60691 L
s
.58736 .23539 m
.59125 .24125 L
s
.49372 .4502 m
.498 .44136 L
s
.33677 .2951 m
.33924 .3318 L
s
.25138 .21656 m
.25615 .22195 L
s
.32301 .21653 m
.32758 .222 L
s
.4686 .30525 m
.47263 .31855 L
s
.46454 .29328 m
.4686 .30525 L
s
.50375 .39361 m
.50797 .38374 L
s
.23724 .38687 m
.24009 .41171 L
s
.47401 .54583 m
.47794 .56566 L
s
.60248 .23748 m
.60638 .24483 L
s
.17277 .36435 m
.17393 .40093 L
s
.4305 1.01307 m
.43143 .99377 L
s
.47263 .31855 m
.47664 .33351 L
s
.33837 .70315 m
.34161 .72984 L
s
.46045 .28223 m
.46454 .29328 L
s
.72663 .22401 m
.73018 .22981 L
s
.39621 .32594 m
.40116 .31884 L
s
.34775 .28616 m
.35041 .32117 L
s
.76794 .21822 m
.77145 .22485 L
s
.26501 .48168 m
.26953 .48886 L
s
.23609 .21549 m
.2409 .22088 L
s
.30775 .21545 m
.31238 .22086 L
s
.38791 .23342 m
.39188 .24765 L
s
.38373 .22332 m
.38791 .23342 L
s
.57219 .23103 m
.57619 .24081 L
s
.24248 .50595 m
.24739 .50945 L
s
.35877 .27662 m
.36171 .30824 L
s
.19178 .38073 m
.19335 .41521 L
s
.71155 .22246 m
.71513 .2282 L
s
.36981 .26672 m
.37308 .29373 L
s
.63282 .24465 m
.63663 .25118 L
s
.43714 .25772 m
.44131 .2667 L
s
.61764 .24106 m
.62153 .24877 L
s
.69647 .22097 m
.70005 .22606 L
s
.38086 .2569 m
.38443 .27896 L
s
.45636 .27151 m
.46045 .28223 L
s
.75313 .21973 m
.75646 .22368 L
s
.49485 .99542 m
.49775 .93529 L
s
.54612 .25588 m
.55004 .24952 L
s
.40363 .29472 m
.40809 .29789 L
s
.47772 .38136 m
.48165 .40212 L
s
.22078 .21442 m
.22564 .21981 L
s
.29248 .21437 m
.29715 .21977 L
s
.47794 .56566 m
.48206 .57388 L
s
.47664 .33351 m
.48062 .35042 L
s
.39188 .24765 m
.39569 .26538 L
s
.47583 .46552 m
.47973 .48829 L
s
.42196 .25652 m
.42613 .26597 L
s
.25416 .73349 m
.2596 .72964 L
s
.36418 .21451 m
.36862 .22066 L
s
.37939 .21606 m
.38373 .22332 L
s
.45225 .26106 m
.45636 .27151 L
s
.2772 .2133 m
.28191 .2187 L
s
.56823 .22384 m
.57219 .23103 L
s
.2494 .48427 m
.25411 .48985 L
s
.38833 .366 m
.39397 .34541 L
s
.34894 .21329 m
.35345 .21893 L
s
.64412 .23943 m
.64782 .24391 L
s
.26298 .38386 m
.26604 .40761 L
s
.40286 .23933 m
.40683 .25385 L
s
.39878 .22725 m
.40286 .23933 L
s
.41084 .26777 m
.41501 .27742 L
s
.66656 .22363 m
.66998 .22388 L
s
.37158 .85761 m
.37531 .87754 L
s
.48082 .53604 m
.48499 .54097 L
s
.27401 .37414 m
.27687 .4007 L
s
.65537 .23246 m
.65892 .23428 L
s
.23489 .53467 m
.23998 .53643 L
s
.39455 .2183 m
.39878 .22725 L
s
.43299 .24787 m
.43714 .25772 L
s
.68137 .21929 m
.68514 .227 L
s
.2619 .21222 m
.26665 .21763 L
s
.39846 .79756 m
.40368 .7799 L
s
.59857 .23044 m
.60248 .23748 L
s
.33368 .21219 m
.33824 .21765 L
s
.29638 .5346 m
.30041 .54755 L
s
.29228 .52254 m
.29638 .5346 L
s
.58343 .22907 m
.58736 .23539 L
s
.73816 .2196 m
.74165 .22503 L
s
.26049 .47418 m
.26501 .48168 L
s
.30041 .54755 m
.30437 .56157 L
s
.44812 .251 m
.45225 .26106 L
s
.77963 .21471 m
.78302 .22018 L
s
.28811 .51127 m
.29228 .52254 L
s
.40683 .25385 m
.41084 .26777 L
s
.25171 .39604 m
.25495 .41751 L
s
.41788 .24443 m
.42196 .25652 L
s
.61376 .23364 m
.61764 .24106 L
s
.48062 .35042 m
.48458 .36927 L
s
.76461 .21393 m
.76794 .21822 L
s
.24658 .21115 m
.25138 .21656 L
s
.3184 .2111 m
.32301 .21653 L
s
.2849 .36619 m
.28754 .39614 L
s
.47684 .51811 m
.48082 .53604 L
s
.41382 .23201 m
.41788 .24443 L
s
.47873 .43453 m
.48264 .45663 L
s
.30437 .56157 m
.30824 .57687 L
s
.23649 .63752 m
.24191 .63534 L
s
.40967 .22151 m
.41382 .23201 L
s
.72306 .21806 m
.72663 .22401 L
s
.28389 .50063 m
.28811 .51127 L
s
.62896 .23724 m
.63282 .24465 L
s
.39569 .26538 m
.39953 .28286 L
s
.42888 .23665 m
.43299 .24787 L
s
.47545 .29102 m
.47949 .30456 L
s
.47139 .27866 m
.47545 .29102 L
s
.29582 .9112 m
.3008 .9101 L
s
.48373 .50547 m
.48791 .50932 L
s
.23124 .21007 m
.23609 .21549 L
s
.7079 .21592 m
.71155 .22246 L
s
.3031 .21003 m
.30775 .21545 L
s
.46731 .26703 m
.47139 .27866 L
s
.44399 .24073 m
.44812 .251 L
s
.3902 .21151 m
.39455 .2183 L
s
.47949 .30456 m
.48352 .31966 L
s
.37495 .2101 m
.37939 .21606 L
s
.2313 .57661 m
.23657 .57661 L
s
.27963 .49043 m
.28389 .50063 L
s
.69291 .21642 m
.69647 .22097 L
s
.46321 .25582 m
.46731 .26703 L
s
.42476 .22555 m
.42888 .23665 L
s
.30824 .57687 m
.31201 .59375 L
s
.4054 .21344 m
.40967 .22151 L
s
.23757 .5021 m
.24248 .50595 L
s
.56438 .22632 m
.56823 .22384 L
s
.28779 .20895 m
.29248 .21437 L
s
.48165 .40212 m
.48559 .42339 L
s
.35968 .20893 m
.36418 .21451 L
s
.52085 .31717 m
.52494 .3134 L
s
.29571 .35943 m
.29811 .39333 L
s
.67772 .21406 m
.68137 .21929 L
s
.24473 .47813 m
.2494 .48427 L
s
.37531 .87754 m
.37835 .91388 L
s
.22503 .40822 m
.22792 .4325 L
s
.25603 .46599 m
.26049 .47418 L
s
.74971 .21485 m
.75313 .21973 L
s
.45911 .24504 m
.46321 .25582 L
s
.43987 .22996 m
.44399 .24073 L
s
.42058 .21614 m
.42476 .22555 L
s
.38443 .27896 m
.38797 .30231 L
s
.59468 .22447 m
.59857 .23044 L
s
.49665 .42001 m
.50086 .41849 L
s
.27246 .20787 m
.2772 .2133 L
s
.48352 .31966 m
.48752 .3365 L
s
.52792 .2948 m
.53198 .29169 L
s
.34439 .20783 m
.34894 .21329 L
s
.48311 .8264 m
.48735 .8252 L
s
.24009 .41171 m
.24349 .43131 L
s
.39953 .28286 m
.40363 .29472 L
s
.27533 .48051 m
.27963 .49043 L
s
.60986 .22636 m
.61376 .23364 L
s
.51377 .3409 m
.5179 .33814 L
s
.57944 .21978 m
.58343 .22907 L
s
.47973 .48829 m
.48373 .50547 L
s
.34161 .72984 m
.34468 .76054 L
s
.64031 .23296 m
.64412 .23943 L
s
.48458 .36927 m
.48855 .38925 L
s
.25711 .20679 m
.2619 .21222 L
s
.20963 .40794 m
.21193 .43725 L
s
.32909 .20674 m
.33368 .21219 L
s
.45499 .23443 m
.45911 .24504 L
s
.62508 .22972 m
.62896 .23724 L
s
.43572 .21971 m
.43987 .22996 L
s
.73461 .21373 m
.73816 .2196 L
s
.31201 .59375 m
.31566 .61258 L
s
.55326 .24037 m
.55717 .23771 L
s
.77614 .20824 m
.77963 .21471 L
s
.48665 .47406 m
.49081 .47944 L
s
.3065 .3533 m
.30865 .39154 L
s
.40105 .20701 m
.4054 .21344 L
s
.27103 .47052 m
.27533 .48051 L
s
.71947 .21215 m
.72306 .21806 L
s
.24175 .2057 m
.24658 .21115 L
s
.31376 .20566 m
.3184 .2111 L
s
.4163 .20871 m
.42058 .21614 L
s
.70435 .2111 m
.7079 .21592 L
s
.25495 .41751 m
.25863 .43447 L
s
.38577 .20569 m
.3902 .21151 L
s
.25163 .45678 m
.25603 .46599 L
s
.22977 .53278 m
.23489 .53467 L
s
.45086 .22393 m
.45499 .23443 L
s
.26604 .40761 m
.26947 .42759 L
s
.53501 .27408 m
.53903 .27273 L
s
.76127 .20968 m
.76461 .21393 L
s
.48237 .27544 m
.48642 .28911 L
s
.4783 .26279 m
.48237 .27544 L
s
.48752 .3365 m
.49152 .35479 L
s
.47421 .25083 m
.4783 .26279 L
s
.43151 .21106 m
.43572 .21971 L
s
.37308 .29373 m
.37618 .32478 L
s
.57551 .21521 m
.57944 .21978 L
s
.29842 .20458 m
.3031 .21003 L
s
.65167 .22775 m
.65537 .23246 L
s
.48264 .45663 m
.48665 .47406 L
s
.37048 .20455 m
.37495 .2101 L
s
.47012 .23947 m
.47421 .25083 L
s
.48642 .28911 m
.49046 .30411 L
s
.50668 .36503 m
.51084 .36541 L
s
.12401 .32561 m
.11938 .40068 L
s
.24009 .47133 m
.24473 .47813 L
s
.26678 .45994 m
.27103 .47052 L
s
.4467 .21428 m
.45086 .22393 L
s
.663 .22112 m
.66656 .22363 L
s
.28307 .20349 m
.28779 .20895 L
s
.60596 .21962 m
.60986 .22636 L
s
.35516 .20345 m
.35968 .20893 L
s
.466 .22861 m
.47012 .23947 L
s
.24875 .73649 m
.25416 .73349 L
s
.23264 .49827 m
.23757 .5021 L
s
.68911 .20833 m
.69291 .21642 L
s
.67428 .21308 m
.67772 .21406 L
s
.59074 .2174 m
.59468 .22447 L
s
.31731 .34716 m
.31926 .38965 L
s
.27687 .4007 m
.28003 .42441 L
s
.24349 .43131 m
.2474 .44577 L
s
.40782 .86937 m
.41235 .86885 L
s
.2474 .44577 m
.25163 .45678 L
s
.6212 .22239 m
.62508 .22972 L
s
.48559 .42339 m
.4896 .4416 L
s
.49046 .30411 m
.49449 .32051 L
s
.31566 .61258 m
.31918 .63373 L
s
.2677 .20241 m
.27246 .20787 L
s
.25863 .43447 m
.26262 .44819 L
s
.26262 .44819 m
.26678 .45994 L
s
.74621 .20929 m
.74971 .21485 L
s
.33982 .20236 m
.34439 .20783 L
s
.39494 .77039 m
.39846 .79756 L
s
.39003 .77802 m
.39494 .77039 L
s
.63646 .22569 m
.64031 .23296 L
s
.29075 .91297 m
.29582 .9112 L
s
.46187 .21831 m
.466 .22861 L
s
.4896 .4416 m
.49372 .4502 L
s
.42723 .20407 m
.43151 .21106 L
s
.48855 .38925 m
.49256 .40786 L
s
.41195 .20253 m
.4163 .20871 L
s
.39181 .32009 m
.39621 .32594 L
s
.77284 .20407 m
.77614 .20824 L
s
.36171 .30824 m
.36431 .34709 L
s
.25231 .20132 m
.25711 .20679 L
s
.73105 .20782 m
.73461 .21373 L
s
.32447 .20127 m
.32909 .20674 L
s
.44248 .20617 m
.4467 .21428 L
s
.23109 .63892 m
.23649 .63752 L
s
.22601 .57637 m
.2313 .57661 L
s
.39664 .20128 m
.40105 .20701 L
s
.49152 .35479 m
.49554 .37309 L
s
.71584 .20582 m
.71947 .21215 L
s
.32821 .34026 m
.33006 .38601 L
s
.54211 .2549 m
.54612 .25588 L
s
.4996 .38798 m
.50375 .39361 L
s
.48933 .2586 m
.4934 .27219 L
s
.48525 .24594 m
.48933 .2586 L
s
.48116 .23411 m
.48525 .24594 L
s
.22792 .4325 m
.23146 .4506 L
s
.38797 .30231 m
.39181 .32009 L
s
.30911 .20019 m
.31376 .20566 L
s
.45771 .20911 m
.46187 .21831 L
s
.26947 .42759 m
.27319 .44453 L
s
.38131 .20015 m
.38577 .20569 L
s
.19335 .41521 m
.19506 .44917 L
s
.49449 .32051 m
.49853 .33776 L
s
.2356 .46285 m
.24009 .47133 L
s
.40403 .84833 m
.40782 .86937 L
s
.39818 .88247 m
.40403 .84833 L
s
.4934 .27219 m
.49746 .28689 L
s
.47705 .22308 m
.48116 .23411 L
s
.68555 .20437 m
.68911 .20833 L
s
.35041 .32117 m
.35257 .3657 L
s
.70074 .20568 m
.70435 .2111 L
s
.15058 .37265 m
.15069 .41635 L
s
.33924 .3318 m
.34114 .3786 L
s
.17393 .40093 m
.17488 .43999 L
s
.29372 .1991 m
.29842 .20458 L
s
.36597 .19905 m
.37048 .20455 L
s
.60206 .21333 m
.60596 .21962 L
s
.28754 .39614 m
.29036 .42457 L
s
.6173 .21525 m
.6212 .22239 L
s
.58676 .20933 m
.59074 .2174 L
s
.75784 .20457 m
.76127 .20968 L
s
.64787 .22127 m
.65167 .22775 L
s
.37947 .42426 m
.38595 .38892 L
s
.57164 .21479 m
.57551 .21521 L
s
.47292 .21295 m
.47705 .22308 L
s
.49746 .28689 m
.50151 .30261 L
s
.63258 .21832 m
.63646 .22569 L
s
.49256 .40786 m
.49665 .42001 L
s
.27832 .19801 m
.28307 .20349 L
s
.35061 .19796 m
.35516 .20345 L
s
.22455 .53152 m
.22977 .53278 L
s
.56044 .2256 m
.56438 .22632 L
s
.4382 .19949 m
.44248 .20617 L
s
.45349 .2014 m
.45771 .20911 L
s
.42289 .19806 m
.42723 .20407 L
s
.27319 .44453 m
.27709 .45946 L
s
.22769 .49424 m
.23264 .49827 L
s
.74267 .20338 m
.74621 .20929 L
s
.26291 .19692 m
.2677 .20241 L
s
.49554 .37309 m
.4996 .38798 L
s
.31918 .63373 m
.32255 .65761 L
s
.23146 .4506 m
.2356 .46285 L
s
.33523 .19687 m
.33982 .20236 L
s
.51674 .31065 m
.52085 .31717 L
s
.40755 .19686 m
.41195 .20253 L
s
.49853 .33776 m
.50258 .35392 L
s
.46875 .20411 m
.47292 .21295 L
s
.49634 .24102 m
.50042 .25421 L
s
.49225 .22884 m
.49634 .24102 L
s
.52383 .28877 m
.52792 .2948 L
s
.50151 .30261 m
.50558 .3186 L
s
.50966 .3327 m
.51377 .3409 L
s
.72746 .20173 m
.73105 .20782 L
s
.50042 .25421 m
.50449 .26838 L
s
.48814 .21771 m
.49225 .22884 L
s
.65929 .21608 m
.663 .22112 L
s
.34468 .76054 m
.34751 .79664 L
s
.31983 .19578 m
.32447 .20127 L
s
.7123 .20101 m
.71584 .20582 L
s
.3922 .19574 m
.39664 .20128 L
s
.27709 .45946 m
.2811 .47322 L
s
.50258 .35392 m
.50668 .36503 L
s
.21193 .43725 m
.21484 .46124 L
s
.58287 .20576 m
.58676 .20933 L
s
.28003 .42441 m
.28343 .44555 L
s
.76949 .19952 m
.77284 .20407 L
s
.50449 .26838 m
.50857 .28332 L
s
.2811 .47322 m
.28514 .48662 L
s
.54925 .23696 m
.55326 .24037 L
s
.484 .20776 m
.48814 .21771 L
s
.30442 .19468 m
.30911 .20019 L
s
.37682 .19464 m
.38131 .20015 L
s
.53093 .26765 m
.53501 .27408 L
s
.28514 .48662 m
.28915 .5003 L
s
.61341 .20869 m
.6173 .21525 L
s
.6707 .20983 m
.67428 .21308 L
s
.37992 .98575 m
.37835 .91388 L
s
.6287 .21107 m
.63258 .21832 L
s
.59811 .20592 m
.60206 .21333 L
s
.69693 .19736 m
.70074 .20568 L
s
.28915 .5003 m
.29312 .51471 L
s
.50558 .3186 m
.50966 .3327 L
s
.64402 .2141 m
.64787 .22127 L
s
.40977 .98609 m
.41294 .93246 L
s
.29811 .39333 m
.30055 .42765 L
s
.44922 .19495 m
.45349 .2014 L
s
.289 .19359 m
.29372 .1991 L
s
.36143 .19354 m
.36597 .19905 L
s
.46454 .19672 m
.46875 .20411 L
s
.50857 .28332 m
.51265 .29812 L
s
.24335 .73883 m
.24875 .73649 L
s
.28557 .9157 m
.29075 .91297 L
s
.43387 .19359 m
.4382 .19949 L
s
.68208 .20251 m
.68555 .20437 L
s
.29312 .51471 m
.29701 .53019 L
s
.75434 .1989 m
.75784 .20457 L
s
.22061 .57684 m
.22601 .57637 L
s
.47984 .19922 m
.484 .20776 L
s
.50746 .2359 m
.51155 .24929 L
s
.50337 .22356 m
.50746 .2359 L
s
.27355 .19249 m
.27832 .19801 L
s
.34603 .19245 m
.35061 .19796 L
s
.41851 .19242 m
.42289 .19806 L
s
.49926 .21243 m
.50337 .22356 L
s
.51265 .29812 m
.51674 .31065 L
s
.51155 .24929 m
.51564 .26335 L
s
.22567 .64005 m
.23109 .63892 L
s
.73912 .19747 m
.74267 .20338 L
s
.53804 .24758 m
.54211 .2549 L
s
.36081 .77 m
.37459 .59056 L
s
.37618 .32478 m
.3795 .35278 L
s
.33061 .19135 m
.33523 .19687 L
s
.51974 .27718 m
.52383 .28877 L
s
.40313 .19131 m
.40755 .19686 L
s
.51564 .26335 m
.51974 .27718 L
s
.22289 .48841 m
.22769 .49424 L
s
.72386 .19577 m
.72746 .20173 L
s
.49513 .20267 m
.49926 .21243 L
s
.29701 .53019 m
.3008 .5471 L
s
.69345 .19465 m
.69693 .19736 L
s
.31517 .19025 m
.31983 .19578 L
s
.38773 .19021 m
.3922 .19574 L
s
.21919 .53119 m
.22455 .53152 L
s
.59417 .19936 m
.59811 .20592 L
s
.65549 .20955 m
.65929 .21608 L
s
.62482 .20414 m
.6287 .21107 L
s
.52683 .2565 m
.53093 .26765 L
s
.6095 .20196 m
.61341 .20869 L
s
.70864 .19478 m
.7123 .20101 L
s
.32255 .65761 m
.32575 .68476 L
s
.37997 .90445 m
.39003 .77802 L
s
.64015 .20684 m
.64402 .2141 L
s
.47563 .19208 m
.47984 .19922 L
s
.46028 .19042 m
.46454 .19672 L
s
.28343 .44555 m
.28701 .46487 L
s
.38346 .3687 m
.38833 .366 L
s
.56768 .21123 m
.57164 .21479 L
s
.29971 .18915 m
.30442 .19468 L
s
.37231 .18911 m
.37682 .19464 L
s
.51863 .23044 m
.52273 .2435 L
s
.51453 .21819 m
.51863 .23044 L
s
.76605 .19421 m
.76949 .19952 L
s
.52273 .2435 m
.52683 .2565 L
s
.44491 .18913 m
.44922 .19495 L
s
.55642 .22009 m
.56044 .2256 L
s
.49097 .1944 m
.49513 .20267 L
s
.51042 .20719 m
.51453 .21819 L
s
.3008 .5471 m
.30448 .56577 L
s
.57895 .20281 m
.58287 .20576 L
s
.28424 .18805 m
.289 .19359 L
s
.35688 .18801 m
.36143 .19354 L
s
.54518 .22874 m
.54925 .23696 L
s
.42951 .18797 m
.43387 .19359 L
s
.29036 .42457 m
.29337 .45138 L
s
.53395 .23665 m
.53804 .24758 L
s
.30865 .39154 m
.31068 .4328 L
s
.21484 .46124 m
.21852 .47816 L
s
.75081 .19298 m
.75434 .1989 L
s
.50629 .19766 m
.51042 .20719 L
s
.66698 .20442 m
.6707 .20983 L
s
.34143 .1869 m
.34603 .19245 L
s
.4141 .18686 m
.41851 .19242 L
s
.73553 .1913 m
.73912 .19747 L
s
.21852 .47816 m
.22289 .48841 L
s
.52984 .22452 m
.53395 .23665 L
s
.7203 .19064 m
.72386 .19577 L
s
.32596 .1858 m
.33061 .19135 L
s
.39868 .18575 m
.40313 .19131 L
s
.52573 .21269 m
.52984 .22452 L
s
.62092 .1975 m
.62482 .20414 L
s
.63627 .19973 m
.64015 .20684 L
s
.59027 .19537 m
.59417 .19936 L
s
.65164 .20246 m
.65549 .20955 L
s
.48677 .18747 m
.49097 .1944 L
s
.60556 .19482 m
.6095 .20196 L
s
.19506 .44917 m
.19724 .47951 L
s
.47139 .1859 m
.47563 .19208 L
s
.52162 .20196 m
.52573 .21269 L
s
.28701 .46487 m
.29068 .48327 L
s
.67847 .1985 m
.68208 .20251 L
s
.70487 .18711 m
.70864 .19478 L
s
.50214 .18963 m
.50629 .19766 L
s
.31048 .1847 m
.31517 .19025 L
s
.38323 .18465 m
.38773 .19021 L
s
.54108 .2181 m
.54518 .22874 L
s
.45599 .18465 m
.46028 .19042 L
s
.30448 .56577 m
.30803 .58655 L
s
.28026 .91971 m
.28557 .9157 L
s
.21499 .57899 m
.22061 .57684 L
s
.23792 .74089 m
.24335 .73883 L
s
.29498 .18359 m
.29971 .18915 L
s
.36777 .18354 m
.37231 .18911 L
s
.44057 .18351 m
.44491 .18913 L
s
.5175 .19268 m
.52162 .20196 L
s
.55235 .21126 m
.55642 .22009 L
s
.76256 .18844 m
.76605 .19421 L
s
.68995 .19184 m
.69345 .19465 L
s
.22015 .64181 m
.22567 .64005 L
s
.53698 .20702 m
.54108 .2181 L
s
.36431 .34709 m
.36691 .38752 L
s
.3523 .18244 m
.35688 .18801 L
s
.42513 .18239 m
.42951 .18797 L
s
.56364 .20419 m
.56768 .21123 L
s
.74726 .18701 m
.75081 .19298 L
s
.2138 .53077 m
.21919 .53119 L
s
.31926 .38965 m
.3209 .4381 L
s
.73196 .18566 m
.73553 .1913 L
s
.53287 .19671 m
.53698 .20702 L
s
.66318 .19782 m
.66698 .20442 L
s
.3368 .18133 m
.34143 .1869 L
s
.40967 .18128 m
.4141 .18686 L
s
.34751 .79664 m
.35013 .83793 L
s
.49796 .18287 m
.50214 .18963 L
s
.6324 .19292 m
.63627 .19973 L
s
.29068 .48327 m
.29436 .50172 L
s
.64778 .19532 m
.65164 .20246 L
s
.60164 .18918 m
.60556 .19482 L
s
.61701 .19056 m
.62092 .1975 L
s
.17488 .43999 m
.17591 .47922 L
s
.70144 .18475 m
.70487 .18711 L
s
.48255 .18139 m
.48677 .18747 L
s
.57497 .19713 m
.57895 .20281 L
s
.51336 .18489 m
.5175 .19268 L
s
.32575 .68476 m
.32875 .71591 L
s
.3795 .35278 m
.38346 .3687 L
s
.32129 .18022 m
.32596 .1858 L
s
.3942 .18017 m
.39868 .18575 L
s
.54826 .2012 m
.55235 .21126 L
s
.71661 .18378 m
.7203 .19064 L
s
.46712 .18016 m
.47139 .1859 L
s
.52875 .18774 m
.53287 .19671 L
s
.30576 .17911 m
.31048 .1847 L
s
.37871 .17906 m
.38323 .18465 L
s
.45167 .17902 m
.45599 .18465 L
s
.30803 .58655 m
.31143 .60991 L
s
.58632 .19036 m
.59027 .19537 L
s
.30055 .42765 m
.30305 .46211 L
s
.29337 .45138 m
.2965 .47713 L
s
.54415 .19145 m
.54826 .2012 L
s
.67473 .19274 m
.67847 .1985 L
s
.36321 .17795 m
.36777 .18354 L
s
.4362 .17791 m
.44057 .18351 L
s
.55957 .19527 m
.56364 .20419 L
s
.75903 .18252 m
.76256 .18844 L
s
.15069 .41635 m
.15052 .4633 L
s
.29436 .50172 m
.298 .52107 L
s
.33006 .38601 m
.33146 .44011 L
s
.35944 .72251 m
.3724 .56385 L
s
.74368 .18091 m
.74726 .18701 L
s
.34769 .17684 m
.3523 .18244 L
s
.42072 .17679 m
.42513 .18239 L
s
.5092 .17828 m
.51336 .18489 L
s
.35257 .3657 m
.35447 .41652 L
s
.65934 .1908 m
.66318 .19782 L
s
.52462 .18018 m
.52875 .18774 L
s
.64392 .18835 m
.64778 .19532 L
s
.6285 .18611 m
.6324 .19292 L
s
.49375 .17686 m
.49796 .18287 L
s
.61309 .18402 m
.61701 .19056 L
s
.72838 .18001 m
.73196 .18566 L
s
.33215 .17573 m
.3368 .18133 L
s
.40522 .17568 m
.40967 .18128 L
s
.54005 .18282 m
.54415 .19145 L
s
.47829 .17565 m
.48255 .18139 L
s
.71296 .17781 m
.71661 .18378 L
s
.59772 .18407 m
.60164 .18918 L
s
.57092 .18931 m
.57497 .19713 L
s
.6863 .18713 m
.68995 .19184 L
s
.34114 .3786 m
.34261 .43416 L
s
.55548 .18617 m
.55957 .19527 L
s
.3166 .17461 m
.32129 .18022 L
s
.3897 .17456 m
.3942 .18017 L
s
.46282 .17452 m
.46712 .18016 L
s
.23241 .74326 m
.23792 .74089 L
s
.20912 .58317 m
.21499 .57899 L
s
.27477 .92531 m
.28026 .91971 L
s
.37417 .17345 m
.37871 .17906 L
s
.44732 .1734 m
.45167 .17902 L
s
.20863 .52784 m
.2138 .53077 L
s
.2144 .64532 m
.22015 .64181 L
s
.19724 .47951 m
.20018 .50344 L
s
.298 .52107 m
.30154 .54206 L
s
.69789 .18101 m
.70144 .18475 L
s
.67093 .18608 m
.67473 .19274 L
s
.58231 .18343 m
.58632 .19036 L
s
.52048 .17369 m
.52462 .18018 L
s
.53594 .17548 m
.54005 .18282 L
s
.75548 .17648 m
.75903 .18252 L
s
.35862 .17233 m
.36321 .17795 L
s
.43181 .17228 m
.4362 .17791 L
s
.65549 .18377 m
.65934 .1908 L
s
.31143 .60991 m
.31465 .63638 L
s
.48542 .98784 m
.48475 .96877 L
s
.64004 .18152 m
.64392 .18835 L
s
.50501 .17232 m
.5092 .17828 L
s
.55139 .17792 m
.55548 .18617 L
s
.62459 .17933 m
.6285 .18611 L
s
.74013 .17536 m
.74368 .18091 L
s
.60917 .17835 m
.61309 .18402 L
s
.56686 .18089 m
.57092 .18931 L
s
.34306 .17121 m
.34769 .17684 L
s
.41629 .17116 m
.42072 .17679 L
s
.39263 .96141 m
.39818 .88247 L
s
.48952 .17113 m
.49375 .17686 L
s
.72466 .17281 m
.72838 .18001 L
s
.32747 .17009 m
.33215 .17573 L
s
.40074 .17004 m
.40522 .17568 L
s
.70948 .17458 m
.71296 .17781 L
s
.47401 .17 m
.47829 .17565 L
s
.59375 .17771 m
.59772 .18407 L
s
.2965 .47713 m
.29969 .50276 L
s
.38518 .16892 m
.3897 .17456 L
s
.45849 .16888 m
.46282 .17452 L
s
.68256 .18105 m
.6863 .18713 L
s
.32875 .71591 m
.33152 .7518 L
s
.5473 .17079 m
.55139 .17792 L
s
.53181 .1691 m
.53594 .17548 L
s
.57827 .17565 m
.58231 .18343 L
s
.56278 .17303 m
.56686 .18089 L
s
.3696 .1678 m
.37417 .17345 L
s
.44296 .16775 m
.44732 .1734 L
s
.6671 .17912 m
.67093 .18608 L
s
.31068 .4328 m
.31259 .4769 L
s
.65163 .17687 m
.65549 .18377 L
s
.51631 .16777 m
.52048 .17369 L
s
.63615 .1747 m
.64004 .18152 L
s
.30154 .54206 m
.30494 .56533 L
s
.75193 .17054 m
.75548 .17648 L
s
.62068 .17312 m
.62459 .17933 L
s
.35401 .16668 m
.35862 .17233 L
s
.4274 .16663 m
.43181 .17228 L
s
.50079 .16659 m
.50501 .17232 L
s
.20401 .51944 m
.20863 .52784 L
s
.73652 .16917 m
.74013 .17536 L
s
.72112 .16821 m
.72466 .17281 L
s
.60523 .17221 m
.60917 .17835 L
s
.69422 .17569 m
.69789 .18101 L
s
.3384 .16555 m
.34306 .17121 L
s
.41183 .1655 m
.41629 .17116 L
s
.48526 .16546 m
.48952 .17113 L
s
.20018 .50344 m
.20401 .51944 L
s
.36662 .91721 m
.37898 .74254 L
s
.22676 .74671 m
.23241 .74326 L
s
.39624 .16438 m
.40074 .17004 L
s
.46971 .16433 m
.47401 .17 L
s
.3741 .43507 m
.37947 .42426 L
s
.58973 .17047 m
.59375 .17771 L
s
.55871 .1661 m
.56278 .17303 L
s
.57422 .16816 m
.57827 .17565 L
s
.54319 .1645 m
.5473 .17079 L
s
.67876 .17433 m
.68256 .18105 L
s
.35013 .83793 m
.35265 .88286 L
s
.30305 .46211 m
.30558 .49725 L
s
.38063 .16325 m
.38518 .16892 L
s
.45415 .1632 m
.45849 .16888 L
s
.66326 .17218 m
.6671 .17912 L
s
.31465 .63638 m
.31767 .66663 L
s
.52766 .1632 m
.53181 .1691 L
s
.64775 .17004 m
.65163 .17687 L
s
.36691 .38752 m
.37 .42036 L
s
.70589 .16999 m
.70948 .17458 L
s
.63225 .16819 m
.63615 .1747 L
s
.26909 .93286 m
.27477 .92531 L
s
.17591 .47922 m
.17734 .51592 L
s
.20831 .65159 m
.2144 .64532 L
s
.20306 .58847 m
.20912 .58317 L
s
.36501 .16212 m
.3696 .1678 L
s
.43856 .16207 m
.44296 .16775 L
s
.51212 .16203 m
.51631 .16777 L
s
.61676 .16695 m
.62068 .17312 L
s
.74837 .1648 m
.75193 .17054 L
s
.34937 .16099 m
.35401 .16668 L
s
.42296 .16095 m
.4274 .16663 L
s
.49656 .1609 m
.50079 .16659 L
s
.73285 .16248 m
.73652 .16917 L
s
.60124 .16536 m
.60523 .17221 L
s
.36889 .51298 m
.37615 .46614 L
s
.29969 .50276 m
.30284 .52947 L
s
.30494 .56533 m
.30816 .59161 L
s
.40735 .15981 m
.41183 .1655 L
s
.5857 .16331 m
.58973 .17047 L
s
.48098 .15977 m
.48526 .16546 L
s
.69046 .16936 m
.69422 .17569 L
s
.57016 .16141 m
.57422 .16816 L
s
.7176 .1641 m
.72112 .16821 L
s
.11938 .40068 m
.11485 .47693 L
s
.55462 .15989 m
.55871 .1661 L
s
.67494 .16744 m
.67876 .17433 L
s
.39171 .15868 m
.39624 .16438 L
s
.46539 .15863 m
.46971 .16433 L
s
.53906 .15863 m
.54319 .1645 L
s
.6594 .16533 m
.66326 .17218 L
s
.64387 .16338 m
.64775 .17004 L
s
.37606 .15755 m
.38063 .16325 L
s
.44977 .1575 m
.45415 .1632 L
s
.62834 .16188 m
.63225 .16819 L
s
.52349 .15746 m
.52766 .1632 L
s
.6128 .16034 m
.61676 .16695 L
s
.36039 .15641 m
.36501 .16212 L
s
.3209 .4381 m
.32226 .49252 L
s
.43415 .15637 m
.43856 .16207 L
s
.5079 .15632 m
.51212 .16203 L
s
.7022 .16417 m
.70589 .16999 L
s
.74474 .15828 m
.74837 .1648 L
s
.72934 .15821 m
.73285 .16248 L
s
.59724 .15848 m
.60124 .16536 L
s
.58167 .15672 m
.5857 .16331 L
s
.4185 .15523 m
.42296 .16095 L
s
.4923 .15518 m
.49656 .1609 L
s
.5661 .15527 m
.57016 .16141 L
s
.36348 .59418 m
.37269 .51083 L
s
.68667 .16261 m
.69046 .16936 L
s
.40284 .15409 m
.40735 .15981 L
s
.47667 .15404 m
.48098 .15977 L
s
.67111 .16059 m
.67494 .16744 L
s
.22086 .75213 m
.22676 .74671 L
s
.55051 .15402 m
.55462 .15989 L
s
.33152 .7518 m
.33404 .79331 L
s
.65554 .15862 m
.6594 .16533 L
s
.15052 .4633 m
.15031 .5116 L
s
.63998 .15695 m
.64387 .16338 L
s
.38716 .15295 m
.39171 .15868 L
s
.46104 .15291 m
.46539 .15863 L
s
.53491 .15286 m
.53906 .15863 L
s
.35835 .89828 m
.37283 .69888 L
s
.71397 .1588 m
.7176 .1641 L
s
.62441 .15539 m
.62834 .16188 L
s
.37146 .15181 m
.37606 .15755 L
s
.44538 .15177 m
.44977 .1575 L
s
.5193 .15172 m
.52349 .15746 L
s
.31767 .66663 m
.32045 .7015 L
s
.60882 .15367 m
.6128 .16034 L
s
.30816 .59161 m
.31117 .62168 L
s
.30284 .52947 m
.30587 .55851 L
s
.59323 .15203 m
.59724 .15848 L
s
.74115 .15259 m
.74474 .15828 L
s
.42971 .15063 m
.43415 .15637 L
s
.50366 .15058 m
.5079 .15632 L
s
.69844 .15767 m
.7022 .16417 L
s
.57763 .15064 m
.58167 .15672 L
s
.26317 .94273 m
.26909 .93286 L
s
.19705 .59271 m
.20306 .58847 L
s
.20183 .66109 m
.20831 .65159 L
s
.68286 .1558 m
.68667 .16261 L
s
.41402 .14948 m
.4185 .15523 L
s
.35447 .41652 m
.35651 .46723 L
s
.48801 .14943 m
.4923 .15518 L
s
.56201 .14941 m
.5661 .15527 L
s
.66726 .15385 m
.67111 .16059 L
s
.72577 .1533 m
.72934 .15821 L
s
.65167 .15211 m
.65554 .15862 L
s
.37 .42036 m
.3741 .43507 L
s
.39831 .14834 m
.40284 .15409 L
s
.47235 .14829 m
.47667 .15404 L
s
.54639 .14824 m
.55051 .15402 L
s
.63607 .15051 m
.63998 .15695 L
s
.30558 .49725 m
.30805 .53427 L
s
.33146 .44011 m
.33251 .50202 L
s
.38258 .14719 m
.38716 .15295 L
s
.45666 .14715 m
.46104 .15291 L
s
.53074 .1471 m
.53491 .15286 L
s
.62046 .14888 m
.62441 .15539 L
s
.60484 .14734 m
.60882 .15367 L
s
.71026 .15263 m
.71397 .1588 L
s
.44096 .146 m
.44538 .15177 L
s
.51508 .14595 m
.5193 .15172 L
s
.17734 .51592 m
.17944 .54737 L
s
.58921 .14599 m
.59323 .15203 L
s
.31259 .4769 m
.31437 .52464 L
s
.69466 .15096 m
.69844 .15767 L
s
.73762 .14779 m
.74115 .15259 L
s
.42524 .14485 m
.42971 .15063 L
s
.4994 .1448 m
.50366 .15058 L
s
.57357 .14477 m
.57763 .15064 L
s
.67903 .14907 m
.68286 .1558 L
s
.34261 .43416 m
.34386 .49575 L
s
.66341 .1473 m
.66726 .15385 L
s
.40951 .1437 m
.41402 .14948 L
s
.48371 .14366 m
.48801 .14943 L
s
.35265 .88286 m
.35502 .93255 L
s
.55791 .14361 m
.56201 .14941 L
s
.64778 .14568 m
.65167 .15211 L
s
.63214 .14411 m
.63607 .15051 L
s
.39375 .14255 m
.39831 .14834 L
s
.46799 .14251 m
.47235 .14829 L
s
.54224 .14246 m
.54639 .14824 L
s
.72211 .14747 m
.72577 .1533 L
s
.21464 .7604 m
.22086 .75213 L
s
.61649 .14264 m
.62046 .14888 L
s
.45226 .14136 m
.45666 .14715 L
s
.52655 .14131 m
.53074 .1471 L
s
.60084 .14132 m
.60484 .14734 L
s
.7065 .14606 m
.71026 .15263 L
s
.43652 .1402 m
.44096 .146 L
s
.51084 .14015 m
.51508 .14595 L
s
.69086 .14426 m
.69466 .15096 L
s
.58517 .14012 m
.58921 .14599 L
s
.30587 .55851 m
.30869 .59118 L
s
.31117 .62168 m
.31392 .65647 L
s
.6752 .1425 m
.67903 .14907 L
s
.42075 .13905 m
.42524 .14485 L
s
.49512 .139 m
.4994 .1448 L
s
.56949 .13896 m
.57357 .14477 L
s
.65954 .14088 m
.66341 .1473 L
s
.73401 .14225 m
.73762 .14779 L
s
.64388 .13935 m
.64778 .14568 L
s
.19142 .59294 m
.19705 .59271 L
s
.40497 .13789 m
.40951 .1437 L
s
.47938 .13785 m
.48371 .14366 L
s
.55379 .1378 m
.55791 .14361 L
s
.62821 .13793 m
.63214 .14411 L
s
.32045 .7015 m
.32295 .74194 L
s
.46362 .13669 m
.46799 .14251 L
s
.53807 .13664 m
.54224 .14246 L
s
.7184 .14111 m
.72211 .14747 L
s
.61252 .13664 m
.61649 .14264 L
s
.25698 .95527 m
.26317 .94273 L
s
.70273 .13943 m
.7065 .14606 L
s
.33404 .79331 m
.33626 .84144 L
s
.44784 .13553 m
.45226 .14136 L
s
.52233 .13548 m
.52655 .14131 L
s
.59683 .13544 m
.60084 .14132 L
s
.68705 .1377 m
.69086 .14426 L
s
.19498 .67344 m
.20183 .66109 L
s
.43205 .13437 m
.43652 .1402 L
s
.67136 .13609 m
.6752 .1425 L
s
.50658 .13432 m
.51084 .14015 L
s
.58111 .13428 m
.58517 .14012 L
s
.65567 .13459 m
.65954 .14088 L
s
.41624 .13321 m
.42075 .13905 L
s
.17944 .54737 m
.18246 .57127 L
s
.49081 .13316 m
.49512 .139 L
s
.56538 .13312 m
.56949 .13896 L
s
.63997 .13321 m
.64388 .13935 L
s
.73034 .1361 m
.73401 .14225 L
s
.47502 .132 m
.47938 .13785 L
s
.54964 .13196 m
.55379 .1378 L
s
.62426 .13194 m
.62821 .13793 L
s
.71465 .13456 m
.7184 .14111 L
s
.30805 .53427 m
.31034 .57489 L
s
.45922 .13084 m
.46362 .13669 L
s
.53387 .13079 m
.53807 .13664 L
s
.60853 .13075 m
.61252 .13664 L
s
.69895 .13289 m
.70273 .13943 L
s
.68323 .1313 m
.68705 .1377 L
s
.44339 .12968 m
.44784 .13553 L
s
.51809 .12963 m
.52233 .13548 L
s
.59279 .12958 m
.59683 .13544 L
s
.18647 .58638 m
.19142 .59294 L
s
.66751 .12983 m
.67136 .13609 L
s
.15031 .5116 m
.15033 .55913 L
s
.35665 .70155 m
.36769 .58542 L
s
.42755 .12851 m
.43205 .13437 L
s
.50229 .12846 m
.50658 .13432 L
s
.57703 .12841 m
.58111 .13428 L
s
.20799 .7723 m
.21464 .7604 L
s
.65178 .12848 m
.65567 .13459 L
s
.48648 .1273 m
.49081 .13316 L
s
.56126 .12725 m
.56538 .13312 L
s
.32226 .49252 m
.32331 .55374 L
s
.63604 .12723 m
.63997 .13321 L
s
.72663 .12967 m
.73034 .1361 L
s
.30869 .59118 m
.31124 .62892 L
s
.47064 .12613 m
.47502 .132 L
s
.54546 .12608 m
.54964 .13196 L
s
.62029 .12603 m
.62426 .13194 L
s
.7109 .12806 m
.71465 .13456 L
s
.18246 .57127 m
.18647 .58638 L
s
.31392 .65647 m
.31635 .69719 L
s
.69515 .1265 m
.69895 .13289 L
s
.45479 .12496 m
.45922 .13084 L
s
.52965 .12491 m
.53387 .13079 L
s
.60452 .12486 m
.60853 .13075 L
s
.67941 .12506 m
.68323 .1313 L
s
.43892 .12379 m
.44339 .12968 L
s
.51383 .12374 m
.51809 .12963 L
s
.58874 .12369 m
.59279 .12958 L
s
.66365 .12373 m
.66751 .12983 L
s
.49798 .12257 m
.50229 .12846 L
s
.35651 .46723 m
.35922 .50795 L
s
.57293 .12252 m
.57703 .12841 L
s
.64788 .12249 m
.65178 .12848 L
s
.48212 .12139 m
.48648 .1273 L
s
.55711 .12134 m
.56126 .12725 L
s
.7229 .12322 m
.72663 .12967 L
s
.31437 .52464 m
.31589 .57769 L
s
.6321 .1213 m
.63604 .12723 L
s
.35577 .95616 m
.35502 .93255 L
s
.70713 .1217 m
.7109 .12806 L
s
.46624 .12022 m
.47064 .12613 L
s
.54127 .12017 m
.54546 .12608 L
s
.25518 .95956 m
.25698 .95527 L
s
.6163 .12012 m
.62029 .12603 L
s
.69136 .12028 m
.69515 .1265 L
s
.32295 .74194 m
.32513 .78906 L
s
.45034 .11904 m
.45479 .12496 L
s
.52541 .11899 m
.52965 .12491 L
s
.60049 .11895 m
.60452 .12486 L
s
.67557 .11897 m
.67941 .12506 L
s
.36321 .5265 m
.36889 .51298 L
s
.50954 .11782 m
.51383 .12374 L
s
.58466 .11777 m
.58874 .12369 L
s
.65978 .11774 m
.66365 .12373 L
s
.18787 .68732 m
.19498 .67344 L
s
.49365 .11664 m
.49798 .12257 L
s
.56881 .11659 m
.57293 .12252 L
s
.64397 .11654 m
.64788 .12249 L
s
.71916 .11688 m
.7229 .12322 L
s
.47774 .11546 m
.48212 .12139 L
s
.55294 .11541 m
.55711 .12134 L
s
.62814 .11536 m
.6321 .1213 L
s
.70336 .11548 m
.70713 .1217 L
s
.46181 .11428 m
.46624 .12022 L
s
.53705 .11423 m
.54127 .12017 L
s
.6123 .11418 m
.6163 .12012 L
s
.11485 .47693 m
.11057 .55317 L
s
.68755 .11419 m
.69136 .12028 L
s
.33626 .84144 m
.33819 .89691 L
s
.52115 .11305 m
.52541 .11899 L
s
.59643 .113 m
.60049 .11895 L
s
.33251 .50202 m
.33329 .57091 L
s
.67172 .11296 m
.67557 .11897 L
s
.31034 .57489 m
.31234 .62119 L
s
.50523 .11186 m
.50954 .11782 L
s
.58055 .11181 m
.58466 .11777 L
s
.20085 .78831 m
.20799 .7723 L
s
.65588 .11177 m
.65978 .11774 L
s
.48929 .11068 m
.49365 .11664 L
s
.56466 .11063 m
.56881 .11659 L
s
.64003 .11058 m
.64397 .11654 L
s
.71541 .11067 m
.71916 .11688 L
s
.34386 .49575 m
.34523 .55814 L
s
.31124 .62892 m
.31341 .6735 L
s
.47333 .10949 m
.47774 .11546 L
s
.54874 .10944 m
.55294 .11541 L
s
.62415 .10939 m
.62814 .11536 L
s
.69957 .10939 m
.70336 .11548 L
s
.53281 .10825 m
.53705 .11423 L
s
.60826 .10821 m
.6123 .11418 L
s
.68372 .10816 m
.68755 .11419 L
s
.51686 .10707 m
.52115 .11305 L
s
.59236 .10702 m
.59643 .113 L
s
.66785 .10697 m
.67172 .11296 L
s
.31635 .69719 m
.31839 .74539 L
s
.50089 .10588 m
.50523 .11186 L
s
.57643 .10583 m
.58055 .11181 L
s
.65197 .10578 m
.65588 .11177 L
s
.15033 .55913 m
.15086 .6036 L
s
.48491 .10468 m
.48929 .11068 L
s
.56048 .10463 m
.56466 .11063 L
s
.63607 .10458 m
.64003 .11058 L
s
.71166 .10457 m
.71541 .11067 L
s
.54452 .10344 m
.54874 .10944 L
s
.62015 .10339 m
.62415 .10939 L
s
.69578 .10335 m
.69957 .10939 L
s
.35922 .50795 m
.36321 .5265 L
s
.52854 .10225 m
.53281 .10825 L
s
.60421 .1022 m
.60826 .10821 L
s
.67988 .10215 m
.68372 .10816 L
s
.37776 .93806 m
.37997 .90445 L
s
.51255 .10105 m
.51686 .10707 L
s
.58825 .101 m
.59236 .10702 L
s
.66397 .10095 m
.66785 .10697 L
s
.49653 .09985 m
.50089 .10588 L
s
.57228 .0998 m
.57643 .10583 L
s
.64803 .09975 m
.65197 .10578 L
s
.18073 .70059 m
.18787 .68732 L
s
.55629 .09861 m
.56048 .10463 L
s
.63208 .09856 m
.63607 .10458 L
s
.70788 .09851 m
.71166 .10457 L
s
.54028 .09741 m
.54452 .10344 L
s
.61612 .09736 m
.62015 .10339 L
s
.69196 .09731 m
.69578 .10335 L
s
.32513 .78906 m
.32692 .84433 L
s
.52425 .0962 m
.52854 .10225 L
s
.60013 .09615 m
.60421 .1022 L
s
.67602 .0961 m
.67988 .10215 L
s
.50821 .095 m
.51255 .10105 L
s
.58413 .09495 m
.58825 .101 L
s
.66005 .0949 m
.66397 .10095 L
s
.56811 .09375 m
.57228 .0998 L
s
.64408 .0937 m
.64803 .09975 L
s
.31589 .57769 m
.31705 .63833 L
s
.32331 .55374 m
.324 .62295 L
s
.19319 .80857 m
.20085 .78831 L
s
.55207 .09254 m
.55629 .09861 L
s
.62808 .09249 m
.63208 .09856 L
s
.70409 .09244 m
.70788 .09851 L
s
.53601 .09134 m
.54028 .09741 L
s
.61207 .09129 m
.61612 .09736 L
s
.68812 .09124 m
.69196 .09731 L
s
.51994 .09013 m
.52425 .0962 L
s
.59603 .09008 m
.60013 .09615 L
s
.67213 .09003 m
.67602 .0961 L
s
.31234 .62119 m
.31391 .67565 L
s
.57998 .08887 m
.58413 .09495 L
s
.65612 .08882 m
.66005 .0949 L
s
.31341 .6735 m
.31509 .72709 L
s
.56391 .08766 m
.56811 .09375 L
s
.6401 .08761 m
.64408 .0937 L
s
.35593 .64093 m
.36348 .59418 L
s
.33906 .93177 m
.33819 .89691 L
s
.54783 .08645 m
.55207 .09254 L
s
.62405 .0864 m
.62808 .09249 L
s
.70028 .08634 m
.70409 .09244 L
s
.53172 .08523 m
.53601 .09134 L
s
.60799 .08518 m
.61207 .09129 L
s
.68426 .08513 m
.68812 .09124 L
s
.59191 .08397 m
.59603 .09008 L
s
.66822 .08392 m
.67213 .09003 L
s
.31839 .74539 m
.31994 .80316 L
s
.15086 .6036 m
.15212 .64276 L
s
.57581 .08275 m
.57998 .08887 L
s
.65217 .0827 m
.65612 .08882 L
s
.5597 .08153 m
.56391 .08766 L
s
.63609 .08148 m
.6401 .08761 L
s
.17385 .7106 m
.18073 .70059 L
s
.54356 .08032 m
.54783 .08645 L
s
.62 .08026 m
.62405 .0864 L
s
.69644 .08021 m
.70028 .08634 L
s
.60389 .07904 m
.60799 .08518 L
s
.68038 .07899 m
.68426 .08513 L
s
.58776 .07782 m
.59191 .08397 L
s
.66429 .07777 m
.66822 .08392 L
s
.57162 .0766 m
.57581 .08275 L
s
.64819 .07655 m
.65217 .0827 L
s
.55545 .07537 m
.5597 .08153 L
s
.63207 .07532 m
.63609 .08148 L
s
.34523 .55814 m
.34724 .61216 L
s
.61593 .0741 m
.62 .08026 L
s
.69259 .07405 m
.69644 .08021 L
s
.33329 .57091 m
.33398 .64421 L
s
.59977 .07287 m
.60389 .07904 L
s
.67647 .07282 m
.68038 .07899 L
s
.58359 .07164 m
.58776 .07782 L
s
.66034 .07159 m
.66429 .07777 L
s
.18501 .8328 m
.19319 .80857 L
s
.5674 .07041 m
.57162 .0766 L
s
.64419 .07036 m
.64819 .07655 L
s
.32692 .84433 m
.32826 .90969 L
s
.11057 .55317 m
.10672 .62808 L
s
.62802 .06913 m
.63207 .07532 L
s
.61183 .0679 m
.61593 .0741 L
s
.68871 .06784 m
.69259 .07405 L
s
.59562 .06666 m
.59977 .07287 L
s
.67255 .06661 m
.67647 .07282 L
s
.5794 .06543 m
.58359 .07164 L
s
.65636 .06537 m
.66034 .07159 L
s
.16754 .71474 m
.17385 .7106 L
s
.15212 .64276 m
.15434 .67458 L
s
.64016 .06414 m
.64419 .07036 L
s
.35208 .88059 m
.36081 .77 L
s
.62395 .0629 m
.62802 .06913 L
s
.60771 .06166 m
.61183 .0679 L
s
.68481 .06161 m
.68871 .06784 L
s
.31509 .72709 m
.31616 .79246 L
s
.31391 .67565 m
.3149 .74107 L
s
.34689 .86345 m
.35944 .72251 L
s
.31705 .63833 m
.31771 .70909 L
s
.59145 .06042 m
.59562 .06666 L
s
.6686 .06037 m
.67255 .06661 L
s
.65237 .05912 m
.65636 .06537 L
s
.63612 .05788 m
.64016 .06414 L
s
.61985 .05663 m
.62395 .0629 L
s
.60357 .05539 m
.60771 .06166 L
s
.68089 .05533 m
.68481 .06161 L
s
.324 .62295 m
.32435 .70075 L
s
.31994 .80316 m
.32089 .87327 L
s
.66463 .05408 m
.6686 .06037 L
s
.16207 .71081 m
.16754 .71474 L
s
.64835 .05283 m
.65237 .05912 L
s
.15434 .67458 m
.15765 .69752 L
s
.63205 .05158 m
.63612 .05788 L
s
.61573 .05033 m
.61985 .05663 L
s
.67694 .04902 m
.68089 .05533 L
s
.66063 .04777 m
.66463 .05408 L
s
.15765 .69752 m
.16207 .71081 L
s
.6443 .04651 m
.64835 .05283 L
s
.34724 .61216 m
.35058 .64447 L
s
.17636 .86027 m
.18501 .8328 L
s
.35058 .64447 m
.35593 .64093 L
s
.62796 .04525 m
.63205 .05158 L
s
.67297 .04268 m
.67694 .04902 L
s
.65661 .04142 m
.66063 .04777 L
s
.64024 .04015 m
.6443 .04651 L
s
.34741 .77706 m
.35665 .70155 L
s
.32828 .91153 m
.32826 .90969 L
s
.66898 .0363 m
.67297 .04268 L
s
.65257 .03503 m
.65661 .04142 L
s
.33398 .64421 m
.33498 .71558 L
s
.66497 .02988 m
.66898 .0363 L
s
.31616 .79246 m
.31646 .87293 L
s
.3149 .74107 m
.31518 .82042 L
s
.10672 .62808 m
.10348 .70022 L
s
.31771 .70909 m
.3178 .79191 L
s
.1685 .88604 m
.17636 .86027 L
s
.32093 .8936 m
.32089 .87327 L
s
.32435 .70075 m
.32449 .7853 L
s
.33498 .71558 m
.33698 .77292 L
s
.10348 .70022 m
.10103 .76806 L
s
.31643 .87759 m
.31646 .87293 L
s
.31495 .8637 m
.31518 .82042 L
s
.34087 .79896 m
.34741 .77706 L
s
.31753 .8528 m
.3178 .79191 L
s
.33698 .77292 m
.34087 .79896 L
s
.32475 .84547 m
.32449 .7853 L
s
.10103 .76806 m
.09953 .83008 L
s
.09948 .83614 m
.09953 .83008 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.23115 .18555 m
.23598 .19102 L
s
[(1)] .22151 .17463 .88293 1 Mshowa
.36874 .1277 m
.37327 .13341 L
s
[(2)] .35968 .11629 .79394 1 Mshowa
.51427 .06651 m
.51847 .07247 L
s
[(3)] .50588 .0546 .70494 1 Mshowa
.66846 .00168 m
.67228 .00789 L
s
[(4)] .66081 -0.01073 .61595 1 Mshowa
.125 Mabswid
.12637 .22961 m
.12939 .23277 L
s
.15215 .21877 m
.15514 .22196 L
s
.1782 .20782 m
.18116 .21104 L
s
.20453 .19675 m
.20746 .19999 L
s
.25807 .17424 m
.26093 .17754 L
s
.28528 .16279 m
.28811 .16613 L
s
.31279 .15123 m
.31558 .15459 L
s
.34061 .13953 m
.34337 .14292 L
s
.39719 .11574 m
.39987 .11919 L
s
.42596 .10364 m
.42861 .10713 L
s
.45507 .09141 m
.45767 .09492 L
s
.4845 .07903 m
.48706 .08257 L
s
.54439 .05385 m
.54687 .05745 L
s
.57487 .04103 m
.5773 .04467 L
s
.6057 .02807 m
.60808 .03173 L
s
.63689 .01495 m
.63923 .01865 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(10)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(20)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(30)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(40)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00kOooool2o`000003oa0@4?oooooooooo05Wooooo
003^ooooo`03o`000?oooooooooo05[ooooo003[ooooo`Go0000Foooool00>_ooooo00CoA4A4omgM
gOoooooo0000G?ooool00>_ooooo00CogMgMoeEEEOoooooo0000G?ooool00>cooooo00?oMgMgolc<
c?l00000G?ooool00>cooooo00?ok^k^odA4A?l00000G?ooool00>gooooo00?oMgMgo`000?ooool0
Foooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?;ooooo
0_l0001Gooooo`00koooool5o`0005Oooooo003]ooooo`;o00001?ooool2o`0005Kooooo003[oooo
o`;o00001_ooool00ol0003oooooo`00001Eooooo`00j?ooool3o`0000Sooooo00?o0000ooooool0
0000EOooool00>Kooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
0000E?ooool008_ooooo0_l00002ooooo`03oa0@4?l0003o000002oooooo00GoV9RHoa0@4?l0003o
<S8bolc<c00Mooooo`?o00003Oooool01?l0003oooooooooool0001Dooooo`00S?ooool01Ol0003o
ooooonk^k_lb<S;oc<c<033ooooo00Go410@okZj^_ooooooMgMgoc8b<P0Kooooo`;o00004?ooool0
1Ol0003ooooooooooooooooo000005?ooooo002<ooooo`04o`000?nHV9So<S8bolc<c3Gooooo00?o
0000ooooooooool05oooool2o`000003ooooool0003ooooo00gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`1@ooooo`00S?ooool00ol0003o410@oiRHV00eooooo`03ojVYZOl@413o
oooo01Gooooo0ol00003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`1@ooooo`00S?ooool01?l0003ok^k^oeEEEOn7QhLcooooo`03oa0@4?l0003o
^[Zj01Cooooo0_l0000Booooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03o`00
0?oooooooooo04oooooo002<ooooo`05o`000?ooooooA4A4o`000?l@4100<oooool00onj^[[o8B4Q
ooooo`0Aooooo`;o00004Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`1?ooooo`00S?ooool00ol0003oooooooooo`0booooo`05oa0@
4?nHV9SooooookZj^_l000003oooool3o`0000;ooooo00?o0000ooooooooool02_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooo
oooo04kooooo002<ooooo`03o`000?oooooooooo03;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0=
ooooo`;o00004oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo04gooooo002;ooooo`;o0000@oooool3o`00017ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
oooo0_l00005ooooo`03o`000?oooooooooo04gooooo003>ooooo`;o000000?oooooo`000?l00000
3_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`1<ooooo`00c?ooool2
o`00013ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000Kooooo00?o0000oooooooo
ool0Boooool00<Wooooo0ol0000Booooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo0037ooooo`?o00004Oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1:ooooo`00a?ooool3o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0B_ooool00<;ooooo0_l0000@ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Wooooo0030ooooo`;o00004_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`18ooooo`00V_ooool5o`0001kooooo0ol00002ooooo`03o`000?oo
oooooooo00cooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?oo
ool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Looooo`;o00004Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo002K
ooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0000@ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0A_oo
ool009cooooo00?oV9RHob4Q8Oo^k^h05oooool3o`000003ooooool0003ooooo00cooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`16ooooo`00WOooool00omgMgOoIVIVooooo`0Doooo
o`;o00004_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo002Noooo
o`03o`000?oooooooooo013ooooo0ol0000Aooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`15ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So
410@013ooooo0_l000000ooooooo0000ooooo`0>ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?oo
ool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04?ooooo002Zooooo`?o00004_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooooooooooooooo0000
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0@oooool00:Sooooo0ol0000@ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo
002Uooooo`?o00000oooool00ol0003oooooooooo`0:ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooooooool2o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04;ooooo002Sooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`00XOooool3o`0000kooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`10ooooo`00W_ooool3o`0000;ooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0@?ooool009cooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?oooool009[ooooo0_l0000@ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03ko
oooo001fooooo`Co000000?o410@ooooooooool06_ooool3o`0000;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`00N?ooool00ol0003oooooooooo`0Jooooo`;o00003oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Ooo
ool007Sooooo00?o0000ooooooooool05oooool3o`0000kooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool007Sooooo00?o0000ooooooooool05Oooool2o`0000?ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0looooo`00N?ooool00ol0003oooooooooo`0Cooooo`;o0000
4Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0kooooo`00N?ooool00ol0003oooooooooo`0@ooooo`?o00004?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`09o`000?oooooooooo
ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0>oooool007Sooooo00?o0000oooooooo
ool03_ooool2o`0000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0jooooo`00M_ooool00omEEEGoIVIVo`00000=ooooo`?o00003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0>Oooool008Cooooo0_l0000Booooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool2o`000003ooooool0003ooooo
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool008;ooooo0_l00002ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool2o`0000;ooooo00Co
0000oooooooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Sooooo001oooooo`?o00004?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Sooooo001mooooo`;o00004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=oooool007_ooooo0_l00002ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool007Sooooo
0ol00005ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`09o`000?ooooooooooooooool0003ooooo
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo001Boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07oooool2o`0000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oooooooooo
ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0eoooo
o`00D_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo0ol00002ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0eooooo`00D_ooool01Ol@413ooooooooooooooooo410@01[ooooo0_l0
000Aooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0=?ooool005;ooooo00Go0000oooooooo
ooooooooo`00000Hooooo`;o00004?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool005;ooooo00Go
0000ooooooooooooooooo`00000Eooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02o`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0<oooool0
05;ooooo00Go410@oooooooooooooooooa0@400Cooooo`;o00004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00004ooooo`?o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo001Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL04?ooool3o`0000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool0<Oooool005;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0<Oooool006?ooooo0_l0000Aooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000001?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo0_l00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033o
oooo001Pooooo`Co00003oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
033ooooo001Nooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00002
ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;oooool005cooooo0_l0
000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooo`000?l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`09o`000?oooooooooooooo
ool0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;_ooool005Wooooo1?l0000>ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo001Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
oooo0ol00002ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0]ooooo`00F?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0;Oooool005Sooooo0_l00009oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooo`000?ooool00_l000001Ooooooo
0000oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0;?ooool005Sooooo0ol00008ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol00002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`00
Eoooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:oooool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:_ooool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`06o`000?oooooo
0000o`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo001=ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo0_l0
0002ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0Yooooo`00COooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool01Oooool01Ol0003oooooo`000?oooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Sooooo001=ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`06oooo
o`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000oooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?oo
ool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo001=ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_l000000ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooo000000Wooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`00COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo0_l0000;ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000ooo
ool4o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`04o`000?oooooooooo
o`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool005Ko
oooo00?o0000ooooooooool02Oooool01ol0003oooooo`000?oooooo0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool3o`0000Cooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo001Fooooo`03o`000?oo
oooooooo00Wooooo00Go0000oooooooooooo0000ooooo`02o`0000Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo1?l000000ooooooo0000ooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo001F
ooooo`03o`000?oooooooooo00Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?o000000Coooooo`000?oooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Toooo
o`00E_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
oooo1?l00003ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Sooooo`00EOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000oooool2o`0000;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`00
EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l000001Ooooooo0000
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol00002oooo
o`?o000000Goooooo`000?ooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooooooool3o`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Rooooo`00EOooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00EOooool2o`00
00_ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00EOooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00004oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooo
oooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03
o`000?oooooooooo00;o00001?ooool00ol0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Pooooo`00EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo0ol00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000Cooooo
o`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`02
o`000005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool005Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo0ol000001Ooooooo0000oooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0
003oooooooooool00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool2o`00
0007ooooool0003oooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Oooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooo`0000Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooooooo0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Nooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00So0000oooooooooooo
0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool3o`000003ooooool0
003o000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool3o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000Go
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0Nooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`Go000000?o
ooooo`000?ooool00_l00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`02o`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_l00002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Mooooo`00E?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000;o000000Coooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000003ooooo`Go000000Goooooo`000?ooooooooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool2o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Looooo`00E?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`03
o`000003ooooool0003ooooo00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`000005ooooool0003o0000oooo
ool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`?o0000
0_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool07?ooool005Cooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool2o`000004ooooool0003oooooo`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000;o000000?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;o00000oooool0
1_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000004oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool06oooool005?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o0000
00?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000000_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06oooool005?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo
0000ooooool00003ooooo`Oo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?ooool2o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo01[ooooo001Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool3o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000
o`000003o`0000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05o`000003ooooool0003o0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;o000000?oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000Cooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`00
Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?oooooo0000ooooool000000_ooool01?l0003oooooooooooooool4o`000004ooooool0003o0000
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`07o`00
0?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o00000_ooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo001C
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`?o000000?oooooo`000?ooool00oooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0003ooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`;o0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06?ooool005?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`03ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oo
oooo0000ooooool00002ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`03
o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0G
ooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool3o`000003ooooool0003ooooo00;o00000_ooool0
2?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool2o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o000000Ko
ooooo`000?l0003oooooo`000?ooool2o`0000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000;ooooo00?o0000ooooool000001?ooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool005;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000001?ooool3o`000003ooooool0003ooooo00;o00000_ooool01?l0
003oooooooooool00002ooooo`;o00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo
00000_ooool02Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooo`02o`000004ooooool0
003oooooo`0000;ooooo00Co0000oooooooooooo00001?ooool02_l0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?oo
ool00oooool01Ol0003oooooo`000?l0003ooooo00?o00000oooool00ol0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001Booooo`?o
00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`Co000000Oooooo
o`000?ooooooooooo`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooo`000004ooooo`05o`000?oooooo0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0Fooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Gooooo00Co0000oooooooo
oooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;o000000Goooooo`000?l0003oooooo`000003ooooo`;o0000
0_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0
0002ooooo`;o00000_ooool01?l0003oooooooooool00005ooooo`06o`000?oooooo0000ooooool0
003ooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0Eooooo`00D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Co
oooo0ol00003ooooo`?o00000_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000ol000001_oo
oooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000000oooool3o`000003ooooool0
003ooooo00;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000oooo
ool000001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Cooooo001Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000oooool3o`000004ooooool0003ooooooooo
o`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?oooooo0000o`0000;ooooo00?o
0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?l00000
0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool2
o`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Dooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo0ol000000ooooooo
0000ooooo`03o`000005ooooool0003o0000ooooool000000_ooool02Ol0003oooooo`000?oooooo
0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00_l000003_oooooo
0000o`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool02Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Cooooo`00DOooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`Co00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool3o`000003ooooool0003ooooo00;o000000Woooooo`000?ooooooooooo`000?oooooo0000
ooooool000000_ooool2o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`03o`00
0?oooooo000000Go000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00?o0000
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooo
oooooooo0000ooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01?ooooo001Aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`?o000000?oooooo`000?l000000_l000002Ooooooo0000oooo
oooooooo0000ooooool0003oooooo`000002ooooo`;o000000Ooooooo`000?ooooooooooo`000?oo
oooo000000;ooooo00Co0000ooooool0003ooooo1?l000001?oooooo0000ooooool00002ooooo`;o
00000_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
ooooool0003o00000oooool3o`000003ooooool0003ooooo00;ooooo0_l000000ooooooo0000o`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo001A
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00ol000001Ooooooo0000oooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00Co00000ooo
ool2o`0000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002ooooo`05o`00
0?oooooo0000ooooool000000_ooool5o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000Gooooo00?o0000ooooooooool00ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l00005ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooooooo
o`?o00004oooool0057ooooo0ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`?o0000017o
ooooo`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`000006ooooool0003oooooo`00
0?oooooo00000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool2o`0000Cooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`02
o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003ooooooooo
o`0Aooooo`00DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?oooooo
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo0_l0
00001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo
00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool0
00000_ooool3o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00004
ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`05ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003ooooo
ooooo`0Aooooo`00DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooo`000?ooool00ol000001Ooooooo
0000oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o
000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo0_l00000
1ooooooo0000oooooooooooo0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Wo0000oooooooooooo0000ooooool0003o
ooooo`000?ooool00ol000000ooooooo0000ooooo`04o`000005ooooool0003o0000ooooool00000
0oooool01ol0003oooooooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00003ooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`0Aoooo
o`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`Co0000
0oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001ooooooo0000oooooooo
oooo0000ooooool000000_ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`05o`00
0?oooooo0000ooooool000000oooool3o`000005ooooool0003oooooo`000?ooool02_l00003oooo
o`;o00001?ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00ol000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo017ooooo
000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo0ol000001?oooooo0000ooooooooool5o`0000;ooooo00?o0000ooooooooool00_l00000
0ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000009
o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooooooo00Ko00000_ooool0
1?l0003oooooooooool00004ooooo`;o00001?ooool00ol0003oooooo`000002ooooo`;o000000?o
ooooo`000?l000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o000000?oooooo`000?ooool0
3?ooool00ol0003oooooooooo`0@ooooo`00=_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`08o`000?ooooooooooooooool0003oooooo`000?oo
ool3o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000002ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`0000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000004o`000008ooooool0003o0000o`000?oo
oooo0000ooooool00002ooooo`03o`000?oooooo000000?ooooo0ol000001Ooooooo0000ooooool0
003ooooo00;o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;ooooo
0_l000001?oooooo0000ooooooooool2o`000003ooooool0003o000000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool3o`000003
ooooool0003ooooo00oooooo00?o0000ooooooooool04?ooool003Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool3o`000005ooooool0003o0000
o`000?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o000000Coooooo`000?oooooo
oooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo0_l000000ooo
oooo0000ooooo`03o`0000;ooooo00Go0000ooooool0003oooooo`000003ooooo`?o00000oooool0
1?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool00000
0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00ol00000
0ooooooo0000ooooo`0Booooo`03o`000?oooooooooo013ooooo000fooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo1ol000002?oooooo0000
o`000?l0003oooooo`000?oooooo00000_ooool2o`000003ooooool0003ooooo00;o000000Cooooo
o`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l000001_l0
00001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Cooooo2?l00002oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`?o000000?ooooo
o`000?ooool00oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000;o00000_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo000fooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo1?l000001?oooooo0000ooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`Go000000?oooooo`000?ooool0
1Ol00002ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`000005ooooool0003ooooo
ooooool000000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Oo
0000oooooooooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000001?oooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Cooooo00Wo0000
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool0
1_l0003ooooooooooooooooo0000ooooo`?o00000_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo013ooooo000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo
000000?o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Co0000
00Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Goooooo`000?oo
ooooooooo`000002ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo1?l000001?oo
oooo0000ooooool00002ooooo`Co00000_ooool2o`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`04o`000?oooooo0000oooo
o`;o000000?oooooo`000?ooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0@ooooo`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o
EEEEofIVI_l000001Oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_l00002oooo
o`03o`000?oooooo000000;ooooo0ol000000ooooooo0000o`000003o`000007ooooool0003ooooo
o`000?oooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000Goooooo`000?l0003oooooo`000004ooooo`03o`000?oooooo
000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`05o`0000;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`00Coooool2o`0000oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000ol000001?oooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooo`000?l00002ooooo`So00000_ooool01Ol0003oooooo`000?l0003ooooo00?o00000_oo
ool00ol0003oooooo`000002ooooo`?o000000?oooooo`000?l000000ol000001_oooooo0000oooo
ool0003oooooo`0000;ooooo1Ol00003ooooo`?o00000_ooool00ol0003oooooo`000002ooooo`04
o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;o00000oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?ooooo0_l00000
1?oooooo0000ooooooooool4o`0000?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0?ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003oooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo1_l0
00001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo
0000ooooool00002ooooo`?o000000Coooooo`000?l0003o00000oooool01Ol0003oooooo`000?oo
oooo000000;ooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00?o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o00000ooo
ool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000007ooooo`Co00000_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo001?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000_ooool5o`000005ooooool0
003oooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l000001?oooooo
0000ooooooooool6o`000006ooooool0003o0000ooooool0003ooooo0_l000000ooooooo0000oooo
o`02o`000006ooooool0003oooooooooool0003ooooo0_l000000ooooooo0000ooooo`02o`0000?o
oooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`08ooooo`;o00000_ooool2o`00
00;ooooo00?o0000ooooooooool01?l00003ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00Go0000:_ooool00ol0003oooooooooo`0?ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooool0003oooooo`000002ooooo`;o000000Goooooo`000?l0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000005oooo
ool0003oooooo`000?ooool01Ol000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`00
0?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o000000?oooooo`000?ooool00_l0
0002ooooo`;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Co00000oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`05o`000?oooooo
ooooo`000?ooool01Ol0000]ooooo`03o`000?oooooooooo00oooooo001?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo
0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000005
ooooool0003oooooo`000?ooool00_l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l0
00001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo1?l00002ooooo`Co
000000Koooooo`000?l0003oooooo`000?ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`00
0?ooool2o`0000Cooooo00?o0000ooooool000000_ooool01ol0003oooooooooool0003oooooo`00
0?ooool00_l00003ooooo`Ko00000oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00oooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?oooooo
0000ooooo`;o00000_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000?o
000000Coooooo`000?l0003ooooo0ol000001Ooooooo0000o`000?oooooo000000?ooooo0ol00002
ooooo`Co000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`000?ooool3o`0000;ooooo
00?o0000ooooool000000oooool00ol0003oooooo`000002ooooo`09o`000?ooooooooooo`000?oo
oooo0000ooooool0003ooooo00Oo00000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00oooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool2
o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooooooool0
00000oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00;o000000?oooooo`00
0?ooool00_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o00000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo1_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?oooooooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo1ol00002ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000oooooooo
ool03oooool004kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
000000Ooooooo`000?oooooo0000ooooool0003ooooo00Co00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo0ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool01_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Co
0000ooooool0003ooooo2?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool01Ol0003o
ooooo`000?l0003ooooo00?o00000_ooool2o`000003ooooool0003o000000;o000000Koooooo`00
0?l0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooool000000_ooool4o`0000;ooooo00Go
0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o00000_oo
ool01Ol0003oooooooooool0003ooooo00;o000000Woooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0005o`000003ooooool0003ooooo00;o000000?oooooo`000?l000001?l000001Ooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool00_ooool01?l0003oooooo`000?ooool8o`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`;o000000?oooooo`000?ooool00ol000000ooo
oooo0000ooooo`03o`00000?ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo1?l00002ooooo`04o`000?ooooooooooo`0003Sooooo00?o
0000ooooooooool03_ooool004kooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00;o000000Koooooo`000?oo
oooo0000ooooool00002ooooo`;o000000?oooooo`000?ooool00_ooool01_l0003ooooooooooooo
oooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`000004ooooool0003o0000oooo
o`?o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000001?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool01?l0
00001Ooooooo0000ooooool0003ooooo00;o000000?oooooo`000?l000001?l000001?oooooo0000
o`000?l00002ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`00
C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool02?l0003ooooooooooooooooo0000ooooool0003ooooo0ol000001_oooooo0000ooooool0
003oooooo`0000;ooooo1?l00003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00003oooo
o`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000_l000001ooooooo0000ooooool0
003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool:o`000007ooooool0003o0000o`000?oooooo0000ooooo`04o`000003ooooool0003o
000000So00000_ooool00ol0003oooooooooo`02ooooo`?o000000Goooooo`000?oooooo0000oooo
o`03o`0003gooooo00?o0000ooooooooool03_ooool004kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00?o000000Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000
o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000_ooool01?l0
003oooooo`000?l00003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000002o`0000;ooooo1_l000000ooooooo0000ooooo`04o`0000Cooooo00?o0000
ooooool000000ol000001?oooooo0000ooooool00002ooooo`?o0000?_ooool00ol0003ooooooooo
o`0>ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00005
ooooo`03o`000?oooooooooo00;o000000[oooooo`000?l0003o0000ooooool0003oooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00ol000000ooo
oooo0000ooooo`02ooooo`;o00000_ooool6o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003o00000_ooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000;o000000Co
ooooo`000?oooooooooo1?l000000ooooooo0000o`000002o`0000;ooooo1Ol00002ooooo`03o`00
0?oooooo000000Co00000_ooool3o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00Co
0000?_ooool00ol0003oooooooooo`0>ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?ooool4o`000006
ooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`03o`000004ooooool0003o
ooooooooo`Co000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Go000000?oooooo`000?ooool00_l00002ooooo`Co00000_ooool00ol0003ooooo
o`000002o`000006ooooool0003oooooooooool0003ooooo0_l000001?oooooo0000ooooool00003
ooooo`Go00000oooool01?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`Ko0000
00?oooooo`000?l000000_l0000nooooo`03o`000?oooooooooo00kooooo001=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`05o`000?oo
oooo0000o`000?ooool00_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooo
oooooooo0000ooooo`03o`0000;ooooo1?l000001?oooooo0000ooooooooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`0000?ooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002o`000004ooooool0003oooooooooo`Co0000
00?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00?o000000?oooooo`000?oo
ool01?l00002ooooo`?o000000?oooooo`000?ooool02?l000000ooooooo0000ooooo`0mooooo`03
o`000?oooooooooo00kooooo001=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`?o000000Woooooo`000?l0003oooooo`000?oooooo0000
ooooool000000_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool4o`000009ooooool0
003oooooo`000?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000003ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`03o`000004ooooool0
003oooooooooo`Co000000?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00Oo
00000_ooool00ol0003oooooo`000005o`0000;ooooo0ol000001_oooooo0000ooooool0003ooooo
o`0003oooooo00?o0000ooooooooool03Oooool004gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0<ooooo`;o00001?ooool6o`000005ooooool0003o0000ooooool000000_ooool0
1?l0003oooooooooool00003ooooo`?o000000goooooo`000?l0003o0000ooooool0003oooooo`00
0?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001ol000000ooooooo0000o`00
0003ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`03o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00Go00000_ooool0
1?l0003oooooo`000?ooool2o`000003ooooool0003o000000;o00000_ooool01Ol0003oooooo`00
0?oooooo000000;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`001_oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool0
2?ooool00omVIVKoMgMgooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool6o`000005ooooool0003o0000ooooool0
00000_ooool01?l0003oooooooooool00004ooooo`Ko000000Woooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000000ooooooo0000o`000008o`000003ooooool0003o000000?ooooo
00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000Coooooo`000?l0003o00000_ooool6
o`0000?ooooo1_l00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00gooooo0006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001ooo
ool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo
1_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000006ooooool0003o
0000ooooool0003ooooo1Ol000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Co000000Coooooo`000?l0003o
00000_ooool03Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oo
ool00_l000000ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool03Oooool000Kooooo00?o0000ooooooooool00oooool01_mVIVKo0000o`000?m4A4Coc<c<o`00
00;ooooo00?o0000ooooooooool01Oooool00omEEEGoV9RHooooo`02ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00on7QhOoIVIVooooo`06ooooo`03o`000?oooooooooo01Oooooo0ol0000?
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`Go00003Oooool00ol0003oooooo`000003o`000003ooooool0003o000000;ooooo00?o0000
ooooool000000oooool00ol0003oooooooooo`03ooooo`0<o`000?oooooo0000o`000?oooooo0000
ooooool0003oooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003o000000Go000000Coooooo`000?oooooooooo0ol000001ooooooo0000o`000?l0003oooooo`00
0?ooool01?l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000?ooooo0_l00000
1_oooooo0000ooooool0003oooooo`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0ol00008ooooo`03o`000?oooooooooo00;o
oooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`?o00002oooool5o`000003ooooool0003o0000
00;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`00
0?l000000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?ooool8o`000005ooooool0003oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`000003oooo
o`;o000000Koooooo`000?oooooo0000ooooool00002ooooo`?o00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oc8b<_oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03_ooool4o`0000Oooooo00?o0000ooooool000000_l000000ooooooo0000o`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?l0
003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o0000
00?oooooo`000?l000001?l000000ooooooo0000ooooo`09o`000005ooooool0003oooooo`000?oo
ool01_l00002ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003ooooo
o`0000;ooooo00?o0000ooooool000000_l0000>ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool3o`0000Gooooo1?l000000ooo
oooo0000o`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0
003oooooo`000?l0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo
000000;ooooo2_l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo
1_l000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`000003oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0000>ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool00_oo
ool01_mVIVKoMgMgooooooooooooQhN7o`0000_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`05ooooo`03onk^k_l0003ooooo00Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`;o00001?ooool6o`0000;ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`03ooooo`?o000000?oooooo`000?l000000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooo000000;ooooo2_l000000ooooooo0000ooooo`02o`000004ooooool0003o0000oooo
o`Go000000Coooooo`000?l0003ooooo1?l000001ooooooo0000o`000?oooooo0000ooooool00000
0oooool3o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`02ooooo`06
onk^k_mVIVKo0000o`000?m4A4Co00002oooool01?mEEEGoMgMgooooool@4105o`0000Cooooo00?o
MgMgoeEEEOooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo0ol0
0002ooooo`Go00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000002ooooo`[o
000000Goooooo`000?l0003oooooo`000002ooooo`Co000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000005o`000003ooooool0003ooooo00;o00000_ooool3o`000006ooooool0003o
ooooo`000?oooooo00000_ooool2o`0000kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`001_ooool00ol0003oooooooooo`0Cooooo`03omgMgOl@413ok^k^00;ooooo00?o
0000ooooooooool01?ooool00oo^k^ko410@omgMg@07ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`03o`000006ooooool0003oooooo`000?oooooo
00000oooool00ol0003oooooooooo`03ooooo`?o00000oooool01Ol0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooool000000_ooool=o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o00000_oo
ool3o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000oooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0Dooooo`05ogMg
MomVIVKoooooooooool000001_ooool00omVIVKoMgMgooooo`07ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02o`000006ooooool0003oooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`Co00001?ooool2o`000003ooooool0003o
oooo00;ooooo0ol00002ooooo`oo00001?ooool2o`0000;ooooo00?o0000ooooool000002ol00000
0ooooooo0000o`000002ooooo`Oo000000Coooooo`000?oooooooooo0_l0000?ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool03?ooool004_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool0
2_l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo1?l00005ooooo`03o`000?oooooo000000?ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000002_l00004ooooo`;o00000_ooool00ol0003oooooo`000004o`000003ooooool0003o0000
00?o00000_ooool2o`0000;ooooo1ol000001Ooooooo0000o`000?oooooo0000013ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`00Boooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Moooo
o`Go000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
0000o`0000Gooooo0ol00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`0<o`0000Cooooo
0_l00002ooooo`Oo000000Koooooo`000?l0003o0000ooooool00002ooooo`?o000000?oooooo`00
0?ooool01Ol00002ooooo`?o00004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00cooooo001;ooooo`;o00004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07_ooool4o`000004ooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000;ooooo00Go0000
ooooool0003o0000ooooo`0=o`000003ooooool0003o000000Cooooo0_l00002ooooo`Oo000000Ko
ooooo`000?l0003o0000ooooool00002ooooo`?o000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000ooooo`03o`00013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<oooo
o`00Boooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`Oo00001oooool4o`000004ooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00005ooooo`07o`000?oooooo
0000o`000?oooooo0000ooooo`02o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo
0000o`000004ooooo`;o00000_ooool6o`000003ooooool0003o000000Co00000_ooool3o`000004
ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0000@ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool02oooool004[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool9o`00
00Oooooo0ol00004ooooo`Co000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000;ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`000003ooooool0003o000000;o
00000oooool2o`0000;ooooo3Ol00002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool7
o`00013ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`;o00004oooool3o`0000;ooooo1Ol000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00ol000000ooooooo0000o`000006
o`000003ooooool0003o000000?o00000_ooool3o`000005ooooool0003o0000o`000?ooool02Ol0
0002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool3o`000004ooooool0003o0000o`00
013ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo1Ol000001?oooooo0000ooooool00003oooo
o`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooooooo0_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000ol000000ooooooo0000ooooo`02o`000005ooooool0003o0000o`00
0?ooool01ol000001?oooooo0000ooooooooool4o`000003ooooool0003ooooo00Cooooo1Ol0000>
ooooo`?o0000@?ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0000Koooo
o`Oo00000oooool01?l0003oooooooooooooool4o`0000;ooooo0_l000001?oooooo0000ooooool0
0003ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`So000000?oooooo`000?l00000
1Ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Go000000Coooooo`000?oo
oooooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002oooool3o`00
00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0001go
oooo1ol00003ooooo`04o`000?ooooooooooooooo`Co00000_ooool2o`000004ooooool0003ooooo
o`0000?ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003o000000Oo000000Go
ooooo`000?l0003o0000ooooo`06o`000005ooooool0003o0000o`000?ooool01ol000001?oooooo
0000ooooooooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool00_l00008oooo
o`?o00001_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo001:ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`?o
000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool4o`0000;ooooo0_l00000
1?oooooo0000ooooool00003ooooo`05o`000?ooooooooooo`000?ooool03?l000001Ooooooo0000
o`000?l0003ooooo00Oo000000Coooooo`000?l0003ooooo1ol000001?oooooo0000ooooooooool2
o`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00005ooooo`?o00002_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo0019ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`?o000000?ooooo
o`000?l000000ol000000ooooooo0000ooooo`02ooooo`Co000000Soooooo`000?oooooo0000oooo
ool0003oooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`0Bo`000004ooooool0003o0000
ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`;o
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo1?l0000>ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo1Ol000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo
00;ooooo00Go0000oooooooooooo0000ooooo`0Bo`000004ooooool0003o0000ooooo`;o000000Ko
ooooo`000?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`Go00004oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00[ooooo0019ooooo`?o00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oo
oooo1ol000001?oooooo0000ooooool00003ooooo`Co000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000003ol00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Oo000000Coooooo`000?l0003o
oooo0_l00009ooooo`?o00005_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[o
oooo0019ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Wooooo`Ko000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000000;o0000
00Goooooo`000?ooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`00
0003ooooool0003o000000;ooooo1ol000000ooooooo0000o`000006o`000006ooooool0003o0000
ooooool0003ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o0000
1_ooool3o`0001[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0:ooooo`00;ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`Go000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`03o`000005oooo
ool0003oooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol000001?oo
oooo0000ooooooooool7o`000003ooooool0003o000000Go00000_ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000?o00000oooool3o`0001kooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`00;oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool3o`000003ooooool0
003o000000;o00001?ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?l000001?l0
00001Ooooooo0000o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`0000;o
oooo0ol000001?oooooo0000ooooooooool7o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko00008_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo000_ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`;o00002?ooool8o`00
0004ooooool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003ooooo00Cooooo00?o0000ooooooooool00_l00002ooooo`?o000000Coooooo`000?oooooooooo
1ol000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_l00003oooo
o`;o000000?oooooo`000?l000002?l0000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool02_ooool002oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool7o`0000;ooooo00?o0000ooooool000000_l000001Ooo
oooo0000oooooooooooo000000Gooooo00?o0000ooooooooool00_l00002ooooo`?o000000Cooooo
o`000?oooooooooo1ol000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003o
oooo0_l00004ooooo`03o`000?oooooo000000Wo00009_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00[ooooo000_ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00gooooo1?l00002ooooo`;o000000Coooooo`000?oo
oooooooo1?l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002oooo
o`?o000000Coooooo`000?oooooooooo1ol000000ooooooo0000o`000002o`000006ooooool0003o
0000ooooool0003ooooo0_l00004ooooo`03o`000?oooooo000000Co000000?oooooo`000?l00000
0_l0000Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Oooool002oooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo0_l0000@ooooo`Go0000
00?oooooo`000?ooool01?l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001?ooool2o`000004ooooool0003oooooooooo`Oo000000?ooooo
o`000?l000000_l000001_oooooo0000o`000?oooooo0000ooooo`;o00000_ooool9o`000003oooo
ool0003o000000;o0000:?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo
000_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo0ol0000Booooo`Go000000?oooooo`000?ooool00_ooool2o`000004ooooool0003o0000o`00
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000_ooool<o`000006ooooool0003o0000ooooool0003ooooo1?l000000ooooooo
0000o`000006o`000003ooooool0003o000000;o0000:Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Wooooo000_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00oooooo1?l0000Eooooo`Go000000?oooooo`000?ooool00_ooool8o`00
00Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo3ol0
00000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
000Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool004Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05oooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003
o`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000So000000?oooooo`000?ooool0
0_ooool2o`000003ooooool0003o000000;o00000_ooool4o`0002[ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`09ooooo`00Aoooool3o`0001?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo1_l00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?ooool3o`0000;ooooo1?l0000[
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool004Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06Oooool2o`000003ooooool0003ooooo00?o00001?ooool8o`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000
o`000009o`000003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?ooool3o`0000;o
oooo1?l0000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool004Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo00?o00001?ooool4o`000003oooo
ool0003o000000?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo0_l000000ooooooo0000ooooo`0;o`000003ooooool0003o000000;o00001?ooool01?l0003o
ooooooooooooool3o`0000;ooooo1?l0000]ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool004Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool2o`000003ooooool0003ooooo00;o
000000?oooooo`000?ooool00_ooool4o`000004ooooool0003oooooooooo`;o000000?oooooo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo2_l000000ooooooo0000o`000003
o`000003ooooool0003o000000;o00001?ooool01?l0003oooooooooooooool3o`0000;ooooo00Co
0000ooooool0003o0000;_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo
0017ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0
003ooooo00?ooooo0ol000001_oooooo0000oooooooooooo0000ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool4
o`0002kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00Aoooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Jooooo`;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`03oooo
o`05o`000?oooooo0000ooooool000000_ooool4o`0000?ooooo00Co0000oooooooooooooooo1?l0
00000ooooooo0000o`000008o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool4o`0002oooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`00Aoooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`;o0000
00Ooooooo`000?ooooooooooo`000?oooooo000000Cooooo00Co0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`02o`0000?ooooo1Ol00004ooooo`go000000?oooooo`000?l000000_ooool3
o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0000`ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool2o`00
0005ooooool0003oooooooooool000000_ooool00ol0003oooooooooo`02o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`03o`000?oo
oooooooo00;ooooo3Ol000000ooooooo0000o`000002ooooo`04o`000?oooooo0000o`0000;ooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0000aooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool2o`000005ooooool0
003oooooooooool000000_ooool00ol0003oooooooooo`04o`000005ooooool0003o0000o`000?oo
ool01?l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo
0000o`000007o`000004ooooool0003oooooooooo`;o000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`02ooooo`?o000000?oooooo`000?ooool00ol0000booooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool3o`000004ooooool0003oooooooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000o`000007
o`000004ooooool0003oooooooooo`?o000000Coooooo`000?oooooooooo0_l00003ooooo`?o0000
00Coooooo`000?oooooooooo0_l0000cooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o000000Go0000
0_ooool00ol0003oooooooooo`08o`000006ooooool0003o0000ooooool0003ooooo0ol00002oooo
o`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`000007o`000004ooooool0003ooooo
ooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`?o000000Goooooo`000?oooooooooo
o`00000dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool004Kooooo0_l0
000Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooooooo`Co00000_ooool3o`000003ooooool0003ooooo00Go0000
0_ooool01?l0003oooooo`000?l00002ooooo`?o000000Coooooo`000?oooooo00001Oooool01?l0
003oooooooooooooool8o`000004ooooool0003oooooooooo`?o000000Goooooo`000?oooooooooo
o`000005ooooo`;o000000Goooooo`000?ooooooooooo`00000eooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01oooool004Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000Ko00000_ooool5o`000004oooo
ool0003o0000o`0000;ooooo0_l00005ooooo`04o`000?ooooooooooooooo`So000000Coooooo`00
0?oooooooooo0ol000001Ooooooo0000oooooooooooo000000Gooooo0_l000001Ooooooo0000oooo
oooooooo000003Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`00AOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1?l00002ooooo`?o000000?o
ooooo`000?l000001Ol00002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`06o`0000Co
oooo00?o0000ooooooooool00_ooool8o`000004ooooool0003oooooooooo`?o000000?oooooo`00
0?ooool00_l00005ooooo`;o000000?oooooo`000?ooool00_l0000gooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool01oooool004Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`So00000_ooool00ol0003oooooo`000002o`000003ooooool0003o000000;o
00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`[o00000_ooool00ol0003oooooo`000002o`000003ooooool0003o0000
00Kooooo0ol000000ooooooo0000o`00000hooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01oooool004Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko
000000?oooooo`000?l000000_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00;o
00001Oooool3o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo2_l00002ooooo`05
o`000?oooooo0000o`000?ooool00_l00007ooooo`?o000000?oooooo`000?l00000>?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0015ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000001[ooooo0_l00003oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?ooool00ol000000ooooooo0000o`000003ooooo`?o00000_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo2Ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l00007
ooooo`?o000000?oooooo`000?l00000>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Oooooo0015ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool01?l0
003oooooo`000?l0000Jooooo`03o`000?oooooooooo00?o00001?ooool5o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000ooooo`03o`0000?ooooo1_l00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool9o`0000;ooooo00Go0000ooooool0003o0000
ooooo`02o`0000Oooooo0ol000000ooooooo0000o`00000jooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01_ooool004Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo0ol00007ooooo`Go000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003ooooo00?o00001_ooool3o`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o0000
00?oooooo`000?ooool00_l00007ooooo`?o000000?oooooo`000?l00000>oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Kooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool09oooool4o`0000[ooooo1Ol000001?oooooo0000ooooool00002ooooo`;o0000
00Koooooo`000?oooooo0000ooooool00006ooooo`Co000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ooooo`04ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o000000Gooooo
o`000?ooooooooooo`000007ooooo`?o000000?oooooo`000?l00000??ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Kooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool09?ooool3o`000003ooooool0003ooooo00_ooooo0_l000001ooooooo0000o`000?oo
oooo0000ooooool000000_ooool2o`000006ooooool0003oooooo`000?oooooo00001_ooool01?l0
003oooooo`000?ooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool9o`0000;ooooo0_l0
00001Ooooooo0000oooooooooooo000000Sooooo0_l000000ooooooo0000o`00000looooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01_ooool004Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`0:ooooo`;o000000Oo
ooooo`000?l0003oooooo`000?oooooo000000;ooooo0_l000000ooooooo0000o`000002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool2o`000005ooooool0003ooooooooo
ool000001Oooool9o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Sooooo0_l00000
0ooooooo0000o`00000mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
04Cooooo0_l0000Fooooo`03o`000?oooooooooo01kooooo0ol00005ooooo`;o00003Oooool2o`00
0007ooooool0003o0000ooooool0003oooooo`000002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooooooo`03ooooo`Wo00000_ooool2o`000005ooooool0003o0000ooooool000002?ooool2o`00
0003ooooool0003o000003kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06oooo
o`00A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo1?l00007ooooo`03
o`000?oooooooooo00gooooo0_l000001ooooooo0000o`000?oooooo0000ooooool000000_ooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`Wo000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003ooooo
00Oooooo0_l000000ooooooo0000ooooo`0oooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01_ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`?o
00002?ooool3o`00013ooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003ooooooooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool01_l0003oooooooooool0
003oooooo`0000Kooooo2Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool0
1oooool2o`000003ooooool0003ooooo043ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`06ooooo`00A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo0ol0
0008ooooo`?o00004oooool2o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000
ooooo`02o`000003ooooool0003ooooo00;o00001_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00006ooooo`Wo000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo00Oo
oooo0_l000000ooooooo0000ooooo`10ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01Oooool004?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`?o0000
2_ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool00_l000001Ooooooo0000
ooooool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00005ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000Kooooo1ol000000ooooooo0000ooooo`02o`0000;ooooo0_l0
00000ooooooo0000ooooo`07ooooo`;o000000?oooooo`000?ooool0@Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool03_ooool3o`0000gooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool01?l000001_oooooo0000ooooool0003oooooo`0000Gooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00001_ooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool01oooool2o`000003ooooool0003o
oooo04;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo1?l0000?ooooo`03o`000?oooooooooo
01Gooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Soooooo`00
0?oooooo0000ooooool0003oooooo`0000Gooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00001_ooool4o`000006ooooool0003o0000ooooool0003ooooo0_l00002ooooo`;o000000?ooooo
o`000?ooool01oooool01?l0003oooooooooool00014ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool004?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07
ooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?ooool00_l00000
0ooooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00005ooooo`;o
00000_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`?o00002Oooool2o`000003ooooool0003ooooo04Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo0ol0000Dooooo`03o`000?oooooooooo01Oooooo0_l000000ooo
oooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Soooooo`000?oooooo0000ooooool0
003oooooo`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`Co0000
00Coooooo`000?l0003ooooo1?l00002ooooo`?o00002_ooool3o`0004Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`0Fooooo`04o`00
0?ooooooooooooooo`?o00005oooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool0
0004ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool4o`0000;ooooo0ol0000:ooooo`?o0000A_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Gooooo0012ooooo`03o`000?oooooooooo01Oooooo1?l0
000Iooooo`03o`000?oooooooooo01Sooooo0_l000000ooooooo0000ooooo`02o`00000=ooooool0
003o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`05o`000?oo
oooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool4o`000004oooo
ool0003o0000ooooo`Co00000_ooool3o`0000[ooooo00?o0000ooooool00000Aoooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0012ooooo`;o00005Oooool4o`0001_ooooo
00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo00;o000000goooooo`000?l0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooooooo`Co00001Oooool4o`000004ooooool0003o0000
ooooo`Co00000_ooool3o`0000[ooooo00?o0000ooooool00000B?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Cooooo0012ooooo`03o`000?oooooooooo017ooooo0ol00003oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool4o`0000;ooooo00Oo0000oooo
ool0003o0000ooooool0003ooooo00;o000000Koooooo`000?ooooooooooo`000?ooool2o`000003
ooooool0003ooooo00;o000000Coooooo`000?oooooooooo1Ol00005ooooo`Co000000Coooooo`00
0?l0003ooooo0ol00003ooooo`?o00002_ooool00ol0003oooooo`000019ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool004;ooooo00?o0000ooooooooool03_ooool3o`00
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`Co00000_ooool01ol0
003oooooooooool0003oooooo`000?ooool00_l000001?oooooo0000ooooooooool2o`000005oooo
ool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Go00001?ooool4o`00
0004ooooool0003o0000ooooo`?o00000oooool3o`0000[ooooo00?o0000ooooool00000BOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo0012ooooo`03o`000?oooooooooo
00_ooooo0ol00009ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool3o`00
00;ooooo00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo
0_l000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool2o`00
0003ooooool0003ooooo00?ooooo1?l000001?oooooo0000o`000?ooool3o`0000?ooooo0ol0000:
ooooo`03o`000?oooooo000004[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`00@_ooool00ol0003oooooooooo`07ooooo`Co00003?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01cooooo0ol00002ooooo`Co000000?oooooo`000?ooool00_l000001?oo
oooo0000ooooooooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`03ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo
00Co0000ooooool0003o00002_ooool00ol0003oooooo`00001;ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool004;ooooo00?o0000ooooooooool01?ooool3o`00013ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`?o00000_ooool4o`000007oooo
ool0003o0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000ooooo`03ooooo`Co000000?oooooo`00
0?l000001?l00002ooooo`04o`000?oooooo0000o`0000[ooooo00?o0000ooooool00000C?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo0011ooooo`03o`000?oooooooooo
00;ooooo0ol0000Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool3o`00
00;ooooo0_l000002Ooooooo0000o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o0000
0_ooool01Ol0003oooooooooool0003ooooo00?o00000oooool2o`000003ooooool0003ooooo00?o
oooo1?l000000ooooooo0000o`000004o`0000;ooooo00Co0000ooooool0003o00002oooool2o`00
04gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`00@Oooool00ol0003o
ooooo`000002o`0001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`?o
00000_ooool2o`000009ooooool0003o0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0
0002ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`;o000000?oooooo`000?ooool0
0oooool4o`000003ooooool0003o000000Co00000_ooool01?l0003oooooo`000?l0000;ooooo`;o
0000COooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo0011ooooo`;o0000
6?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`00
0?oooooooooo00;o000000Koooooo`000?oooooo0000ooooool00002ooooo`;o00001Oooool01?l0
003oooooo`000?l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_l0
00000ooooooo0000o`000004o`0000;ooooo00Co0000ooooool0003o00002oooool2o`0004kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00@oooool2o`0001Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`?o00000_ooool00ol0003ooooooooo
o`02o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000Gooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000ooooo`So00000_ooool0
1?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`00A?ooool2o`0001Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Nooooo`?o00000_ooool00ol0003oooooooooo`02o`000006ooooool0003o
ooooo`000?oooooo00000_ooool2o`0000?ooooo00Go0000ooooool0003oooooo`000005ooooo`04
o`000?ooooooooooo`0000?ooooo0ol000000ooooooo0000o`000006o`0000;ooooo00Co0000oooo
ool0003o00003?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00oooool004Cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01kooooo0ol00002ooooo`03o`000?oooooooooo00;o000000Koooooo`00
0?oooooo0000ooooool00002ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000Cooooo
0_l00003ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000001_l00002ooooo`04o`00
0?oooooo0000o`0005kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00
Aoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
7oooool4o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0003ooooo0ol00002ooooo`;o
00000_ooool2o`000004ooooool0003oooooo`0000Cooooo0_l00003ooooo`03o`000?oooooooooo
00?o000000?oooooo`000?l000001_l00002ooooo`04o`000?oooooo0000o`0005kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00B?ooool2o`00017ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Oooooo`Co000000?oooooo`000?ooool00_ooool01?l0
003oooooo`000?ooool3o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00001?oo
ool2o`0000?ooooo00?o0000ooooooooool00ol000001?oooooo0000o`000?ooool5o`0000;ooooo
00Co0000ooooool0003o0000Goooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Oooooo`Co000000?oooooo`000?ooool00_ooool01Ol0003oooooo`000?l0003ooooo00;o
00000_ooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`;o00000ooo
ool00ol0003oooooooooo`03o`000004ooooool0003o0000ooooo`Go00000_ooool01?l0003ooooo
o`000?l0001Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool004[ooooo
0ol0000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool4o`000003oooo
ool0003ooooo00;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo0_l000001?oooooo0000
ooooooooool2o`000003ooooool0003ooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?o
000000Coooooo`000?l0003ooooo1Ol00002ooooo`04o`000?oooooo0000o`00067ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`02ooooo`00COooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool4o`000003ooooool0003ooooo
00;ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo0_l00000
0ooooooo0000ooooo`03ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`000004ooooool0
003o0000ooooo`Go00000_ooool01?l0003oooooo`000?l0001Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00_ooool004kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo023ooooo1?l000000ooooooo0000ooooo`02ooooo`;o0000
00Coooooo`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Go
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002
ooooo`04o`000?oooooo0000o`0006;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`00@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000Qooooo`03o`000?oo
oooooooo023ooooo1?l000000ooooooo0000ooooo`02ooooo`;o000000Coooooo`000?oooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0
003o0000Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo0010ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0001oooooo00?o0000ooooooooool08Oooool4o`00
0004ooooool0003oooooooooo`?o000000Coooooo`000?oooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?l0003ooooo1?l00003ooooo`04o`000?ooooooooooo`0006Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`00@?ooool01Ol@413ooooooooooooooooo410@00go
oooo0_l0000Mooooo`03o`000?oooooooooo027ooooo0_l000001?oooooo0000ooooool00002oooo
o`?o000000?oooooo`000?ooool00_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00003oooo
o`;o00001oooool00ol0003oooooo`000002o`000003ooooool0003o000000;o00000oooool01?l0
003oooooooooool0001Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
043ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08Oooool2o`000004ooooool0003oooooo`0000;ooooo0ol000000ooooooo0000oooo
o`02o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Cooooo0_l0
0007ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_l00003ooooo`04o`000?oo
ooooooooo`0006Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00@?oo
ool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Iooooo`03o`000?oooooooooo02;ooooo
0_l000001?oooooo0000ooooool00002ooooo`?o000000?oooooo`000?ooool00_l00002ooooo`03
o`000?oooooo000000Co000000?oooooo`000?l000001?ooool2o`0000Oooooo00?o0000ooooool0
00000_l000000ooooooo0000o`000002o`0000?ooooo00Co0000oooooooooooo0000I_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0010ooooo`05oa0@4?oooooooooooooo
ool@41004Oooool2o`0001Sooooo00?o0000ooooooooool08_ooool2o`000004ooooool0003ooooo
o`0000;ooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00000_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000000_l00003ooooo`04o`000?ooooooooooo`0006Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`01ooooo`00@?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`;o000000Coooooo`000?oo
oooo00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`?o000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00005ooooo`03o`00
0?oooooooooo00?o000000?oooooo`000?l000000_l00003ooooo`04o`000?oooooo0000o`0006So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00@?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Cooooo0_l0000Eooooo`03o`000?oooooooooo02;ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`06o`000?oooooooooo
ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool01?oo
ool00ol0003oooooooooo`03o`000003ooooool0003o000000;o00000oooool01?l0003oooooo`00
0?l0001Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool005_ooooo0_l0
000Booooo`03o`000?oooooooooo02?ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo
0_l000001Ooooooo0000ooooool0003ooooo00?o00000oooool02Ol0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol0
00000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0003o0000J_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo001Looooo`;o00004Oooool00ol0003ooooooooo
o`0Sooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooo
o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003o`000003
ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol000000ooooooo0000o`000002o`0000?o
oooo00Co0000ooooool0003o0000Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo001Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool2o`000005
ooooool0003oooooooooool000000_ooool3o`0000;ooooo1?l00004ooooo`05o`000?oooooo0000
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00?o0000ooooooooool0
0ol000000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0003o0000Joooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001Oooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool09Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o
000000Coooooo`000?l0003ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000001Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00000oooool3o`0000?ooooo00Co0000
ooooool0003o0000K?ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00H?ooool3
o`0000_ooooo00?o0000ooooooooool09Oooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool00_l00004ooooo`05o`000?oooooo0000ooooool00000
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00000oooool00ol0003ooooo
o`000003ooooo`04o`000?oooooo0000o`0006gooooo00?o0000ooooooooool02Oooool1o`00007o
oooo0Oooool0067ooooo0_l0000cooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
oooo0_l000001?oooooo0000ooooooooool2o`0000Cooooo00Go0000ooooool0003oooooo`000005
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ol00002ooooo`?o00000oooool0
1?l0003oooooo`000?l0001^ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001S
ooooo`;o0000<Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o000000Cooooo
o`000?oooooooooo0_l00004ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00?o00000_ooool3o`0000?ooooo00Co0000ooooool0003o
0000Koooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00IOooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00?o000000Goooooo`000?l0003oooooo`000002ooooo`;o
00001?ooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`03o`0000;ooooo0ol00003ooooo`04o`000?oooooo0000o`0006oooooo00?o0000
ooooooooool01oooool1o`00007ooooo0Oooool006Kooooo0_l0000`ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo00Go0000ooooool0003ooooo
o`000005ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooooooo0_l00002ooooo`?o
00000oooool01?l0003oooooo`000?l0001`ooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`7ooooo001Wooooo`;o0000;oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00Co
0000oooooooooooooooo0_l00002ooooo`?o00000oooool01?l0003oooooo`000?l0001aooooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo02Kooooo
1ol00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o0000
L_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00J_ooool2o`0002;ooooo1?l0
0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000ooooool0003o
0000Loooool00ol0003oooooooooo`04ooooo`7o00000Oooool006cooooo00?o0000ooooooooool0
7Oooool2o`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
00000oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooo`000?l0
001cooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00F_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`?o00007?ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000001Oooool2o`0000?ooooo00?o0000ooooooooool00_l00005oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Co0000ooooool0003o0000M?ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool005cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001Oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`04o`000?oooooo0000o`0007Gooooo00?o0000ooooooooool00_ooool1o`00007o
oooo001Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooo000001Oooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooo`00001gooooo`05o`000?ooooooooooooooool000000Oooool005cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000Fooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_l00005ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`00001hooooo`04o`000?ooooooooooo`00007ooooo001Looooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Go
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000007Sooooo00Co0000oooooooooooo0000
0Oooool005cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo
0_l0000Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000;o00001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooool00000NOooool00ol0003oooooooooo`01o`000000G?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0000oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l00005
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`00001jooooo`7o00000Oooool1o`000000
F_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo0ol00005ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`00001kooooo`;o0000001hooooo`;o00003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00001Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool00000N_ooool3o`000000N_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002
ooooo`?o00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ooo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000MOooool5o`00
00?ooooo001kooooo`;o00002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`00
0?ooooooooooo`00077ooooo1?l00008ooooo`00O?ooool2o`0000Oooooo00?o0000ooooooooool0
7_ooool01?l0003oooooooooool00002ooooo`?o00001Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co
0000oooooooooooo0000KOooool4o`0000cooooo001nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool3o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooooooo
o`0006Sooooo1Ol0000@ooooo`00Ooooool3o`0002Cooooo00?o0000ooooooooool00oooool3o`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Ko0000
ooooool0003o0000ooooool00002ooooo`04o`000?ooooooooooo`0006Cooooo1?l0000Eooooo`00
POooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool01?l0003oooooooooool0001Oooooo`Go00006Oooool008;ooooo0_l0000R
ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01?l0003o
ooooooooool0001Kooooo`Co00007_ooool008Cooooo00?o0000ooooool000007oooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001Oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00Co0000oooooooooooo0000
E_ooool5o`0002;ooooo0025ooooo`;o00007oooool00ol0003oooooooooo`03ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01_l0003ooooo
o`000?l0003oooooo`0000;ooooo00?o0000ooooool00000Doooool4o`0002Oooooo0026ooooo`;o
00007_ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o
0000ooooool00000Coooool4o`0002_ooooo001dooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Oooooo0_l000001ooooooo0000oooooooooooo0000oooo
ool00000B_ooool5o`0002oooooo001dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Qooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001oooool2o`000007ooooool0003oooooooooool0003o
ooooo`000016ooooo`Co0000=?ooool007Gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Wooooo0_l0000Pooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
047ooooo1Ol0000hooooo`00M_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000002oooool2o`0001kooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000?Oooool4
o`0003gooooo001gooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`;o00007?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000iooooo`Co0000@Ooo
ool007Sooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o
0000ooooooooool06_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000dooooo`Go0000
AOooool007Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03oooool2o`0001[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000<?ooool4o`00
04[ooooo001dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^017ooooo00?o0000ooooool000005oooool2o`0000[ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000:oooool5o`0004kooooo002C
ooooo`;o00005oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000002Oooooo1?l0001Cooooo`00UOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooo000002;ooooo1Ol0001Gooooo`00U_ooool3o`0001?ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000001kooooo1?l0
001Looooo`00V?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00Co0000
oooooooooooo00003_ooool00ol0003oooooo`00000Jooooo`Co0000H?ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`0Eooooo`Go0000I?ooool009[ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00008_ooool4o`0006Wooooo002Looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02_ooool01?l0003oooooooooool0000Mooooo`Go0000KOooool009cooooo0ol0000<
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00006Oooool4o`0007;ooooo002<
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
1?l0001fooooo`00S?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017o
oooo1Ol0001jooooo`00T?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`Co
0000Ooooool008oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Go0000Poooool007Oooooo
00GoV9RHo`000?l0003oA4A4okZj^P0Booooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co0000R?ooool007Oo
oooo00Go410@okZj^_o^k^koMgMgoa0@400Cooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`Go0000S?ooool0
07Oooooo00?o0000ooooooooool04_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`05o`000?oooooo0000ooooool000002_ooool4o`00097ooooo
001gooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03oooool2o`000003ooooool0003ooooo00Gooooo1?l0002Eooooo`00
Moooool00ol0003oooooooooo`0_ooooo`?o000000?oooooo`000?l000000ol0002Iooooo`00MOoo
ool00ol@413o0000o`000003o`00033ooooo0_l0002Nooooo`00Moooool00ol0003oooooooooo`3A
ooooo`00Moooool00ol0003oooooooooo`3Aooooo`00oooooom<ooooo`00oooooom<ooooo`00oooo
oom<ooooo`00Y?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^09co
oooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Looooo`00
X_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@402Looooo`00X_ooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool00000W?ooool00:;ooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000009cooooo002Sooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@402Looooo`00Xoooool00oo^k^koA4A4o`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0W?ooool00:Cooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^09cooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo
003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0033ooooo`04oa0@
4?l0003o0000o`0008Cooooo0034ooooo`03o`000?oooooooooo08Cooooo0034ooooo`03o`000?oo
oooooooo08Cooooo002Gooooo`05o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`00
0?mgMgOo410@o`0000Cooooo00?o8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4
okZj^POooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3ooooo`09o`000?mgMgOo0000o`000?mE
EEGok^k^ooooooo^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4
A4Coc<c<00?ooooo00OoV9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool01_nHV9So
0000o`000?mgMgOo0000oa0@40;o00000_ooool01Ol0003oooooooooool0003o410@053ooooo002F
ooooo`06ojVYZOl0003oQhN7oiRHV?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Co
oooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Oooooo00Ko
0000ojVYZOoooooooooookZj^_l00003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomE
EEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooo
oon7QhOo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1?ooooo`00
U_ooool01_mEEEGoQhN7odA4A?mEEEGoMgMgoeEEE@;ooooo00Go410@ohN7Qoooooook^k^o`000004
ooooo`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool02oooool01Onj^[[oQhN7ofIV
I_mVIVKo410@00?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
04oooooo002Fooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002
o`0000?ooooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00001oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`00
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0Coooool009Gooooo00SoZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZ@Co
oooo00Ooc<c<o`000?ooooooooooonk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b1oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00go
0000oeEEEOo^k^koooooogMgMomVIVKooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00;ooooo00Ko
IVIVogMgMoooooooooooohN7Qol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oc8b<_oM
gMd01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoM
gMgo8B4Q057ooooo002Eooooo`?o00000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0_oo
ool00ol@413o0000o`000002ooooo`?o000000?oooooonk^k_mEEED00_l000000om4A4Cok^k^oooo
o`06ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool00ol@413o0000ogMgM`02o`000005
ofIVI_o^k^koooooonk^k_mEEED00_l000001_m4A4Cok^k^ooooooooooook^k^ofIVIP;o000000Co
A4A4o`000?oooooo410@1Ol00003ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o
0000ooooooooool2o`000009ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY057ooooo
003Looooo`03o`000?oooooooooo06cooooo003Looooo`03o`000?oooooooooo06cooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.163248, -0.0828824, \
0.00404337, 0.00404337}}],

Cell[TextData[{
  "Fig. 7.8 Spectrum associated with solution shown in Fig. ",
  ButtonBox["7.7",
    ButtonData:>"Fig. 7.7",
    ButtonStyle->"Hyperlink"]
}], "Caption",
  CellTags->"Fig. 7.8"],

Cell[TextData[{
  "\tThis leaves us in a bit of a quandary. By including dispersion in the \
KdV equation, which should make the equation a more accurate descriptor of \
water waves than Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " ,  we have actually lost wavebreaking, one of the main qualitative \
features of such waves.  "
}], "Text"],

Cell[TextData[{
  "\tThe solution to this puzzle lies in the approximate form of dispersion \
in the KdV equation. As already mentioned in connection with the rounded \
peaks of cnoidal waves, Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  is a poor approximation for large wavenumbers, yielding a phase velocity \
that can actually be negative for large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". The exact dispersion relation ",
  ButtonBox["(7.2.1)",
    ButtonData:>{"Chapter7.nb", "(7.2.1)"},
    ButtonStyle->"Hyperlink"],
  "  varies much less rapidly at large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", and results in weaker dispersion that allows real water waves to break, \
provided their amplitude is sufficiently large. "
}], "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowSize->{650, 573},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:18"->{
    Cell[2045, 65, 124, 4, 32, "Subsubtitle",
      CellTags->"c:18"]},
  "c:19"->{
    Cell[2194, 73, 51, 1, 36, "Section",
      CellTags->"c:19"]},
  "i:74"->{
    Cell[3253, 96, 367, 12, 44, "Text",
      CellTags->"i:74"]},
  "(7.2.20)"->{
    Cell[3623, 110, 338, 12, 32, "NE2",
      CellTags->"(7.2.20)"]},
  "(7.2.21)"->{
    Cell[4121, 131, 212, 7, 38, "NE2",
      CellTags->"(7.2.21)"]},
  "(7.2.22)"->{
    Cell[4687, 151, 912, 23, 46, "NE2",
      CellTags->"(7.2.22)"]},
  "(7.2.23)"->{
    Cell[6423, 202, 322, 8, 35, "NE2",
      CellTags->"(7.2.23)"]},
  "(7.2.24)"->{
    Cell[7115, 226, 148, 5, 29, "NE2",
      CellTags->"(7.2.24)"]},
  "Cell 7.40"->{
    Cell[7422, 240, 155, 4, 67, "Input",
      CellTags->"Cell 7.40"]},
  "i:53"->{
    Cell[9246, 298, 790, 20, 78, "Text",
      CellTags->"i:53"]},
  "Cell 7.41"->{
    Cell[10934, 344, 125, 3, 67, "Input",
      CellTags->"Cell 7.41"]},
  "i:44"->{
    Cell[11163, 354, 72, 1, 30, "Section",
      CellTags->{"i:44", "c:20"}]},
  "c:20"->{
    Cell[11163, 354, 72, 1, 30, "Section",
      CellTags->{"i:44", "c:20"}]},
  "Cell 7.42"->{
    Cell[11340, 362, 318, 7, 119, "Input",
      CellTags->"Cell 7.42"]},
  "Cell 7.43"->{
    Cell[11950, 384, 291, 7, 103, "Input",
      CellTags->"Cell 7.43"]},
  "(7.2.25)"->{
    Cell[12564, 407, 273, 9, 28, "NE2",
      CellTags->"(7.2.25)"]},
  "Cell 7.44"->{
    Cell[12919, 422, 392, 11, 183, "Input",
      CellTags->"Cell 7.44"]},
  "Cell 7.45"->{
    Cell[15566, 506, 1253, 22, 391, "Input",
      CellTags->"Cell 7.45"]},
  "Cell 7.46"->{
    Cell[17076, 541, 100, 3, 55, "Input",
      CellTags->"Cell 7.46"]},
  "c:21"->{
    Cell[17919, 565, 70, 1, 30, "Section",
      CellTags->"c:21"]},
  "Cell 7.47"->{
    Cell[18117, 573, 247, 6, 87, "Input",
      CellTags->"Cell 7.47"]},
  "Cell 7.48"->{
    Cell[18439, 583, 375, 11, 183, "Input",
      CellTags->"Cell 7.48"]},
  "Cell 7.49"->{
    Cell[19224, 608, 105, 3, 55, "Input",
      CellTags->"Cell 7.49"]},
  "i:45"->{
    Cell[20344, 637, 87, 1, 30, "Section",
      CellTags->{"i:45", "c:22"}]},
  "c:22"->{
    Cell[20344, 637, 87, 1, 30, "Section",
      CellTags->{"i:45", "c:22"}]},
  "Cell 7.50"->{
    Cell[21419, 666, 313, 7, 119, "Input",
      CellTags->"Cell 7.50"]},
  "Cell 7.51"->{
    Cell[22361, 694, 541, 11, 183, "Input",
      CellTags->"Cell 7.51"]},
  "Fig. 7.7"->{
    Cell[210431, 7457, 95, 1, 15, "Caption",
      CellTags->"Fig. 7.7"]},
  "Fig. 7.8"->{
    Cell[506182, 21001, 194, 6, 15, "Caption",
      CellTags->"Fig. 7.8"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:18", 540423, 22133},
  {"c:19", 540507, 22136},
  {"i:74", 540586, 22139},
  {"(7.2.20)", 540668, 22142},
  {"(7.2.21)", 540754, 22145},
  {"(7.2.22)", 540839, 22148},
  {"(7.2.23)", 540925, 22151},
  {"(7.2.24)", 541010, 22154},
  {"Cell 7.40", 541096, 22157},
  {"i:53", 541180, 22160},
  {"Cell 7.41", 541264, 22163},
  {"i:44", 541349, 22166},
  {"c:20", 541440, 22169},
  {"Cell 7.42", 541536, 22172},
  {"Cell 7.43", 541627, 22175},
  {"(7.2.25)", 541717, 22178},
  {"Cell 7.44", 541804, 22181},
  {"Cell 7.45", 541896, 22184},
  {"Cell 7.46", 541989, 22187},
  {"c:21", 542074, 22190},
  {"Cell 7.47", 542160, 22193},
  {"Cell 7.48", 542250, 22196},
  {"Cell 7.49", 542342, 22199},
  {"i:45", 542427, 22202},
  {"c:22", 542518, 22205},
  {"Cell 7.50", 542614, 22208},
  {"Cell 7.51", 542705, 22211},
  {"Fig. 7.7", 542796, 22214},
  {"Fig. 7.8", 542887, 22217}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 151, 4, 68, "Subtitle"],
Cell[1881, 58, 139, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[2045, 65, 124, 4, 32, "Subsubtitle",
  CellTags->"c:18"],

Cell[CellGroupData[{
Cell[2194, 73, 51, 1, 36, "Section",
  CellTags->"c:19"],
Cell[2248, 76, 610, 9, 95, "Text"],
Cell[2861, 87, 389, 7, 78, "Text"],
Cell[3253, 96, 367, 12, 44, "Text",
  CellTags->"i:74"],
Cell[3623, 110, 338, 12, 32, "NE2",
  CellTags->"(7.2.20)"],
Cell[3964, 124, 154, 5, 27, "Text"],
Cell[4121, 131, 212, 7, 38, "NE2",
  CellTags->"(7.2.21)"],
Cell[4336, 140, 348, 9, 49, "Text"],
Cell[4687, 151, 912, 23, 46, "NE2",
  CellTags->"(7.2.22)"],
Cell[5602, 176, 818, 24, 67, "Text"],
Cell[6423, 202, 322, 8, 35, "NE2",
  CellTags->"(7.2.23)"],
Cell[6748, 212, 364, 12, 44, "Text"],
Cell[7115, 226, 148, 5, 29, "NE2",
  CellTags->"(7.2.24)"],
Cell[7266, 233, 153, 5, 27, "Text"],
Cell[7422, 240, 155, 4, 67, "Input",
  CellTags->"Cell 7.40"],
Cell[7580, 246, 1663, 50, 156, "Text"],
Cell[9246, 298, 790, 20, 78, "Text",
  CellTags->"i:53"],
Cell[10039, 320, 892, 22, 95, "Text"],
Cell[10934, 344, 125, 3, 67, "Input",
  CellTags->"Cell 7.41"],
Cell[11062, 349, 64, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11163, 354, 72, 1, 30, "Section",
  CellTags->{"i:44", "c:20"}],
Cell[11238, 357, 99, 3, 24, "Text"],
Cell[11340, 362, 318, 7, 119, "Input",
  CellTags->"Cell 7.42"],
Cell[11661, 371, 264, 9, 40, "Text"],

Cell[CellGroupData[{
Cell[11950, 384, 291, 7, 103, "Input",
  CellTags->"Cell 7.43"],
Cell[12244, 393, 104, 3, 38, "Output"]
}, Open  ]],
Cell[12363, 399, 198, 6, 24, "Text"],
Cell[12564, 407, 273, 9, 28, "NE2",
  CellTags->"(7.2.25)"],
Cell[12840, 418, 54, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[12919, 422, 392, 11, 183, "Input",
  CellTags->"Cell 7.44"],
Cell[13314, 435, 274, 6, 74, "Message"],
Cell[13591, 443, 275, 6, 58, "Message"],
Cell[13869, 451, 274, 6, 74, "Message"],
Cell[14146, 459, 220, 5, 58, "Message"]
}, Open  ]],
Cell[14381, 467, 274, 5, 56, "Text"],
Cell[14658, 474, 905, 30, 72, "Text"],
Cell[15566, 506, 1253, 22, 391, "Input",
  CellTags->"Cell 7.45"],
Cell[16822, 530, 251, 9, 24, "Text"],
Cell[17076, 541, 100, 3, 55, "Input",
  CellTags->"Cell 7.46"],
Cell[17179, 546, 79, 1, 43, "Input"],
Cell[17261, 549, 621, 11, 88, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[17919, 565, 70, 1, 30, "Section",
  CellTags->"c:21"],
Cell[17992, 568, 122, 3, 24, "Text"],
Cell[18117, 573, 247, 6, 87, "Input",
  CellTags->"Cell 7.47"],
Cell[18367, 581, 69, 0, 24, "Text"],
Cell[18439, 583, 375, 11, 183, "Input",
  CellTags->"Cell 7.48"],
Cell[18817, 596, 404, 10, 56, "Text"],
Cell[19224, 608, 105, 3, 55, "Input",
  CellTags->"Cell 7.49"],
Cell[19332, 613, 79, 1, 43, "Input"],
Cell[19414, 616, 521, 8, 104, "Text"],
Cell[19938, 626, 369, 6, 72, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20344, 637, 87, 1, 30, "Section",
  CellTags->{"i:45", "c:22"}],
Cell[20434, 640, 594, 11, 88, "Text"],
Cell[21031, 653, 385, 11, 56, "Text"],
Cell[21419, 666, 313, 7, 119, "Input",
  CellTags->"Cell 7.50"],
Cell[21735, 675, 79, 1, 43, "Input"],
Cell[21817, 678, 519, 12, 72, "Text"],

Cell[CellGroupData[{
Cell[22361, 694, 541, 11, 183, "Input",
  CellTags->"Cell 7.51"],
Cell[22905, 707, 186076, 6710, 296, 62427, 5179, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[208996, 7420, 535, 13, 72, "Text"],
Cell[209534, 7435, 831, 17, 120, "Text"],
Cell[210368, 7454, 60, 1, 43, "Input"],
Cell[210431, 7457, 95, 1, 15, "Caption",
  CellTags->"Fig. 7.7"],
Cell[210529, 7460, 295650, 13539, 296, 133579, 11534, "GraphicsData", \
"PostScript", "Picture"],
Cell[506182, 21001, 194, 6, 15, "Caption",
  CellTags->"Fig. 7.8"],
Cell[506379, 21009, 405, 9, 56, "Text"],
Cell[506787, 21020, 835, 20, 104, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

